(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    309622,       6802]
NotebookOptionsPosition[    307875,       6737]
NotebookOutlinePosition[    308238,       6753]
CellTagsIndexPosition[    308195,       6750]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["\<\
Reinforcement Learning Dynamics in Social Dilemmas - Figure 1\
\>", "Title"],

Cell["Luis R. Izquierdo and Segismundo S. Izquierdo", "Subtitle"],

Cell[TextData[{
 "This program was used to generate figure 1 in the paper: \nIzquierdo, S. \
S., Izquierdo, L. R. and Gotts, N. M. (2008). Reinforcement Learning Dynamics \
in Social Dilemmas. Journal of Artificial Societies and Social Simulation \
11(2)1. <",
 ButtonBox["http://jasss.soc.surrey.ac.uk/11/2/1.html",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://jasss.soc.surrey.ac.uk/11/2/1.html"], None}],
 ">\nThe output of this program is a phase plane with several arrows \
representing the expected motion at various states of the system, and with a \
sample simulation run."
}], "Subsubtitle",
 CellChangeTimes->{{3.3934427174375*^9, 3.393442718140625*^9}, 
   3.4140420699351254`*^9, {3.4140421038101254`*^9, 3.4140421261070004`*^9}, 
   3.4140424423882504`*^9}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Licence", "Section"]], "Section"],

Cell["\<\
Copyright (C) 2007 Luis R. Izquierdo & Segismundo S. Izquierdo

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version. 

This program is distributed in the hope that it will be useful, 
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details. 

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, \
USA.\
\>", "Subsubtitle"]
}, Closed]],

Cell[CellGroupData[{

Cell["Setting the Environment", "Section"],

Cell[BoxData[
 RowBox[{"Off", "[", 
  RowBox[{"General", "::", "spell"}], "]"}]], "Input",
 CellChangeTimes->{{3.392687636046875*^9, 3.392687636953125*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Parameters", "Section"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", "Payoffs", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"T", "=", "3"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"R", "=", "4"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"P", "=", "1"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"S", "=", "0"}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"Aspiration", " ", "Threshold"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"A", "=", 
     RowBox[{"1", "/", "2"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"Learning", " ", "rate"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"l", "=", 
     RowBox[{"1", "/", "2"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", "Noise", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"noise", "=", "0"}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "Distance", " ", "between", " ", "consecutive", " ", "trajectories", " ", 
     "in", " ", "the", " ", "perimeter", " ", "of", " ", "the", " ", "state", 
     " ", "space"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"step", "=", 
     RowBox[{"5", "/", "100"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"Simulation", " ", "parameters"}], "*)"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"SeedRandom", "[", "1", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"nOfIterations", "=", "40"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"initialProb1", "=", 
     RowBox[{"1", "/", "2"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"initialProb2", "=", 
     RowBox[{"1", "/", "2"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "Directory", " ", "where", " ", "the", " ", "figure", " ", "will", " ", 
     "be", " ", "saved"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"SetDirectory", "[", "\"\<C:\\\\temp\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"File", " ", "extensions", " ", "required"}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"extensions", "=", 
     RowBox[{"{", "\"\<.png\>\"", "}"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"figureSize", " ", "=", " ", "600"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"textScaleFactor", "=", 
     RowBox[{"figureSize", "/", "600"}]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.392707136859375*^9, 3.392707138125*^9}, {
   3.392707253765625*^9, 3.39270725534375*^9}, {3.392759847390625*^9, 
   3.39275985003125*^9}, {3.39276092778125*^9, 3.392760938890625*^9}, {
   3.392763584703125*^9, 3.3927635946875*^9}, {3.39276372115625*^9, 
   3.392763728890625*^9}, {3.392763943625*^9, 3.392763943859375*^9}, 
   3.39285697478125*^9, {3.392857065765625*^9, 3.392857088984375*^9}, {
   3.39285722871875*^9, 3.392857229140625*^9}, 3.39285748475*^9, {
   3.39286376171875*^9, 3.39286376225*^9}, {3.393437145859375*^9, 
   3.393437200734375*^9}, 3.39343724715625*^9, {3.393437638703125*^9, 
   3.393437639140625*^9}, {3.393437791234375*^9, 3.39343779196875*^9}, {
   3.39343809265625*^9, 3.393438093078125*^9}, {3.393438161609375*^9, 
   3.393438162234375*^9}, {3.3934382738125*^9, 3.393438279453125*^9}, {
   3.393439720859375*^9, 3.393439721296875*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Definition of functions and labels", "Section"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"Labels", ".", " ", "This"}], " ", "is", " ", "done", " ", "for", 
    " ", "efficiency", " ", "and", " ", "code", " ", "readability"}], "*)"}], 
  "\n", 
  RowBox[{
   RowBox[{
    RowBox[{"Cooperate", "=", "0"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Defect", "=", "1"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"CC", "=", "0"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"CD", "=", "1"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"DC", "=", "2"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"DD", "=", "3"}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"Calculation", " ", "of", " ", "possible", " ", 
     RowBox[{"stimuli", ".", " ", "These"}], " ", "operations", " ", "are", 
     " ", "performed", " ", "only", " ", "once", " ", "for", " ", 
     "efficiency"}], "*)"}], "\n", 
   RowBox[{
    RowBox[{"divisor", "=", 
     RowBox[{"Max", "[", 
      RowBox[{
       RowBox[{"Abs", "[", 
        RowBox[{"T", "-", "A"}], "]"}], ",", 
       RowBox[{"Abs", "[", 
        RowBox[{"R", "-", "A"}], "]"}], ",", 
       RowBox[{"Abs", "[", 
        RowBox[{"P", "-", "A"}], "]"}], ",", 
       RowBox[{"Abs", "[", 
        RowBox[{"S", "-", "A"}], "]"}]}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"stimulusAfterCC", " ", "=", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"R", "-", "A"}], ")"}], "/", "divisor"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"stimulusAfterCD", " ", "=", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"S", "-", "A"}], ")"}], "/", "divisor"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"stimulusAfterDC", " ", "=", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"T", "-", "A"}], ")"}], "/", "divisor"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"stimulusAfterDD", " ", "=", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"P", "-", "A"}], ")"}], "/", "divisor"}]}], ";"}], "\n", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"Stimulus", " ", "after", " ", "a", " ", "certain", " ", 
     RowBox[{"outcome", ".", " ", "This"}], " ", "function", " ", "returns", 
     " ", "the", " ", "stimulus", " ", "after", " ", "a", " ", "given", " ", 
     "outcome", " ", 
     RowBox[{"(", 
      RowBox[{"e", ".", "g", ".", " ", "CD"}], ")"}], " ", "for", " ", "the", 
     " ", "agent", " ", "who", " ", "has", " ", "selected", " ", "the", " ", 
     "action", " ", "indicated", " ", "by", " ", "the", " ", "first", " ", 
     "letter", " ", "of", " ", "the", " ", "outcome", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"e", ".", "g", ".", " ", "C"}], ")"}], "."}]}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"stimulusAfter", "[", "x_", "]"}], ":=", 
     RowBox[{"Switch", "[", 
      RowBox[{
      "x", ",", "\[IndentingNewLine]", "CC", ",", "stimulusAfterCC", ",", 
       "\[IndentingNewLine]", "CD", ",", "stimulusAfterCD", ",", 
       "\[IndentingNewLine]", "DC", ",", "stimulusAfterDC", ",", 
       "\[IndentingNewLine]", "DD", ",", "stimulusAfterDD"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\n", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{
     "Changes", " ", "in", " ", "the", " ", "probability", " ", "of", " ", 
      "cooperating", " ", "after", " ", "given", " ", 
      RowBox[{"outcomes", ".", " ", "The"}], " ", "first", " ", "argument", 
      " ", "is", " ", "the", " ", "outcome"}], ",", " ", 
     RowBox[{
     "and", " ", "the", " ", "second", " ", "argument", " ", "is", " ", "the",
       " ", "probability", " ", "to", " ", "be", " ", 
      RowBox[{"updated", ".", " ", "This"}], " ", "function", " ", "returns", 
      " ", "the", " ", "change", " ", "on", " ", "the", " ", "probability", 
      " ", "indicated", " ", "by", " ", "the", " ", "second", " ", "argument",
       " ", "after", " ", "the", " ", "outcome", " ", "indicated", " ", "in", 
      " ", "the", " ", "first", " ", "argument", " ", 
      RowBox[{"(", 
       RowBox[{"e", ".", "g", ".", " ", "CD"}], ")"}], " ", "for", " ", "the",
       " ", "agent", " ", "who", " ", "has", " ", "selected", " ", "the", " ",
       "action", " ", "indicated", " ", "by", " ", "the", " ", "first", " ", 
      "letter", " ", "of", " ", "the", " ", "outcome", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"e", ".", "g", ".", " ", "C"}], ")"}], "."}]}]}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"changeAfterOn", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], ":=", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"x", "\[Equal]", "CC"}], ")"}], "||", 
        RowBox[{"(", 
         RowBox[{"x", "\[Equal]", "CD"}], ")"}]}], ",", " ", 
       "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{"Agent", " ", "has", " ", "cooperated"}], "*)"}], 
       "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"stimulusAfter", "[", "x", "]"}], "\[GreaterEqual]", "0"}], 
         ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", "y"}], ")"}], "*", "l", "*", 
          RowBox[{"stimulusAfter", "[", "x", "]"}]}], ",", 
         RowBox[{"y", "*", "l", "*", 
          RowBox[{"stimulusAfter", "[", "x", "]"}]}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{"Agent", " ", "has", " ", "defected"}], "*)"}], 
       "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"stimulusAfter", "[", "x", "]"}], "\[GreaterEqual]", "0"}], 
         ",", 
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{"y", "*", "l", "*", 
            RowBox[{"stimulusAfter", "[", "x", "]"}]}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{"1", "-", "y"}], ")"}]}], "*", "l", "*", 
          RowBox[{"stimulusAfter", "[", "x", "]"}]}]}], "]"}]}], 
      "\[IndentingNewLine]", "]"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"Expected", " ", "change", " ", "in", " ", "the", " ", 
     RowBox[{"probability", " ", "/", " ", "propensity"}], " ", "to", " ", 
     "cooperate"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"expectedChangeX", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"x", "*", 
          RowBox[{"(", 
           RowBox[{"1", "-", "noise"}], ")"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", "x"}], ")"}], "*", "noise"}]}], ")"}], "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"y", "*", 
          RowBox[{"(", 
           RowBox[{"1", "-", "noise"}], ")"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", "y"}], ")"}], "*", "noise"}]}], ")"}], "*", 
       RowBox[{"changeAfterOn", "[", 
        RowBox[{"CC", ",", "x"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"x", "*", 
          RowBox[{"(", 
           RowBox[{"1", "-", "noise"}], ")"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", "x"}], ")"}], "*", "noise"}]}], ")"}], "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", "y"}], ")"}], "*", 
          RowBox[{"(", 
           RowBox[{"1", "-", "noise"}], ")"}]}], "+", 
         RowBox[{"y", "*", "noise"}]}], ")"}], "*", 
       RowBox[{"changeAfterOn", "[", 
        RowBox[{"CD", ",", "x"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", "x"}], ")"}], "*", 
          RowBox[{"(", 
           RowBox[{"1", "-", "noise"}], ")"}]}], "+", 
         RowBox[{"x", "*", "noise"}]}], ")"}], "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"y", "*", 
          RowBox[{"(", 
           RowBox[{"1", "-", "noise"}], ")"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", "y"}], ")"}], "*", "noise"}]}], ")"}], "*", 
       RowBox[{"changeAfterOn", "[", 
        RowBox[{"DC", ",", "x"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", "x"}], ")"}], "*", 
          RowBox[{"(", 
           RowBox[{"1", "-", "noise"}], ")"}]}], "+", 
         RowBox[{"x", "*", "noise"}]}], ")"}], "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", "y"}], ")"}], "*", 
          RowBox[{"(", 
           RowBox[{"1", "-", "noise"}], ")"}]}], "+", 
         RowBox[{"y", "*", "noise"}]}], ")"}], "*", 
       RowBox[{"changeAfterOn", "[", 
        RowBox[{"DD", ",", "x"}], "]"}]}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"expectedChangeY", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], ":=", 
     RowBox[{"expectedChangeX", "[", 
      RowBox[{"y", ",", "x"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"expChangeNorm", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], ":=", 
     RowBox[{"Norm", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"expectedChangeX", "[", 
         RowBox[{"x", ",", "y"}], "]"}], ",", 
        RowBox[{"expectedChangeY", "[", 
         RowBox[{"x", ",", "y"}], "]"}]}], "}"}], "]"}]}], ";"}]}]}]], "Input",\

 CellChangeTimes->{{3.3934068298125*^9, 3.39340683171875*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Expected Movement Phase Plane - Initialisation", "Section"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"expectedMovementArrows", "=", 
   RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"points", "=", 
   RowBox[{"{", "}"}]}], ";"}]}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Expected Movement Phase Plane - Creation", "Section"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"For", "[", 
   RowBox[{
    RowBox[{"x", "=", "0"}], ",", 
    RowBox[{"x", "\[LessEqual]", 
     RowBox[{"1", "+", 
      FractionBox["step", "2"]}]}], ",", 
    RowBox[{"x", "=", 
     RowBox[{"x", "+", "step"}]}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"For", "[", 
      RowBox[{
       RowBox[{"y", "=", "0"}], ",", 
       RowBox[{"y", "\[LessEqual]", 
        RowBox[{"1", "+", 
         FractionBox["step", "2"]}]}], ",", 
       RowBox[{"y", "=", 
        RowBox[{"y", "+", "step"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"v", "=", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"expectedChangeX", "[", 
            RowBox[{"x", ",", "y"}], "]"}], ",", 
           RowBox[{"expectedChangeY", "[", 
            RowBox[{"x", ",", "y"}], "]"}]}], "}"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Norm", "[", "v", "]"}], "\[Equal]", "0"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"AppendTo", "[", 
           RowBox[{"points", ",", 
            RowBox[{"Point", "[", 
             RowBox[{"{", 
              RowBox[{"x", ",", "y"}], "}"}], "]"}]}], "]"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"AppendTo", "[", 
            RowBox[{"expectedMovementArrows", ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Arrowheads", "[", "0.02", "]"}], ",", 
               RowBox[{"Arrow", "[", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{"x", ",", "y"}], "}"}], ",", 
                  RowBox[{
                   RowBox[{"{", 
                    RowBox[{"x", ",", "y"}], "}"}], "+", "v"}]}], "}"}], 
                "]"}]}], "}"}]}], "]"}], ";"}]}], "\[IndentingNewLine]", 
         "]"}], ";"}]}], "\[IndentingNewLine]", "]"}], ";"}]}], 
   "\[IndentingNewLine]", "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"Clear", "[", 
    RowBox[{"x", ",", "y"}], "]"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"expectedMovementArrowsAndPoints", "=", 
   RowBox[{"Append", "[", 
    RowBox[{"expectedMovementArrows", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"PointSize", "[", "0.008`", "]"}], ",", "points"}], "}"}]}], 
    "]"}]}], ";"}], "\n", 
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"Graphics", "[", "expectedMovementArrowsAndPoints", "]"}], ",", 
   RowBox[{"AxesOrigin", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "0.025`"}], ",", 
      RowBox[{"-", "0.025`"}]}], "}"}]}], ",", 
   RowBox[{"Axes", "\[Rule]", "True"}], ",", 
   RowBox[{"AspectRatio", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<Prob C Player1\>\"", ",", "\"\<Prob C Player2\>\""}], 
     "}"}]}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<Expected Change\>\""}]}], 
  "]"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{
  3.392687991390625*^9, {3.39268821234375*^9, 3.392688264265625*^9}, {
   3.39268829559375*^9, 3.392688332421875*^9}, {3.39268840528125*^9, 
   3.392688428734375*^9}, 3.392688468578125*^9, {3.392688559453125*^9, 
   3.39268856296875*^9}, {3.392689613390625*^9, 3.3926896175*^9}, {
   3.39268965665625*^9, 3.392689689515625*^9}, {3.39268977840625*^9, 
   3.392689779171875*^9}, {3.392689820703125*^9, 3.3926898510625*^9}, {
   3.39269538959375*^9, 3.392695394578125*^9}, {3.39275277975*^9, 
   3.392752792140625*^9}, {3.392869590875*^9, 3.39286959703125*^9}}],

Cell[BoxData[
 GraphicsBox[{
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{0, Rational[1, 20]}, {0, Rational[13, 280]}}, {{
       0, 0.05}, {0, 0.04642857142857143}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{0, Rational[1, 10]}, {0, Rational[13, 140]}}, {{
       0, 0.1}, {0, 0.09285714285714286}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{0, Rational[3, 20]}, {0, Rational[39, 280]}}, {{
       0, 0.15}, {0, 0.1392857142857143}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{0, Rational[1, 5]}, {0, Rational[13, 70]}}, {{0, 0.2}, {
       0, 0.18571428571428572`}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{0, Rational[1, 4]}, {0, Rational[13, 56]}}, {{
       0, 0.25}, {0, 0.23214285714285715`}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{0, Rational[3, 10]}, {0, Rational[39, 140]}}, {{
       0, 0.3}, {0, 0.2785714285714286}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{0, Rational[7, 20]}, {0, Rational[13, 40]}}, {{
       0, 0.35}, {0, 0.325}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{0, Rational[2, 5]}, {0, Rational[13, 35]}}, {{0, 0.4}, {
       0, 0.37142857142857144`}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{0, Rational[9, 20]}, {0, Rational[117, 280]}}, {{
       0, 0.45}, {0, 0.41785714285714287`}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{0, Rational[1, 2]}, {0, Rational[13, 28]}}, {{0, 0.5}, {
       0, 0.4642857142857143}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{0, Rational[11, 20]}, {0, Rational[143, 280]}}, {{
       0, 0.55}, {0, 0.5107142857142857}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{0, Rational[3, 5]}, {0, Rational[39, 70]}}, {{0, 0.6}, {
       0, 0.5571428571428572}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{0, Rational[13, 20]}, {0, Rational[169, 280]}}, {{
       0, 0.65}, {0, 0.6035714285714285}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{0, Rational[7, 10]}, {0, Rational[13, 20]}}, {{
       0, 0.7}, {0, 0.65}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{0, Rational[3, 4]}, {0, Rational[39, 56]}}, {{
       0, 0.75}, {0, 0.6964285714285714}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{0, Rational[4, 5]}, {0, Rational[26, 35]}}, {{0, 0.8}, {
       0, 0.7428571428571429}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{0, Rational[17, 20]}, {0, Rational[221, 280]}}, {{
       0, 0.85}, {0, 0.7892857142857143}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{0, Rational[9, 10]}, {0, Rational[117, 140]}}, {{
       0, 0.9}, {0, 0.8357142857142857}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{0, Rational[19, 20]}, {0, Rational[247, 280]}}, {{
       0, 0.95}, {0, 0.8821428571428571}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{0, 1}, {0, Rational[13, 14]}}, {{0, 1}, {
       0, 0.9285714285714286}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 20], 0}, {Rational[13, 280], 0}}, {{
       0.05, 0}, {0.04642857142857143, 0}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 20], Rational[1, 20]}, {
       Rational[2629, 56000], Rational[2629, 56000]}}, {{0.05, 0.05}, {
      0.04694642857142857, 0.04694642857142857}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 20], Rational[1, 10]}, {
       Rational[1329, 28000], Rational[657, 7000]}}, {{0.05, 0.1}, {
      0.047464285714285716`, 0.09385714285714286}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 20], Rational[3, 20]}, {
       Rational[2687, 56000], Rational[7881, 56000]}}, {{0.05, 0.15}, {
      0.047982142857142855`, 0.14073214285714286`}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 20], Rational[1, 5]}, {
       Rational[97, 2000], Rational[1313, 7000]}}, {{0.05, 0.2}, {0.0485, 
      0.18757142857142858`}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 20], Rational[1, 4]}, {
       Rational[549, 11200], Rational[15, 64]}}, {{0.05, 0.25}, {
      0.04901785714285714, 0.234375}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 20], Rational[3, 10]}, {
       Rational[1387, 28000], Rational[246, 875]}}, {{0.05, 0.3}, {
      0.04953571428571429, 0.28114285714285714`}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 20], Rational[7, 20]}, {
       Rational[2803, 56000], Rational[2623, 8000]}}, {{0.05, 0.35}, {
      0.050053571428571426`, 0.327875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 20], Rational[2, 5]}, {
       Rational[177, 3500], Rational[1311, 3500]}}, {{0.05, 0.4}, {
      0.05057142857142857, 0.37457142857142856`}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 20], Rational[9, 20]}, {
       Rational[2861, 56000], Rational[23589, 56000]}}, {{0.05, 0.45}, {
      0.05108928571428571, 0.42123214285714283`}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 20], Rational[1, 2]}, {
       Rational[289, 5600], Rational[131, 280]}}, {{0.05, 0.5}, {
      0.05160714285714286, 0.46785714285714286`}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 20], Rational[11, 20]}, {
       Rational[417, 8000], Rational[28809, 56000]}}, {{0.05, 0.55}, {
      0.052125, 0.5144464285714285}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 20], Rational[3, 5]}, {
       Rational[737, 14000], Rational[561, 1000]}}, {{0.05, 0.6}, {
      0.052642857142857144`, 0.561}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 20], Rational[13, 20]}, {
       Rational[2977, 56000], Rational[34021, 56000]}}, {{0.05, 0.65}, {
      0.05316071428571428, 0.6075178571428571}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 20], Rational[7, 10]}, {
       Rational[1503, 28000], Rational[327, 500]}}, {{0.05, 0.7}, {
      0.05367857142857143, 0.654}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 20], Rational[3, 4]}, {
       Rational[607, 11200], Rational[1569, 2240]}}, {{0.05, 0.75}, {
      0.05419642857142857, 0.7004464285714286}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 20], Rational[4, 5]}, {
       Rational[383, 7000], Rational[1307, 1750]}}, {{0.05, 0.8}, {
      0.054714285714285715`, 0.7468571428571429}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 20], Rational[17, 20]}, {
       Rational[3093, 56000], Rational[44421, 56000]}}, {{0.05, 0.85}, {
      0.055232142857142855`, 0.7932321428571428}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 20], Rational[9, 10]}, {
       Rational[223, 4000], Rational[5877, 7000]}}, {{0.05, 0.9}, {0.05575, 
      0.8395714285714285}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 20], Rational[19, 20]}, {
       Rational[3151, 56000], Rational[7087, 8000]}}, {{0.05, 0.95}, {
      0.05626785714285714, 0.885875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 20], 1}, {
       Rational[159, 2800], Rational[261, 280]}}, {{0.05, 1}, {
       0.05678571428571429, 0.9321428571428572}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 10], 0}, {Rational[13, 140], 0}}, {{
       0.1, 0}, {0.09285714285714286, 0}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 10], Rational[1, 20]}, {
       Rational[657, 7000], Rational[1329, 28000]}}, {{0.1, 0.05}, {
      0.09385714285714286, 0.047464285714285716`}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 10], Rational[1, 10]}, {
       Rational[83, 875], Rational[83, 875]}}, {{0.1, 0.1}, {
      0.09485714285714286, 0.09485714285714286}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 10], Rational[3, 20]}, {
       Rational[671, 7000], Rational[3981, 28000]}}, {{0.1, 0.15}, {
      0.09585714285714286, 0.14217857142857143`}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 10], Rational[1, 5]}, {
       Rational[339, 3500], Rational[663, 3500]}}, {{0.1, 0.2}, {
      0.09685714285714286, 0.18942857142857142`}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 10], Rational[1, 4]}, {
       Rational[137, 1400], Rational[53, 224]}}, {{0.1, 0.25}, {
      0.09785714285714285, 0.23660714285714285`}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 10], Rational[3, 10]}, {
       Rational[173, 1750], Rational[993, 3500]}}, {{0.1, 0.3}, {
      0.09885714285714285, 0.2837142857142857}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 10], Rational[7, 20]}, {
       Rational[699, 7000], Rational[1323, 4000]}}, {{0.1, 0.35}, {
      0.09985714285714285, 0.33075}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 10], Rational[2, 5]}, {
       Rational[353, 3500], Rational[661, 1750]}}, {{0.1, 0.4}, {
      0.10085714285714285`, 0.3777142857142857}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 10], Rational[9, 20]}, {
       Rational[713, 7000], Rational[11889, 28000]}}, {{0.1, 0.45}, {
      0.10185714285714285`, 0.42460714285714285`}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 10], Rational[1, 2]}, {
       Rational[18, 175], Rational[33, 70]}}, {{0.1, 0.5}, {
      0.10285714285714286`, 0.4714285714285714}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 10], Rational[11, 20]}, {
       Rational[727, 7000], Rational[14509, 28000]}}, {{0.1, 0.55}, {
      0.10385714285714286`, 0.5181785714285714}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 10], Rational[3, 5]}, {
       Rational[367, 3500], Rational[1977, 3500]}}, {{0.1, 0.6}, {
      0.10485714285714286`, 0.5648571428571428}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 10], Rational[13, 20]}, {
       Rational[741, 7000], Rational[17121, 28000]}}, {{0.1, 0.65}, {
      0.10585714285714286`, 0.6114642857142857}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 10], Rational[7, 10]}, {
       Rational[187, 1750], Rational[329, 500]}}, {{0.1, 0.7}, {
      0.10685714285714286`, 0.658}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 10], Rational[3, 4]}, {
       Rational[151, 1400], Rational[789, 1120]}}, {{0.1, 0.75}, {
      0.10785714285714286`, 0.7044642857142858}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 10], Rational[4, 5]}, {
       Rational[381, 3500], Rational[657, 875]}}, {{0.1, 0.8}, {
      0.10885714285714286`, 0.7508571428571429}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 10], Rational[17, 20]}, {
       Rational[769, 7000], Rational[22321, 28000]}}, {{0.1, 0.85}, {
      0.10985714285714286`, 0.7971785714285714}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 10], Rational[9, 10]}, {
       Rational[97, 875], Rational[738, 875]}}, {{0.1, 0.9}, {
      0.11085714285714286`, 0.8434285714285714}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 10], Rational[19, 20]}, {
       Rational[783, 7000], Rational[24909, 28000]}}, {{0.1, 0.95}, {
      0.11185714285714286`, 0.8896071428571428}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 10], 1}, {
       Rational[79, 700], Rational[131, 140]}}, {{0.1, 1}, {
       0.11285714285714285`, 0.9357142857142857}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 20], 0}, {Rational[39, 280], 0}}, {{
       0.15, 0}, {0.1392857142857143, 0}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 20], Rational[1, 20]}, {
       Rational[7881, 56000], Rational[2687, 56000]}}, {{0.15, 0.05}, {
      0.14073214285714286`, 0.047982142857142855`}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 20], Rational[1, 10]}, {
       Rational[3981, 28000], Rational[671, 7000]}}, {{0.15, 0.1}, {
      0.14217857142857143`, 0.09585714285714286}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 20], Rational[3, 20]}, {
       Rational[1149, 8000], Rational[1149, 8000]}}, {{0.15, 0.15}, {0.143625,
       0.143625}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 20], Rational[1, 5]}, {
       Rational[2031, 14000], Rational[1339, 7000]}}, {{0.15, 0.2}, {
      0.14507142857142857`, 0.19128571428571428`}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 20], Rational[1, 4]}, {
       Rational[1641, 11200], Rational[107, 448]}}, {{0.15, 0.25}, {
      0.14651785714285714`, 0.23883928571428573`}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 20], Rational[3, 10]}, {
       Rational[4143, 28000], Rational[501, 1750]}}, {{0.15, 0.3}, {
      0.14796428571428571`, 0.2862857142857143}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 20], Rational[7, 20]}, {
       Rational[8367, 56000], Rational[2669, 8000]}}, {{0.15, 0.35}, {
      0.14941071428571429`, 0.333625}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 20], Rational[2, 5]}, {
       Rational[132, 875], Rational[1333, 3500]}}, {{0.15, 0.4}, {
      0.15085714285714286`, 0.38085714285714284`}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 20], Rational[9, 20]}, {
       Rational[8529, 56000], Rational[23967, 56000]}}, {{0.15, 0.45}, {
      0.15230357142857143`, 0.42798214285714287`}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 20], Rational[1, 2]}, {
       Rational[123, 800], Rational[19, 40]}}, {{0.15, 0.5}, {0.15375, 
      0.475}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 20], Rational[11, 20]}, {
       Rational[8691, 56000], Rational[29227, 56000]}}, {{0.15, 0.55}, {
      0.15519642857142857`, 0.5219107142857143}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 20], Rational[3, 5]}, {
       Rational[2193, 14000], Rational[3981, 7000]}}, {{0.15, 0.6}, {
      0.15664285714285714`, 0.5687142857142857}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 20], Rational[13, 20]}, {
       Rational[8853, 56000], Rational[34463, 56000]}}, {{0.15, 0.65}, {
      0.1580892857142857, 0.6154107142857143}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 20], Rational[7, 10]}, {
       Rational[4467, 28000], Rational[331, 500]}}, {{0.15, 0.7}, {
      0.15953571428571428`, 0.662}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 20], Rational[3, 4]}, {
       Rational[1803, 11200], Rational[1587, 2240]}}, {{0.15, 0.75}, {
      0.16098214285714285`, 0.7084821428571428}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 20], Rational[4, 5]}, {
       Rational[1137, 7000], Rational[1321, 1750]}}, {{0.15, 0.8}, {
      0.16242857142857142`, 0.7548571428571429}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 20], Rational[17, 20]}, {
       Rational[1311, 8000], Rational[6409, 8000]}}, {{0.15, 0.85}, {0.163875,
       0.801125}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 20], Rational[9, 10]}, {
       Rational[4629, 28000], Rational[5931, 7000]}}, {{0.15, 0.9}, {
      0.16532142857142856`, 0.8472857142857143}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 20], Rational[19, 20]}, {
       Rational[9339, 56000], Rational[50027, 56000]}}, {{0.15, 0.95}, {
      0.16676785714285713`, 0.8933392857142857}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 20], 1}, {
       Rational[471, 2800], Rational[263, 280]}}, {{0.15, 1}, {
       0.1682142857142857, 0.9392857142857143}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 5], 0}, {Rational[13, 70], 0}}, {{0.2, 0}, {
       0.18571428571428572`, 0}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 5], Rational[1, 20]}, {
       Rational[1313, 7000], Rational[97, 2000]}}, {{0.2, 0.05}, {
      0.18757142857142858`, 0.0485}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 5], Rational[1, 10]}, {
       Rational[663, 3500], Rational[339, 3500]}}, {{0.2, 0.1}, {
      0.18942857142857142`, 0.09685714285714286}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 5], Rational[3, 20]}, {
       Rational[1339, 7000], Rational[2031, 14000]}}, {{0.2, 0.15}, {
      0.19128571428571428`, 0.14507142857142857`}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 5], Rational[1, 5]}, {
       Rational[169, 875], Rational[169, 875]}}, {{0.2, 0.2}, {
      0.19314285714285714`, 0.19314285714285714`}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 5], Rational[1, 4]}, {
       Rational[39, 200], Rational[27, 112]}}, {{0.2, 0.25}, {0.195, 
      0.24107142857142858`}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 5], Rational[3, 10]}, {
       Rational[689, 3500], Rational[1011, 3500]}}, {{0.2, 0.3}, {
      0.19685714285714287`, 0.28885714285714287`}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[
     NCache[{{Rational[1, 5], Rational[7, 20]}, {
       Rational[1391, 7000], Rational[673, 2000]}}, {{0.2, 0.35}, {
      0.1987142857142857, 0.3365}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 5], Rational[2, 5]}, {
       Rational[351, 1750], Rational[48, 125]}}, {{0.2, 0.4}, {
      0.20057142857142857`, 0.384}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 5], Rational[9, 20]}, {
       Rational[1417, 7000], Rational[6039, 14000]}}, {{0.2, 0.45}, {
      0.20242857142857143`, 0.4313571428571429}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 5], Rational[1, 2]}, {
       Rational[143, 700], Rational[67, 140]}}, {{0.2, 0.5}, {
      0.2042857142857143, 0.4785714285714286}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 5], Rational[11, 20]}, {
       Rational[1443, 7000], Rational[7359, 14000]}}, {{0.2, 0.55}, {
      0.20614285714285716`, 0.5256428571428572}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 5], Rational[3, 5]}, {
       Rational[26, 125], Rational[501, 875]}}, {{0.2, 0.6}, {0.208, 
      0.5725714285714286}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 5], Rational[13, 20]}, {
       Rational[1469, 7000], Rational[8671, 14000]}}, {{0.2, 0.65}, {
      0.20985714285714285`, 0.6193571428571428}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 5], Rational[7, 10]}, {
       Rational[741, 3500], Rational[333, 500]}}, {{0.2, 0.7}, {
      0.21171428571428572`, 0.666}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 5], Rational[3, 4]}, {
       Rational[299, 1400], Rational[57, 80]}}, {{0.2, 0.75}, {
      0.21357142857142858`, 0.7125}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 5], Rational[4, 5]}, {
       Rational[377, 1750], Rational[664, 875]}}, {{0.2, 0.8}, {
      0.21542857142857144`, 0.7588571428571429}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 5], Rational[17, 20]}, {
       Rational[1521, 7000], Rational[11271, 14000]}}, {{0.2, 0.85}, {
      0.21728571428571428`, 0.8050714285714285}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 5], Rational[9, 10]}, {
       Rational[767, 3500], Rational[2979, 3500]}}, {{0.2, 0.9}, {
      0.21914285714285714`, 0.8511428571428571}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 5], Rational[19, 20]}, {
       Rational[221, 1000], Rational[12559, 14000]}}, {{0.2, 0.95}, {0.221, 
      0.8970714285714285}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 5], 1}, {
       Rational[39, 175], Rational[33, 35]}}, {{0.2, 1}, {
       0.22285714285714286`, 0.9428571428571428}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 4], 0}, {Rational[13, 56], 0}}, {{
       0.25, 0}, {0.23214285714285715`, 0}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 4], Rational[1, 20]}, {
       Rational[15, 64], Rational[549, 11200]}}, {{0.25, 0.05}, {0.234375, 
      0.04901785714285714}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 4], Rational[1, 10]}, {
       Rational[53, 224], Rational[137, 1400]}}, {{0.25, 0.1}, {
      0.23660714285714285`, 0.09785714285714285}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 4], Rational[3, 20]}, {
       Rational[107, 448], Rational[1641, 11200]}}, {{0.25, 0.15}, {
      0.23883928571428573`, 0.14651785714285714`}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 4], Rational[1, 5]}, {
       Rational[27, 112], Rational[39, 200]}}, {{0.25, 0.2}, {
      0.24107142857142858`, 0.195}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 4], Rational[1, 4]}, {
       Rational[109, 448], Rational[109, 448]}}, {{0.25, 0.25}, {
      0.24330357142857142`, 0.24330357142857142`}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 4], Rational[3, 10]}, {
       Rational[55, 224], Rational[51, 175]}}, {{0.25, 0.3}, {
      0.24553571428571427`, 0.2914285714285714}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 4], Rational[7, 20]}, {
       Rational[111, 448], Rational[543, 1600]}}, {{0.25, 0.35}, {
      0.24776785714285715`, 0.339375}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 4], Rational[2, 5]}, {
       Rational[1, 4], Rational[271, 700]}}, {{0.25, 0.4}, {0.25, 
      0.3871428571428571}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 4], Rational[9, 20]}, {
       Rational[113, 448], Rational[4869, 11200]}}, {{0.25, 0.45}, {
      0.25223214285714285`, 0.43473214285714284`}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 4], Rational[1, 2]}, {
       Rational[57, 224], Rational[27, 56]}}, {{0.25, 0.5}, {
      0.2544642857142857, 0.48214285714285715`}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 4], Rational[11, 20]}, {
       Rational[115, 448], Rational[847, 1600]}}, {{0.25, 0.55}, {
      0.25669642857142855`, 0.529375}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 4], Rational[3, 5]}, {
       Rational[29, 112], Rational[807, 1400]}}, {{0.25, 0.6}, {
      0.25892857142857145`, 0.5764285714285714}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 4], Rational[13, 20]}, {
       Rational[117, 448], Rational[6981, 11200]}}, {{0.25, 0.65}, {
      0.2611607142857143, 0.6233035714285714}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 4], Rational[7, 10]}, {
       Rational[59, 224], Rational[67, 100]}}, {{0.25, 0.7}, {
      0.26339285714285715`, 0.67}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 4], Rational[3, 4]}, {
       Rational[17, 64], Rational[321, 448]}}, {{0.25, 0.75}, {0.265625, 
      0.7165178571428571}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 4], Rational[4, 5]}, {
       Rational[15, 56], Rational[267, 350]}}, {{0.25, 0.8}, {
      0.26785714285714285`, 0.7628571428571429}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 4], Rational[17, 20]}, {
       Rational[121, 448], Rational[9061, 11200]}}, {{0.25, 0.85}, {
      0.2700892857142857, 0.8090178571428571}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 4], Rational[9, 10]}, {
       Rational[61, 224], Rational[171, 200]}}, {{0.25, 0.9}, {
      0.27232142857142855`, 0.855}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 4], Rational[19, 20]}, {
       Rational[123, 448], Rational[10089, 11200]}}, {{0.25, 0.95}, {
      0.27455357142857145`, 0.9008035714285715}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 4], 1}, {
       Rational[31, 112], Rational[53, 56]}}, {{0.25, 1}, {0.2767857142857143,
        0.9464285714285714}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 10], 0}, {Rational[39, 140], 0}}, {{
       0.3, 0}, {0.2785714285714286, 0}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 10], Rational[1, 20]}, {
       Rational[246, 875], Rational[1387, 28000]}}, {{0.3, 0.05}, {
      0.28114285714285714`, 0.04953571428571429}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 10], Rational[1, 10]}, {
       Rational[993, 3500], Rational[173, 1750]}}, {{0.3, 0.1}, {
      0.2837142857142857, 0.09885714285714285}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 10], Rational[3, 20]}, {
       Rational[501, 1750], Rational[4143, 28000]}}, {{0.3, 0.15}, {
      0.2862857142857143, 0.14796428571428571`}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 10], Rational[1, 5]}, {
       Rational[1011, 3500], Rational[689, 3500]}}, {{0.3, 0.2}, {
      0.28885714285714287`, 0.19685714285714287`}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 10], Rational[1, 4]}, {
       Rational[51, 175], Rational[55, 224]}}, {{0.3, 0.25}, {
      0.2914285714285714, 0.24553571428571427`}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 10], Rational[3, 10]}, {
       Rational[147, 500], Rational[147, 500]}}, {{0.3, 0.3}, {0.294, 
      0.294}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 10], Rational[7, 20]}, {
       Rational[519, 1750], Rational[1369, 4000]}}, {{0.3, 0.35}, {
      0.2965714285714286, 0.34225}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 10], Rational[2, 5]}, {
       Rational[1047, 3500], Rational[683, 1750]}}, {{0.3, 0.4}, {
      0.29914285714285715`, 0.3902857142857143}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 10], Rational[9, 20]}, {
       Rational[264, 875], Rational[12267, 28000]}}, {{0.3, 0.45}, {
      0.3017142857142857, 0.43810714285714286`}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 10], Rational[1, 2]}, {
       Rational[213, 700], Rational[17, 35]}}, {{0.3, 0.5}, {
      0.30428571428571427`, 0.4857142857142857}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 10], Rational[11, 20]}, {
       Rational[537, 1750], Rational[14927, 28000]}}, {{0.3, 0.55}, {
      0.3068571428571429, 0.5331071428571429}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 10], Rational[3, 5]}, {
       Rational[1083, 3500], Rational[2031, 3500]}}, {{0.3, 0.6}, {
      0.30942857142857144`, 0.5802857142857143}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 10], Rational[13, 20]}, {
       Rational[39, 125], Rational[2509, 4000]}}, {{0.3, 0.65}, {0.312, 
      0.62725}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 10], Rational[7, 10]}, {
       Rational[1101, 3500], Rational[337, 500]}}, {{0.3, 0.7}, {
      0.31457142857142856`, 0.674}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 10], Rational[3, 4]}, {
       Rational[111, 350], Rational[807, 1120]}}, {{0.3, 0.75}, {
      0.3171428571428571, 0.7205357142857143}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 10], Rational[4, 5]}, {
       Rational[1119, 3500], Rational[671, 875]}}, {{0.3, 0.8}, {
      0.31971428571428573`, 0.7668571428571429}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 10], Rational[17, 20]}, {
       Rational[282, 875], Rational[22763, 28000]}}, {{0.3, 0.85}, {
      0.3222857142857143, 0.8129642857142857}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 10], Rational[9, 10]}, {
       Rational[1137, 3500], Rational[1503, 1750]}}, {{0.3, 0.9}, {
      0.32485714285714284`, 0.8588571428571429}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 10], Rational[19, 20]}, {
       Rational[573, 1750], Rational[25327, 28000]}}, {{0.3, 0.95}, {
      0.3274285714285714, 0.9045357142857143}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 10], 1}, {
       Rational[33, 100], Rational[19, 20]}}, {{0.3, 1}, {0.33, 0.95}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[7, 20], 0}, {Rational[13, 40], 0}}, {{
       0.35, 0}, {0.325, 0}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[7, 20], Rational[1, 20]}, {
       Rational[2623, 8000], Rational[2803, 56000]}}, {{0.35, 0.05}, {
      0.327875, 0.050053571428571426`}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[7, 20], Rational[1, 10]}, {
       Rational[1323, 4000], Rational[699, 7000]}}, {{0.35, 0.1}, {0.33075, 
      0.09985714285714285}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[7, 20], Rational[3, 20]}, {
       Rational[2669, 8000], Rational[8367, 56000]}}, {{0.35, 0.15}, {
      0.333625, 0.14941071428571429`}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[7, 20], Rational[1, 5]}, {
       Rational[673, 2000], Rational[1391, 7000]}}, {{0.35, 0.2}, {0.3365, 
      0.1987142857142857}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[7, 20], Rational[1, 4]}, {
       Rational[543, 1600], Rational[111, 448]}}, {{0.35, 0.25}, {0.339375, 
      0.24776785714285715`}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[7, 20], Rational[3, 10]}, {
       Rational[1369, 4000], Rational[519, 1750]}}, {{0.35, 0.3}, {0.34225, 
      0.2965714285714286}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[7, 20], Rational[7, 20]}, {
       Rational[2761, 8000], Rational[2761, 8000]}}, {{0.35, 0.35}, {0.345125,
       0.345125}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[7, 20], Rational[2, 5]}, {
       Rational[87, 250], Rational[1377, 3500]}}, {{0.35, 0.4}, {0.348, 
      0.3934285714285714}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[7, 20], Rational[9, 20]}, {
       Rational[2807, 8000], Rational[24723, 56000]}}, {{0.35, 0.45}, {
      0.350875, 0.4414821428571429}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[7, 20], Rational[1, 2]}, {
       Rational[283, 800], Rational[137, 280]}}, {{0.35, 0.5}, {0.35375, 
      0.48928571428571427`}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[7, 20], Rational[11, 20]}, {
       Rational[2853, 8000], Rational[30063, 56000]}}, {{0.35, 0.55}, {
      0.356625, 0.5368392857142857}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[7, 20], Rational[3, 5]}, {
       Rational[719, 2000], Rational[4089, 7000]}}, {{0.35, 0.6}, {0.3595, 
      0.5841428571428572}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[7, 20], Rational[13, 20]}, {
       Rational[2899, 8000], Rational[35347, 56000]}}, {{0.35, 0.65}, {
      0.362375, 0.6311964285714285}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[7, 20], Rational[7, 10]}, {
       Rational[1461, 4000], Rational[339, 500]}}, {{0.35, 0.7}, {0.36525, 
      0.678}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[7, 20], Rational[3, 4]}, {
       Rational[589, 1600], Rational[1623, 2240]}}, {{0.35, 0.75}, {0.368125, 
      0.7245535714285715}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[7, 20], Rational[4, 5]}, {
       Rational[371, 1000], Rational[1349, 1750]}}, {{0.35, 0.8}, {0.371, 
      0.7708571428571429}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[7, 20], Rational[17, 20]}, {
       Rational[2991, 8000], Rational[45747, 56000]}}, {{0.35, 0.85}, {
      0.373875, 0.8169107142857143}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[7, 20], Rational[9, 10]}, {
       Rational[1507, 4000], Rational[6039, 7000]}}, {{0.35, 0.9}, {0.37675, 
      0.8627142857142858}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[7, 20], Rational[19, 20]}, {
       Rational[3037, 8000], Rational[50863, 56000]}}, {{0.35, 0.95}, {
      0.379625, 0.9082678571428572}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[7, 20], 1}, {
       Rational[153, 400], Rational[267, 280]}}, {{0.35, 1}, {0.3825, 
       0.9535714285714286}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[2, 5], 0}, {Rational[13, 35], 0}}, {{0.4, 0}, {
       0.37142857142857144`, 0}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[2, 5], Rational[1, 20]}, {
       Rational[1311, 3500], Rational[177, 3500]}}, {{0.4, 0.05}, {
      0.37457142857142856`, 0.05057142857142857}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[2, 5], Rational[1, 10]}, {
       Rational[661, 1750], Rational[353, 3500]}}, {{0.4, 0.1}, {
      0.3777142857142857, 0.10085714285714285`}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[2, 5], Rational[3, 20]}, {
       Rational[1333, 3500], Rational[132, 875]}}, {{0.4, 0.15}, {
      0.38085714285714284`, 0.15085714285714286`}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[2, 5], Rational[1, 5]}, {
       Rational[48, 125], Rational[351, 1750]}}, {{0.4, 0.2}, {0.384, 
      0.20057142857142857`}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[2, 5], Rational[1, 4]}, {
       Rational[271, 700], Rational[1, 4]}}, {{0.4, 0.25}, {
      0.3871428571428571, 0.25}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[2, 5], Rational[3, 10]}, {
       Rational[683, 1750], Rational[1047, 3500]}}, {{0.4, 0.3}, {
      0.3902857142857143, 0.29914285714285715`}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[2, 5], Rational[7, 20]}, {
       Rational[1377, 3500], Rational[87, 250]}}, {{0.4, 0.35}, {
      0.3934285714285714, 0.348}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[2, 5], Rational[2, 5]}, {
       Rational[347, 875], Rational[347, 875]}}, {{0.4, 0.4}, {
      0.3965714285714286, 0.3965714285714286}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[2, 5], Rational[9, 20]}, {
       Rational[1399, 3500], Rational[1557, 3500]}}, {{0.4, 0.45}, {
      0.3997142857142857, 0.44485714285714284`}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[2, 5], Rational[1, 2]}, {
       Rational[141, 350], Rational[69, 140]}}, {{0.4, 0.5}, {
      0.40285714285714286`, 0.4928571428571429}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[2, 5], Rational[11, 20]}, {
       Rational[203, 500], Rational[473, 875]}}, {{0.4, 0.55}, {0.406, 
      0.5405714285714286}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[2, 5], Rational[3, 5]}, {
       Rational[358, 875], Rational[147, 250]}}, {{0.4, 0.6}, {
      0.40914285714285714`, 0.588}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[2, 5], Rational[13, 20]}, {
       Rational[1443, 3500], Rational[2223, 3500]}}, {{0.4, 0.65}, {
      0.4122857142857143, 0.6351428571428571}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[2, 5], Rational[7, 10]}, {
       Rational[727, 1750], Rational[341, 500]}}, {{0.4, 0.7}, {
      0.4154285714285714, 0.682}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[2, 5], Rational[3, 4]}, {
       Rational[293, 700], Rational[51, 70]}}, {{0.4, 0.75}, {
      0.4185714285714286, 0.7285714285714285}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[2, 5], Rational[4, 5]}, {
       Rational[369, 875], Rational[678, 875]}}, {{0.4, 0.8}, {
      0.4217142857142857, 0.7748571428571429}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[2, 5], Rational[17, 20]}, {
       Rational[1487, 3500], Rational[2873, 3500]}}, {{0.4, 0.85}, {
      0.4248571428571429, 0.8208571428571428}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[2, 5], Rational[9, 10]}, {
       Rational[107, 250], Rational[3033, 3500]}}, {{0.4, 0.9}, {0.428, 
      0.8665714285714285}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[2, 5], Rational[19, 20]}, {
       Rational[1509, 3500], Rational[114, 125]}}, {{0.4, 0.95}, {
      0.43114285714285716`, 0.912}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[2, 5], 1}, {
       Rational[76, 175], Rational[67, 70]}}, {{0.4, 1}, {0.4342857142857143, 
       0.9571428571428572}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[9, 20], 0}, {Rational[117, 280], 0}}, {{
       0.45, 0}, {0.41785714285714287`, 0}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[9, 20], Rational[1, 20]}, {
       Rational[23589, 56000], Rational[2861, 56000]}}, {{0.45, 0.05}, {
      0.42123214285714283`, 0.05108928571428571}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[9, 20], Rational[1, 10]}, {
       Rational[11889, 28000], Rational[713, 7000]}}, {{0.45, 0.1}, {
      0.42460714285714285`, 0.10185714285714285`}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[9, 20], Rational[3, 20]}, {
       Rational[23967, 56000], Rational[8529, 56000]}}, {{0.45, 0.15}, {
      0.42798214285714287`, 0.15230357142857143`}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[9, 20], Rational[1, 5]}, {
       Rational[6039, 14000], Rational[1417, 7000]}}, {{0.45, 0.2}, {
      0.4313571428571429, 0.20242857142857143`}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[9, 20], Rational[1, 4]}, {
       Rational[4869, 11200], Rational[113, 448]}}, {{0.45, 0.25}, {
      0.43473214285714284`, 0.25223214285714285`}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[9, 20], Rational[3, 10]}, {
       Rational[12267, 28000], Rational[264, 875]}}, {{0.45, 0.3}, {
      0.43810714285714286`, 0.3017142857142857}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[9, 20], Rational[7, 20]}, {
       Rational[24723, 56000], Rational[2807, 8000]}}, {{0.45, 0.35}, {
      0.4414821428571429, 0.350875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[9, 20], Rational[2, 5]}, {
       Rational[1557, 3500], Rational[1399, 3500]}}, {{0.45, 0.4}, {
      0.44485714285714284`, 0.3997142857142857}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[9, 20], Rational[9, 20]}, {
       Rational[25101, 56000], Rational[25101, 56000]}}, {{0.45, 0.45}, {
      0.44823214285714286`, 0.44823214285714286`}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[9, 20], Rational[1, 2]}, {
       Rational[2529, 5600], Rational[139, 280]}}, {{0.45, 0.5}, {
      0.4516071428571429, 0.49642857142857144`}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[9, 20], Rational[11, 20]}, {
       Rational[25479, 56000], Rational[30481, 56000]}}, {{0.45, 0.55}, {
      0.45498214285714284`, 0.5443035714285714}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[9, 20], Rational[3, 5]}, {
       Rational[6417, 14000], Rational[4143, 7000]}}, {{0.45, 0.6}, {
      0.45835714285714285`, 0.5918571428571429}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[9, 20], Rational[13, 20]}, {
       Rational[25857, 56000], Rational[35789, 56000]}}, {{0.45, 0.65}, {
      0.46173214285714287`, 0.6390892857142857}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[9, 20], Rational[7, 10]}, {
       Rational[13023, 28000], Rational[343, 500]}}, {{0.45, 0.7}, {
      0.46510714285714283`, 0.686}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[9, 20], Rational[3, 4]}, {
       Rational[5247, 11200], Rational[1641, 2240]}}, {{0.45, 0.75}, {
      0.46848214285714285`, 0.7325892857142857}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[9, 20], Rational[4, 5]}, {
       Rational[3303, 7000], Rational[1363, 1750]}}, {{0.45, 0.8}, {
      0.47185714285714286`, 0.7788571428571428}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[9, 20], Rational[17, 20]}, {
       Rational[26613, 56000], Rational[46189, 56000]}}, {{0.45, 0.85}, {
      0.4752321428571429, 0.8248035714285714}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[9, 20], Rational[9, 10]}, {
       Rational[13401, 28000], Rational[6093, 7000]}}, {{0.45, 0.9}, {
      0.47860714285714284`, 0.8704285714285714}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[9, 20], Rational[19, 20]}, {
       Rational[26991, 56000], Rational[51281, 56000]}}, {{0.45, 0.95}, {
      0.48198214285714286`, 0.9157321428571429}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[9, 20], 1}, {
       Rational[1359, 2800], Rational[269, 280]}}, {{0.45, 1}, {
       0.4853571428571429, 0.9607142857142857}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 2], 0}, {Rational[13, 28], 0}}, {{0.5, 0}, {
       0.4642857142857143, 0}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 2], Rational[1, 20]}, {
       Rational[131, 280], Rational[289, 5600]}}, {{0.5, 0.05}, {
      0.46785714285714286`, 0.05160714285714286}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 2], Rational[1, 10]}, {
       Rational[33, 70], Rational[18, 175]}}, {{0.5, 0.1}, {
      0.4714285714285714, 0.10285714285714286`}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 2], Rational[3, 20]}, {
       Rational[19, 40], Rational[123, 800]}}, {{0.5, 0.15}, {0.475, 
      0.15375}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 2], Rational[1, 5]}, {
       Rational[67, 140], Rational[143, 700]}}, {{0.5, 0.2}, {
      0.4785714285714286, 0.2042857142857143}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 2], Rational[1, 4]}, {
       Rational[27, 56], Rational[57, 224]}}, {{0.5, 0.25}, {
      0.48214285714285715`, 0.2544642857142857}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 2], Rational[3, 10]}, {
       Rational[17, 35], Rational[213, 700]}}, {{0.5, 0.3}, {
      0.4857142857142857, 0.30428571428571427`}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 2], Rational[7, 20]}, {
       Rational[137, 280], Rational[283, 800]}}, {{0.5, 0.35}, {
      0.48928571428571427`, 0.35375}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 2], Rational[2, 5]}, {
       Rational[69, 140], Rational[141, 350]}}, {{0.5, 0.4}, {
      0.4928571428571429, 0.40285714285714286`}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 2], Rational[9, 20]}, {
       Rational[139, 280], Rational[2529, 5600]}}, {{0.5, 0.45}, {
      0.49642857142857144`, 0.4516071428571429}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 2], Rational[11, 20]}, {
       Rational[141, 280], Rational[3069, 5600]}}, {{0.5, 0.55}, {
      0.5035714285714286, 0.5480357142857143}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 2], Rational[3, 5]}, {
       Rational[71, 140], Rational[417, 700]}}, {{0.5, 0.6}, {
      0.5071428571428571, 0.5957142857142858}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 2], Rational[13, 20]}, {
       Rational[143, 280], Rational[3601, 5600]}}, {{0.5, 0.65}, {
      0.5107142857142857, 0.6430357142857143}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 2], Rational[7, 10]}, {
       Rational[18, 35], Rational[69, 100]}}, {{0.5, 0.7}, {
      0.5142857142857142, 0.69}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 2], Rational[3, 4]}, {
       Rational[29, 56], Rational[165, 224]}}, {{0.5, 0.75}, {
      0.5178571428571429, 0.7366071428571429}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 2], Rational[4, 5]}, {
       Rational[73, 140], Rational[137, 175]}}, {{0.5, 0.8}, {
      0.5214285714285715, 0.7828571428571428}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 2], Rational[17, 20]}, {
       Rational[21, 40], Rational[663, 800]}}, {{0.5, 0.85}, {0.525, 
      0.82875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 2], Rational[9, 10]}, {
       Rational[37, 70], Rational[153, 175]}}, {{0.5, 0.9}, {
      0.5285714285714286, 0.8742857142857143}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 2], Rational[19, 20]}, {
       Rational[149, 280], Rational[5149, 5600]}}, {{0.5, 0.95}, {
      0.5321428571428571, 0.9194642857142857}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 2], 1}, {
       Rational[15, 28], Rational[27, 28]}}, {{0.5, 1}, {0.5357142857142857, 
       0.9642857142857143}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[11, 20], 0}, {Rational[143, 280], 0}}, {{
       0.55, 0}, {0.5107142857142857, 0}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[11, 20], Rational[1, 20]}, {
       Rational[28809, 56000], Rational[417, 8000]}}, {{0.55, 0.05}, {
      0.5144464285714285, 0.052125}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[11, 20], Rational[1, 10]}, {
       Rational[14509, 28000], Rational[727, 7000]}}, {{0.55, 0.1}, {
      0.5181785714285714, 0.10385714285714286`}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[11, 20], Rational[3, 20]}, {
       Rational[29227, 56000], Rational[8691, 56000]}}, {{0.55, 0.15}, {
      0.5219107142857143, 0.15519642857142857`}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[11, 20], Rational[1, 5]}, {
       Rational[7359, 14000], Rational[1443, 7000]}}, {{0.55, 0.2}, {
      0.5256428571428572, 0.20614285714285716`}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[11, 20], Rational[1, 4]}, {
       Rational[847, 1600], Rational[115, 448]}}, {{0.55, 0.25}, {0.529375, 
      0.25669642857142855`}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[11, 20], Rational[3, 10]}, {
       Rational[14927, 28000], Rational[537, 1750]}}, {{0.55, 0.3}, {
      0.5331071428571429, 0.3068571428571429}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[11, 20], Rational[7, 20]}, {
       Rational[30063, 56000], Rational[2853, 8000]}}, {{0.55, 0.35}, {
      0.5368392857142857, 0.356625}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[11, 20], Rational[2, 5]}, {
       Rational[473, 875], Rational[203, 500]}}, {{0.55, 0.4}, {
      0.5405714285714286, 0.406}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[11, 20], Rational[9, 20]}, {
       Rational[30481, 56000], Rational[25479, 56000]}}, {{0.55, 0.45}, {
      0.5443035714285714, 0.45498214285714284`}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[11, 20], Rational[1, 2]}, {
       Rational[3069, 5600], Rational[141, 280]}}, {{0.55, 0.5}, {
      0.5480357142857143, 0.5035714285714286}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[11, 20], Rational[11, 20]}, {
       Rational[30899, 56000], Rational[30899, 56000]}}, {{0.55, 0.55}, {
      0.5517678571428571, 0.5517678571428571}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[11, 20], Rational[3, 5]}, {
       Rational[1111, 2000], Rational[4197, 7000]}}, {{0.55, 0.6}, {0.5555, 
      0.5995714285714285}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[11, 20], Rational[13, 20]}, {
       Rational[31317, 56000], Rational[36231, 56000]}}, {{0.55, 0.65}, {
      0.5592321428571428, 0.6469821428571428}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[11, 20], Rational[7, 10]}, {
       Rational[15763, 28000], Rational[347, 500]}}, {{0.55, 0.7}, {
      0.5629642857142857, 0.694}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[11, 20], Rational[3, 4]}, {
       Rational[6347, 11200], Rational[237, 320]}}, {{0.55, 0.75}, {
      0.5666964285714285, 0.740625}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[11, 20], Rational[4, 5]}, {
       Rational[3993, 7000], Rational[1377, 1750]}}, {{0.55, 0.8}, {
      0.5704285714285714, 0.7868571428571428}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[11, 20], Rational[17, 20]}, {
       Rational[32153, 56000], Rational[46631, 56000]}}, {{0.55, 0.85}, {
      0.5741607142857142, 0.8326964285714286}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[11, 20], Rational[9, 10]}, {
       Rational[16181, 28000], Rational[6147, 7000]}}, {{0.55, 0.9}, {
      0.5778928571428571, 0.8781428571428571}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[11, 20], Rational[19, 20]}, {
       Rational[4653, 8000], Rational[51699, 56000]}}, {{0.55, 0.95}, {
      0.581625, 0.9231964285714286}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[11, 20], 1}, {
       Rational[1639, 2800], Rational[271, 280]}}, {{0.55, 1}, {
       0.5853571428571429, 0.9678571428571429}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 5], 0}, {Rational[39, 70], 0}}, {{0.6, 0}, {
       0.5571428571428572, 0}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 5], Rational[1, 20]}, {
       Rational[561, 1000], Rational[737, 14000]}}, {{0.6, 0.05}, {0.561, 
      0.052642857142857144`}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 5], Rational[1, 10]}, {
       Rational[1977, 3500], Rational[367, 3500]}}, {{0.6, 0.1}, {
      0.5648571428571428, 0.10485714285714286`}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 5], Rational[3, 20]}, {
       Rational[3981, 7000], Rational[2193, 14000]}}, {{0.6, 0.15}, {
      0.5687142857142857, 0.15664285714285714`}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 5], Rational[1, 5]}, {
       Rational[501, 875], Rational[26, 125]}}, {{0.6, 0.2}, {
      0.5725714285714286, 0.208}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 5], Rational[1, 4]}, {
       Rational[807, 1400], Rational[29, 112]}}, {{0.6, 0.25}, {
      0.5764285714285714, 0.25892857142857145`}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 5], Rational[3, 10]}, {
       Rational[2031, 3500], Rational[1083, 3500]}}, {{0.6, 0.3}, {
      0.5802857142857143, 0.30942857142857144`}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 5], Rational[7, 20]}, {
       Rational[4089, 7000], Rational[719, 2000]}}, {{0.6, 0.35}, {
      0.5841428571428572, 0.3595}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 5], Rational[2, 5]}, {
       Rational[147, 250], Rational[358, 875]}}, {{0.6, 0.4}, {0.588, 
      0.40914285714285714`}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 5], Rational[9, 20]}, {
       Rational[4143, 7000], Rational[6417, 14000]}}, {{0.6, 0.45}, {
      0.5918571428571429, 0.45835714285714285`}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 5], Rational[1, 2]}, {
       Rational[417, 700], Rational[71, 140]}}, {{0.6, 0.5}, {
      0.5957142857142858, 0.5071428571428571}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 5], Rational[11, 20]}, {
       Rational[4197, 7000], Rational[1111, 2000]}}, {{0.6, 0.55}, {
      0.5995714285714285, 0.5555}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 5], Rational[3, 5]}, {
       Rational[528, 875], Rational[528, 875]}}, {{0.6, 0.6}, {
      0.6034285714285714, 0.6034285714285714}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 5], Rational[13, 20]}, {
       Rational[4251, 7000], Rational[9113, 14000]}}, {{0.6, 0.65}, {
      0.6072857142857143, 0.6509285714285714}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 5], Rational[7, 10]}, {
       Rational[2139, 3500], Rational[349, 500]}}, {{0.6, 0.7}, {
      0.6111428571428571, 0.698}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 5], Rational[3, 4]}, {
       Rational[123, 200], Rational[417, 560]}}, {{0.6, 0.75}, {0.615, 
      0.7446428571428572}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 5], Rational[4, 5]}, {
       Rational[1083, 1750], Rational[692, 875]}}, {{0.6, 0.8}, {
      0.6188571428571429, 0.7908571428571428}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 5], Rational[17, 20]}, {
       Rational[4359, 7000], Rational[11713, 14000]}}, {{0.6, 0.85}, {
      0.6227142857142857, 0.8366428571428571}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 5], Rational[9, 10]}, {
       Rational[2193, 3500], Rational[441, 500]}}, {{0.6, 0.9}, {
      0.6265714285714286, 0.882}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 5], Rational[19, 20]}, {
       Rational[4413, 7000], Rational[12977, 14000]}}, {{0.6, 0.95}, {
      0.6304285714285714, 0.9269285714285714}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 5], 1}, {
       Rational[111, 175], Rational[34, 35]}}, {{0.6, 1}, {0.6342857142857142,
        0.9714285714285714}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[13, 20], 0}, {Rational[169, 280], 0}}, {{
       0.65, 0}, {0.6035714285714285, 0}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[13, 20], Rational[1, 20]}, {
       Rational[34021, 56000], Rational[2977, 56000]}}, {{0.65, 0.05}, {
      0.6075178571428571, 0.05316071428571428}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[13, 20], Rational[1, 10]}, {
       Rational[17121, 28000], Rational[741, 7000]}}, {{0.65, 0.1}, {
      0.6114642857142857, 0.10585714285714286`}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[13, 20], Rational[3, 20]}, {
       Rational[34463, 56000], Rational[8853, 56000]}}, {{0.65, 0.15}, {
      0.6154107142857143, 0.1580892857142857}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[13, 20], Rational[1, 5]}, {
       Rational[8671, 14000], Rational[1469, 7000]}}, {{0.65, 0.2}, {
      0.6193571428571428, 0.20985714285714285`}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[13, 20], Rational[1, 4]}, {
       Rational[6981, 11200], Rational[117, 448]}}, {{0.65, 0.25}, {
      0.6233035714285714, 0.2611607142857143}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[13, 20], Rational[3, 10]}, {
       Rational[2509, 4000], Rational[39, 125]}}, {{0.65, 0.3}, {0.62725, 
      0.312}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[13, 20], Rational[7, 20]}, {
       Rational[35347, 56000], Rational[2899, 8000]}}, {{0.65, 0.35}, {
      0.6311964285714285, 0.362375}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[13, 20], Rational[2, 5]}, {
       Rational[2223, 3500], Rational[1443, 3500]}}, {{0.65, 0.4}, {
      0.6351428571428571, 0.4122857142857143}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[13, 20], Rational[9, 20]}, {
       Rational[35789, 56000], Rational[25857, 56000]}}, {{0.65, 0.45}, {
      0.6390892857142857, 0.46173214285714287`}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[13, 20], Rational[1, 2]}, {
       Rational[3601, 5600], Rational[143, 280]}}, {{0.65, 0.5}, {
      0.6430357142857143, 0.5107142857142857}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[13, 20], Rational[11, 20]}, {
       Rational[36231, 56000], Rational[31317, 56000]}}, {{0.65, 0.55}, {
      0.6469821428571428, 0.5592321428571428}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[13, 20], Rational[3, 5]}, {
       Rational[9113, 14000], Rational[4251, 7000]}}, {{0.65, 0.6}, {
      0.6509285714285714, 0.6072857142857143}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[13, 20], Rational[13, 20]}, {
       Rational[5239, 8000], Rational[5239, 8000]}}, {{0.65, 0.65}, {0.654875,
       0.654875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[13, 20], Rational[7, 10]}, {
       Rational[18447, 28000], Rational[351, 500]}}, {{0.65, 0.7}, {
      0.6588214285714286, 0.702}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[13, 20], Rational[3, 4]}, {
       Rational[7423, 11200], Rational[1677, 2240]}}, {{0.65, 0.75}, {
      0.6627678571428571, 0.7486607142857142}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[13, 20], Rational[4, 5]}, {
       Rational[4667, 7000], Rational[1391, 1750]}}, {{0.65, 0.8}, {
      0.6667142857142857, 0.7948571428571428}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[13, 20], Rational[17, 20]}, {
       Rational[37557, 56000], Rational[47073, 56000]}}, {{0.65, 0.85}, {
      0.6706607142857143, 0.8405892857142857}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[13, 20], Rational[9, 10]}, {
       Rational[18889, 28000], Rational[6201, 7000]}}, {{0.65, 0.9}, {
      0.6746071428571428, 0.8858571428571429}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[13, 20], Rational[19, 20]}, {
       Rational[37999, 56000], Rational[52117, 56000]}}, {{0.65, 0.95}, {
      0.6785535714285714, 0.9306607142857143}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[13, 20], 1}, {
       Rational[273, 400], Rational[39, 40]}}, {{0.65, 1}, {0.6825, 
       0.975}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[7, 10], 0}, {Rational[13, 20], 0}}, {{
       0.7, 0}, {0.65, 0}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[7, 10], Rational[1, 20]}, {
       Rational[327, 500], Rational[1503, 28000]}}, {{0.7, 0.05}, {0.654, 
      0.05367857142857143}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[7, 10], Rational[1, 10]}, {
       Rational[329, 500], Rational[187, 1750]}}, {{0.7, 0.1}, {0.658, 
      0.10685714285714286`}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[7, 10], Rational[3, 20]}, {
       Rational[331, 500], Rational[4467, 28000]}}, {{0.7, 0.15}, {0.662, 
      0.15953571428571428`}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[7, 10], Rational[1, 5]}, {
       Rational[333, 500], Rational[741, 3500]}}, {{0.7, 0.2}, {0.666, 
      0.21171428571428572`}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[7, 10], Rational[1, 4]}, {
       Rational[67, 100], Rational[59, 224]}}, {{0.7, 0.25}, {0.67, 
      0.26339285714285715`}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[7, 10], Rational[3, 10]}, {
       Rational[337, 500], Rational[1101, 3500]}}, {{0.7, 0.3}, {0.674, 
      0.31457142857142856`}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[7, 10], Rational[7, 20]}, {
       Rational[339, 500], Rational[1461, 4000]}}, {{0.7, 0.35}, {0.678, 
      0.36525}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[7, 10], Rational[2, 5]}, {
       Rational[341, 500], Rational[727, 1750]}}, {{0.7, 0.4}, {0.682, 
      0.4154285714285714}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[7, 10], Rational[9, 20]}, {
       Rational[343, 500], Rational[13023, 28000]}}, {{0.7, 0.45}, {0.686, 
      0.46510714285714283`}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[7, 10], Rational[1, 2]}, {
       Rational[69, 100], Rational[18, 35]}}, {{0.7, 0.5}, {0.69, 
      0.5142857142857142}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[7, 10], Rational[11, 20]}, {
       Rational[347, 500], Rational[15763, 28000]}}, {{0.7, 0.55}, {0.694, 
      0.5629642857142857}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[7, 10], Rational[3, 5]}, {
       Rational[349, 500], Rational[2139, 3500]}}, {{0.7, 0.6}, {0.698, 
      0.6111428571428571}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[7, 10], Rational[13, 20]}, {
       Rational[351, 500], Rational[18447, 28000]}}, {{0.7, 0.65}, {0.702, 
      0.6588214285714286}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[7, 10], Rational[7, 10]}, {
       Rational[353, 500], Rational[353, 500]}}, {{0.7, 0.7}, {0.706, 
      0.706}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[7, 10], Rational[3, 4]}, {
       Rational[71, 100], Rational[843, 1120]}}, {{0.7, 0.75}, {0.71, 
      0.7526785714285714}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[7, 10], Rational[4, 5]}, {
       Rational[357, 500], Rational[699, 875]}}, {{0.7, 0.8}, {0.714, 
      0.7988571428571428}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[7, 10], Rational[17, 20]}, {
       Rational[359, 500], Rational[23647, 28000]}}, {{0.7, 0.85}, {0.718, 
      0.8445357142857143}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[7, 10], Rational[9, 10]}, {
       Rational[361, 500], Rational[1557, 1750]}}, {{0.7, 0.9}, {0.722, 
      0.8897142857142857}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[7, 10], Rational[19, 20]}, {
       Rational[363, 500], Rational[26163, 28000]}}, {{0.7, 0.95}, {0.726, 
      0.9343928571428571}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[7, 10], 1}, {
       Rational[73, 100], Rational[137, 140]}}, {{0.7, 1}, {0.73, 
       0.9785714285714285}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 4], 0}, {Rational[39, 56], 0}}, {{
       0.75, 0}, {0.6964285714285714, 0}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 4], Rational[1, 20]}, {
       Rational[1569, 2240], Rational[607, 11200]}}, {{0.75, 0.05}, {
      0.7004464285714286, 0.05419642857142857}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 4], Rational[1, 10]}, {
       Rational[789, 1120], Rational[151, 1400]}}, {{0.75, 0.1}, {
      0.7044642857142858, 0.10785714285714286`}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 4], Rational[3, 20]}, {
       Rational[1587, 2240], Rational[1803, 11200]}}, {{0.75, 0.15}, {
      0.7084821428571428, 0.16098214285714285`}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 4], Rational[1, 5]}, {
       Rational[57, 80], Rational[299, 1400]}}, {{0.75, 0.2}, {0.7125, 
      0.21357142857142858`}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 4], Rational[1, 4]}, {
       Rational[321, 448], Rational[17, 64]}}, {{0.75, 0.25}, {
      0.7165178571428571, 0.265625}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 4], Rational[3, 10]}, {
       Rational[807, 1120], Rational[111, 350]}}, {{0.75, 0.3}, {
      0.7205357142857143, 0.3171428571428571}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 4], Rational[7, 20]}, {
       Rational[1623, 2240], Rational[589, 1600]}}, {{0.75, 0.35}, {
      0.7245535714285715, 0.368125}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 4], Rational[2, 5]}, {
       Rational[51, 70], Rational[293, 700]}}, {{0.75, 0.4}, {
      0.7285714285714285, 0.4185714285714286}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 4], Rational[9, 20]}, {
       Rational[1641, 2240], Rational[5247, 11200]}}, {{0.75, 0.45}, {
      0.7325892857142857, 0.46848214285714285`}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 4], Rational[1, 2]}, {
       Rational[165, 224], Rational[29, 56]}}, {{0.75, 0.5}, {
      0.7366071428571429, 0.5178571428571429}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 4], Rational[11, 20]}, {
       Rational[237, 320], Rational[6347, 11200]}}, {{0.75, 0.55}, {0.740625, 
      0.5666964285714285}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 4], Rational[3, 5]}, {
       Rational[417, 560], Rational[123, 200]}}, {{0.75, 0.6}, {
      0.7446428571428572, 0.615}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 4], Rational[13, 20]}, {
       Rational[1677, 2240], Rational[7423, 11200]}}, {{0.75, 0.65}, {
      0.7486607142857142, 0.6627678571428571}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 4], Rational[7, 10]}, {
       Rational[843, 1120], Rational[71, 100]}}, {{0.75, 0.7}, {
      0.7526785714285714, 0.71}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 4], Rational[3, 4]}, {
       Rational[339, 448], Rational[339, 448]}}, {{0.75, 0.75}, {
      0.7566964285714286, 0.7566964285714286}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 4], Rational[4, 5]}, {
       Rational[213, 280], Rational[281, 350]}}, {{0.75, 0.8}, {
      0.7607142857142857, 0.8028571428571428}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 4], Rational[17, 20]}, {
       Rational[1713, 2240], Rational[9503, 11200]}}, {{0.75, 0.85}, {
      0.7647321428571429, 0.8484821428571429}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 4], Rational[9, 10]}, {
       Rational[123, 160], Rational[1251, 1400]}}, {{0.75, 0.9}, {0.76875, 
      0.8935714285714286}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 4], Rational[19, 20]}, {
       Rational[1731, 2240], Rational[1501, 1600]}}, {{0.75, 0.95}, {
      0.7727678571428571, 0.938125}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 4], 1}, {
       Rational[87, 112], Rational[55, 56]}}, {{0.75, 1}, {0.7767857142857143,
        0.9821428571428571}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[4, 5], 0}, {Rational[26, 35], 0}}, {{0.8, 0}, {
       0.7428571428571429, 0}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[4, 5], Rational[1, 20]}, {
       Rational[1307, 1750], Rational[383, 7000]}}, {{0.8, 0.05}, {
      0.7468571428571429, 0.054714285714285715`}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[4, 5], Rational[1, 10]}, {
       Rational[657, 875], Rational[381, 3500]}}, {{0.8, 0.1}, {
      0.7508571428571429, 0.10885714285714286`}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[4, 5], Rational[3, 20]}, {
       Rational[1321, 1750], Rational[1137, 7000]}}, {{0.8, 0.15}, {
      0.7548571428571429, 0.16242857142857142`}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[4, 5], Rational[1, 5]}, {
       Rational[664, 875], Rational[377, 1750]}}, {{0.8, 0.2}, {
      0.7588571428571429, 0.21542857142857144`}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[4, 5], Rational[1, 4]}, {
       Rational[267, 350], Rational[15, 56]}}, {{0.8, 0.25}, {
      0.7628571428571429, 0.26785714285714285`}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[4, 5], Rational[3, 10]}, {
       Rational[671, 875], Rational[1119, 3500]}}, {{0.8, 0.3}, {
      0.7668571428571429, 0.31971428571428573`}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[4, 5], Rational[7, 20]}, {
       Rational[1349, 1750], Rational[371, 1000]}}, {{0.8, 0.35}, {
      0.7708571428571429, 0.371}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[4, 5], Rational[2, 5]}, {
       Rational[678, 875], Rational[369, 875]}}, {{0.8, 0.4}, {
      0.7748571428571429, 0.4217142857142857}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[4, 5], Rational[9, 20]}, {
       Rational[1363, 1750], Rational[3303, 7000]}}, {{0.8, 0.45}, {
      0.7788571428571428, 0.47185714285714286`}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[4, 5], Rational[1, 2]}, {
       Rational[137, 175], Rational[73, 140]}}, {{0.8, 0.5}, {
      0.7828571428571428, 0.5214285714285715}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[4, 5], Rational[11, 20]}, {
       Rational[1377, 1750], Rational[3993, 7000]}}, {{0.8, 0.55}, {
      0.7868571428571428, 0.5704285714285714}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[4, 5], Rational[3, 5]}, {
       Rational[692, 875], Rational[1083, 1750]}}, {{0.8, 0.6}, {
      0.7908571428571428, 0.6188571428571429}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[4, 5], Rational[13, 20]}, {
       Rational[1391, 1750], Rational[4667, 7000]}}, {{0.8, 0.65}, {
      0.7948571428571428, 0.6667142857142857}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[4, 5], Rational[7, 10]}, {
       Rational[699, 875], Rational[357, 500]}}, {{0.8, 0.7}, {
      0.7988571428571428, 0.714}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[4, 5], Rational[3, 4]}, {
       Rational[281, 350], Rational[213, 280]}}, {{0.8, 0.75}, {
      0.8028571428571428, 0.7607142857142857}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[4, 5], Rational[4, 5]}, {
       Rational[706, 875], Rational[706, 875]}}, {{0.8, 0.8}, {
      0.8068571428571428, 0.8068571428571428}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[4, 5], Rational[17, 20]}, {
       Rational[1419, 1750], Rational[5967, 7000]}}, {{0.8, 0.85}, {
      0.8108571428571428, 0.8524285714285714}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[4, 5], Rational[9, 10]}, {
       Rational[713, 875], Rational[3141, 3500]}}, {{0.8, 0.9}, {
      0.8148571428571428, 0.8974285714285715}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[4, 5], Rational[19, 20]}, {
       Rational[1433, 1750], Rational[6593, 7000]}}, {{0.8, 0.95}, {
      0.8188571428571428, 0.9418571428571428}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[4, 5], 1}, {
       Rational[144, 175], Rational[69, 70]}}, {{0.8, 1}, {0.8228571428571428,
        0.9857142857142858}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[17, 20], 0}, {Rational[221, 280], 0}}, {{
       0.85, 0}, {0.7892857142857143, 0}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[17, 20], Rational[1, 20]}, {
       Rational[44421, 56000], Rational[3093, 56000]}}, {{0.85, 0.05}, {
      0.7932321428571428, 0.055232142857142855`}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[17, 20], Rational[1, 10]}, {
       Rational[22321, 28000], Rational[769, 7000]}}, {{0.85, 0.1}, {
      0.7971785714285714, 0.10985714285714286`}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[17, 20], Rational[3, 20]}, {
       Rational[6409, 8000], Rational[1311, 8000]}}, {{0.85, 0.15}, {0.801125,
       0.163875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[
     NCache[{{Rational[17, 20], Rational[1, 5]}, {
       Rational[11271, 14000], Rational[1521, 7000]}}, {{0.85, 0.2}, {
      0.8050714285714285, 0.21728571428571428`}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[17, 20], Rational[1, 4]}, {
       Rational[9061, 11200], Rational[121, 448]}}, {{0.85, 0.25}, {
      0.8090178571428571, 0.2700892857142857}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[17, 20], Rational[3, 10]}, {
       Rational[22763, 28000], Rational[282, 875]}}, {{0.85, 0.3}, {
      0.8129642857142857, 0.3222857142857143}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[17, 20], Rational[7, 20]}, {
       Rational[45747, 56000], Rational[2991, 8000]}}, {{0.85, 0.35}, {
      0.8169107142857143, 0.373875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[17, 20], Rational[2, 5]}, {
       Rational[2873, 3500], Rational[1487, 3500]}}, {{0.85, 0.4}, {
      0.8208571428571428, 0.4248571428571429}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[17, 20], Rational[9, 20]}, {
       Rational[46189, 56000], Rational[26613, 56000]}}, {{0.85, 0.45}, {
      0.8248035714285714, 0.4752321428571429}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[17, 20], Rational[1, 2]}, {
       Rational[663, 800], Rational[21, 40]}}, {{0.85, 0.5}, {0.82875, 
      0.525}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[17, 20], Rational[11, 20]}, {
       Rational[46631, 56000], Rational[32153, 56000]}}, {{0.85, 0.55}, {
      0.8326964285714286, 0.5741607142857142}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[17, 20], Rational[3, 5]}, {
       Rational[11713, 14000], Rational[4359, 7000]}}, {{0.85, 0.6}, {
      0.8366428571428571, 0.6227142857142857}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[17, 20], Rational[13, 20]}, {
       Rational[47073, 56000], Rational[37557, 56000]}}, {{0.85, 0.65}, {
      0.8405892857142857, 0.6706607142857143}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[17, 20], Rational[7, 10]}, {
       Rational[23647, 28000], Rational[359, 500]}}, {{0.85, 0.7}, {
      0.8445357142857143, 0.718}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[17, 20], Rational[3, 4]}, {
       Rational[9503, 11200], Rational[1713, 2240]}}, {{0.85, 0.75}, {
      0.8484821428571429, 0.7647321428571429}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[17, 20], Rational[4, 5]}, {
       Rational[5967, 7000], Rational[1419, 1750]}}, {{0.85, 0.8}, {
      0.8524285714285714, 0.8108571428571428}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[17, 20], Rational[17, 20]}, {
       Rational[6851, 8000], Rational[6851, 8000]}}, {{0.85, 0.85}, {0.856375,
       0.856375}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[17, 20], Rational[9, 10]}, {
       Rational[24089, 28000], Rational[6309, 7000]}}, {{0.85, 0.9}, {
      0.8603214285714286, 0.9012857142857142}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[17, 20], Rational[19, 20]}, {
       Rational[48399, 56000], Rational[52953, 56000]}}, {{0.85, 0.95}, {
      0.8642678571428571, 0.9455892857142857}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[17, 20], 1}, {
       Rational[2431, 2800], Rational[277, 280]}}, {{0.85, 1}, {
       0.8682142857142857, 0.9892857142857143}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[9, 10], 0}, {Rational[117, 140], 0}}, {{
       0.9, 0}, {0.8357142857142857, 0}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[9, 10], Rational[1, 20]}, {
       Rational[5877, 7000], Rational[223, 4000]}}, {{0.9, 0.05}, {
      0.8395714285714285, 0.05575}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[9, 10], Rational[1, 10]}, {
       Rational[738, 875], Rational[97, 875]}}, {{0.9, 0.1}, {
      0.8434285714285714, 0.11085714285714286`}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[9, 10], Rational[3, 20]}, {
       Rational[5931, 7000], Rational[4629, 28000]}}, {{0.9, 0.15}, {
      0.8472857142857143, 0.16532142857142856`}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[9, 10], Rational[1, 5]}, {
       Rational[2979, 3500], Rational[767, 3500]}}, {{0.9, 0.2}, {
      0.8511428571428571, 0.21914285714285714`}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[9, 10], Rational[1, 4]}, {
       Rational[171, 200], Rational[61, 224]}}, {{0.9, 0.25}, {0.855, 
      0.27232142857142855`}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[9, 10], Rational[3, 10]}, {
       Rational[1503, 1750], Rational[1137, 3500]}}, {{0.9, 0.3}, {
      0.8588571428571429, 0.32485714285714284`}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[9, 10], Rational[7, 20]}, {
       Rational[6039, 7000], Rational[1507, 4000]}}, {{0.9, 0.35}, {
      0.8627142857142858, 0.37675}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[9, 10], Rational[2, 5]}, {
       Rational[3033, 3500], Rational[107, 250]}}, {{0.9, 0.4}, {
      0.8665714285714285, 0.428}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[9, 10], Rational[9, 20]}, {
       Rational[6093, 7000], Rational[13401, 28000]}}, {{0.9, 0.45}, {
      0.8704285714285714, 0.47860714285714284`}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[9, 10], Rational[1, 2]}, {
       Rational[153, 175], Rational[37, 70]}}, {{0.9, 0.5}, {
      0.8742857142857143, 0.5285714285714286}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[9, 10], Rational[11, 20]}, {
       Rational[6147, 7000], Rational[16181, 28000]}}, {{0.9, 0.55}, {
      0.8781428571428571, 0.5778928571428571}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[9, 10], Rational[3, 5]}, {
       Rational[441, 500], Rational[2193, 3500]}}, {{0.9, 0.6}, {0.882, 
      0.6265714285714286}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[9, 10], Rational[13, 20]}, {
       Rational[6201, 7000], Rational[18889, 28000]}}, {{0.9, 0.65}, {
      0.8858571428571429, 0.6746071428571428}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[9, 10], Rational[7, 10]}, {
       Rational[1557, 1750], Rational[361, 500]}}, {{0.9, 0.7}, {
      0.8897142857142857, 0.722}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[9, 10], Rational[3, 4]}, {
       Rational[1251, 1400], Rational[123, 160]}}, {{0.9, 0.75}, {
      0.8935714285714286, 0.76875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[9, 10], Rational[4, 5]}, {
       Rational[3141, 3500], Rational[713, 875]}}, {{0.9, 0.8}, {
      0.8974285714285715, 0.8148571428571428}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[9, 10], Rational[17, 20]}, {
       Rational[6309, 7000], Rational[24089, 28000]}}, {{0.9, 0.85}, {
      0.9012857142857142, 0.8603214285714286}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[9, 10], Rational[9, 10]}, {
       Rational[792, 875], Rational[792, 875]}}, {{0.9, 0.9}, {
      0.9051428571428571, 0.9051428571428571}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[9, 10], Rational[19, 20]}, {
       Rational[909, 1000], Rational[26581, 28000]}}, {{0.9, 0.95}, {0.909, 
      0.9493214285714285}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[9, 10], 1}, {
       Rational[639, 700], Rational[139, 140]}}, {{0.9, 1}, {
       0.9128571428571428, 0.9928571428571429}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[19, 20], 0}, {Rational[247, 280], 0}}, {{
       0.95, 0}, {0.8821428571428571, 0}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[19, 20], Rational[1, 20]}, {
       Rational[7087, 8000], Rational[3151, 56000]}}, {{0.95, 0.05}, {
      0.885875, 0.05626785714285714}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[19, 20], Rational[1, 10]}, {
       Rational[24909, 28000], Rational[783, 7000]}}, {{0.95, 0.1}, {
      0.8896071428571428, 0.11185714285714286`}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[19, 20], Rational[3, 20]}, {
       Rational[50027, 56000], Rational[9339, 56000]}}, {{0.95, 0.15}, {
      0.8933392857142857, 0.16676785714285713`}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[
     NCache[{{Rational[19, 20], Rational[1, 5]}, {
       Rational[12559, 14000], Rational[221, 1000]}}, {{0.95, 0.2}, {
      0.8970714285714285, 0.221}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[19, 20], Rational[1, 4]}, {
       Rational[10089, 11200], Rational[123, 448]}}, {{0.95, 0.25}, {
      0.9008035714285715, 0.27455357142857145`}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[19, 20], Rational[3, 10]}, {
       Rational[25327, 28000], Rational[573, 1750]}}, {{0.95, 0.3}, {
      0.9045357142857143, 0.3274285714285714}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[19, 20], Rational[7, 20]}, {
       Rational[50863, 56000], Rational[3037, 8000]}}, {{0.95, 0.35}, {
      0.9082678571428572, 0.379625}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[19, 20], Rational[2, 5]}, {
       Rational[114, 125], Rational[1509, 3500]}}, {{0.95, 0.4}, {0.912, 
      0.43114285714285716`}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[19, 20], Rational[9, 20]}, {
       Rational[51281, 56000], Rational[26991, 56000]}}, {{0.95, 0.45}, {
      0.9157321428571429, 0.48198214285714286`}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[19, 20], Rational[1, 2]}, {
       Rational[5149, 5600], Rational[149, 280]}}, {{0.95, 0.5}, {
      0.9194642857142857, 0.5321428571428571}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[19, 20], Rational[11, 20]}, {
       Rational[51699, 56000], Rational[4653, 8000]}}, {{0.95, 0.55}, {
      0.9231964285714286, 0.581625}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[19, 20], Rational[3, 5]}, {
       Rational[12977, 14000], Rational[4413, 7000]}}, {{0.95, 0.6}, {
      0.9269285714285714, 0.6304285714285714}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[19, 20], Rational[13, 20]}, {
       Rational[52117, 56000], Rational[37999, 56000]}}, {{0.95, 0.65}, {
      0.9306607142857143, 0.6785535714285714}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[19, 20], Rational[7, 10]}, {
       Rational[26163, 28000], Rational[363, 500]}}, {{0.95, 0.7}, {
      0.9343928571428571, 0.726}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[19, 20], Rational[3, 4]}, {
       Rational[1501, 1600], Rational[1731, 2240]}}, {{0.95, 0.75}, {0.938125,
       0.7727678571428571}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[19, 20], Rational[4, 5]}, {
       Rational[6593, 7000], Rational[1433, 1750]}}, {{0.95, 0.8}, {
      0.9418571428571428, 0.8188571428571428}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[19, 20], Rational[17, 20]}, {
       Rational[52953, 56000], Rational[48399, 56000]}}, {{0.95, 0.85}, {
      0.9455892857142857, 0.8642678571428571}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[19, 20], Rational[9, 10]}, {
       Rational[26581, 28000], Rational[909, 1000]}}, {{0.95, 0.9}, {
      0.9493214285714285, 0.909}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[19, 20], Rational[19, 20]}, {
       Rational[53371, 56000], Rational[53371, 56000]}}, {{0.95, 0.95}, {
      0.9530535714285714, 0.9530535714285714}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[19, 20], 1}, {
       Rational[2679, 2800], Rational[279, 280]}}, {{0.95, 1}, {
       0.9567857142857142, 0.9964285714285714}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{1, 0}, {Rational[13, 14], 0}}, {{1, 0}, {
       0.9285714285714286, 0}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{1, Rational[1, 20]}, {
       Rational[261, 280], Rational[159, 2800]}}, {{1, 0.05}, {
       0.9321428571428572, 0.05678571428571429}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{1, Rational[1, 10]}, {
       Rational[131, 140], Rational[79, 700]}}, {{1, 0.1}, {
       0.9357142857142857, 0.11285714285714285`}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{1, Rational[3, 20]}, {
       Rational[263, 280], Rational[471, 2800]}}, {{1, 0.15}, {
       0.9392857142857143, 0.1682142857142857}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{1, Rational[1, 5]}, {
       Rational[33, 35], Rational[39, 175]}}, {{1, 0.2}, {0.9428571428571428, 
       0.22285714285714286`}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{1, Rational[1, 4]}, {
       Rational[53, 56], Rational[31, 112]}}, {{1, 0.25}, {0.9464285714285714,
        0.2767857142857143}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{1, Rational[3, 10]}, {
       Rational[19, 20], Rational[33, 100]}}, {{1, 0.3}, {0.95, 0.33}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{1, Rational[7, 20]}, {
       Rational[267, 280], Rational[153, 400]}}, {{1, 0.35}, {
       0.9535714285714286, 0.3825}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{1, Rational[2, 5]}, {
       Rational[67, 70], Rational[76, 175]}}, {{1, 0.4}, {0.9571428571428572, 
       0.4342857142857143}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{1, Rational[9, 20]}, {
       Rational[269, 280], Rational[1359, 2800]}}, {{1, 0.45}, {
       0.9607142857142857, 0.4853571428571429}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{1, Rational[1, 2]}, {
       Rational[27, 28], Rational[15, 28]}}, {{1, 0.5}, {0.9642857142857143, 
       0.5357142857142857}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{1, Rational[11, 20]}, {
       Rational[271, 280], Rational[1639, 2800]}}, {{1, 0.55}, {
       0.9678571428571429, 0.5853571428571429}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{1, Rational[3, 5]}, {
       Rational[34, 35], Rational[111, 175]}}, {{1, 0.6}, {0.9714285714285714,
        0.6342857142857142}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{1, Rational[13, 20]}, {
       Rational[39, 40], Rational[273, 400]}}, {{1, 0.65}, {0.975, 
       0.6825}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{1, Rational[7, 10]}, {
       Rational[137, 140], Rational[73, 100]}}, {{1, 0.7}, {
       0.9785714285714285, 0.73}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{1, Rational[3, 4]}, {
       Rational[55, 56], Rational[87, 112]}}, {{1, 0.75}, {0.9821428571428571,
        0.7767857142857143}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{1, Rational[4, 5]}, {
       Rational[69, 70], Rational[144, 175]}}, {{1, 0.8}, {0.9857142857142858,
        0.8228571428571428}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{1, Rational[17, 20]}, {
       Rational[277, 280], Rational[2431, 2800]}}, {{1, 0.85}, {
       0.9892857142857143, 0.8682142857142857}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{1, Rational[9, 10]}, {
       Rational[139, 140], Rational[639, 700]}}, {{1, 0.9}, {
       0.9928571428571429, 0.9128571428571428}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{1, Rational[19, 20]}, {
       Rational[279, 280], Rational[2679, 2800]}}, {{1, 0.95}, {
       0.9964285714285714, 0.9567857142857142}}]]}, 
   {PointSize[0.008], PointBox[{0, 0}], 
    PointBox[NCache[{Rational[1, 2], Rational[1, 2]}, {0.5, 0.5}]], 
    PointBox[{1, 1}]}},
  AspectRatio->Automatic,
  Axes->True,
  AxesLabel->{
    FormBox["\"Prob C Player1\"", TraditionalForm], 
    FormBox["\"Prob C Player2\"", TraditionalForm]},
  AxesOrigin->{-0.025, -0.025},
  PlotLabel->FormBox["\"Expected Change\"", TraditionalForm]]], "Output",
 CellChangeTimes->{
  3.39268776928125*^9, {3.3926879939375*^9, 3.392688048109375*^9}, 
   3.39268833396875*^9, {3.392688413046875*^9, 3.39268842940625*^9}, {
   3.392688469859375*^9, 3.39268847896875*^9}, 3.392688563609375*^9, {
   3.392689618640625*^9, 3.39268969428125*^9}, 3.3926897840625*^9, {
   3.392689827609375*^9, 3.392689847015625*^9}, {3.392695391046875*^9, 
   3.392695398859375*^9}, 3.392699693421875*^9, 3.39270144609375*^9, 
   3.392705525578125*^9, 3.392705665890625*^9, 3.39270663440625*^9, 
   3.39270714203125*^9, 3.392707211328125*^9, 3.392707260703125*^9, {
   3.392752799875*^9, 3.39275280615625*^9}, 3.39275907028125*^9, 
   3.392759141453125*^9, 3.3927591866875*^9, 3.3927592425625*^9, 
   3.392759854046875*^9, 3.39276067034375*^9, 3.392760941109375*^9, {
   3.39276137440625*^9, 3.392761390859375*^9}, 3.39276311371875*^9, 
   3.3927636099375*^9, 3.392763753703125*^9, 3.3927639528125*^9, 
   3.39276420696875*^9, 3.392764340921875*^9, 3.392764902078125*^9, 
   3.392776917953125*^9, 3.392777823953125*^9, 3.392855041671875*^9, 
   3.392855280109375*^9, 3.392855403125*^9, 3.3928554410625*^9, 
   3.39285549803125*^9, 3.3928569774375*^9, {3.39285706821875*^9, 
   3.39285709196875*^9}, 3.392859516203125*^9, 3.392859776359375*^9, 
   3.3928601668125*^9, 3.392860290421875*^9, 3.392860632015625*^9, 
   3.39286362865625*^9, 3.392863719375*^9, 3.392863766390625*^9, 
   3.392869603390625*^9, 3.393406906140625*^9, 3.3934070338125*^9, 
   3.393407337078125*^9, 3.39340761284375*^9, 3.393436889984375*^9, 
   3.39343695946875*^9, 3.393437282515625*^9, 3.39343733696875*^9, 
   3.393437374515625*^9, 3.39343751653125*^9, 3.393437641609375*^9, {
   3.393437765984375*^9, 3.393437794453125*^9}, 3.393437830375*^9, 
   3.393437882640625*^9, 3.393438016375*^9, {3.3934380965*^9, 
   3.39343811796875*^9}, 3.39343816559375*^9, {3.39343856565625*^9, 
   3.393438592359375*^9}, 3.393438790359375*^9, {3.393438902234375*^9, 
   3.3934389309375*^9}, 3.393439725515625*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Simulation - Initialisation", "Section"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
   "Vector", " ", "with", " ", "the", " ", "decisions", " ", "made", " ", 
    "by", " ", "each", " ", "of", " ", "the", " ", "agents"}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"decisions", "=", 
     RowBox[{"{", ",", "}"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"prob1", "=", "initialProb1"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"prob2", "=", "initialProb2"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"listOfProb", "=", 
     RowBox[{"{", "}"}]}], ";"}]}]}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Simulation - Execution", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Draw", " ", "a", " ", "black", " ", "ball", " ", "with", " ", "number", 
    " ", "0", " ", "for", " ", "the", " ", "initial", " ", "conditions"}], 
   " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"AppendTo", "[", 
     RowBox[{"listOfProb", ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"EdgeForm", "[", "Thick", "]"}], ",", 
        RowBox[{"Disk", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"initialProb1", ",", "initialProb2"}], "}"}], ",", 
          "0.03`"}], "]"}]}], "}"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"AppendTo", "[", 
     RowBox[{"listOfProb", ",", 
      RowBox[{"Text", "[", 
       RowBox[{
        RowBox[{"Style", "[", 
         RowBox[{"\"\<0\>\"", ",", 
          RowBox[{"FontSize", "\[Rule]", 
           RowBox[{"16", "*", "textScaleFactor"}]}], ",", "Bold", ",", 
          RowBox[{"GrayLevel", "[", "1", "]"}], ",", 
          RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"initialProb1", ",", "initialProb2"}], "}"}]}], "]"}]}], 
     "]"}], ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{"and", " ", "the", " ", "rest", " ", "of", " ", "them"}], 
     "..."}], " ", "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", " ", 
   
   RowBox[{
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"i", "=", "1"}], ",", 
      RowBox[{"i", "\[LessEqual]", "nOfIterations"}], ",", 
      RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
      
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"RandomReal", "[", "]"}], "\[LessEqual]", "prob1"}], ",", 
         RowBox[{
          RowBox[{
          "decisions", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}],
           "=", "Cooperate"}], ",", 
         RowBox[{
          RowBox[{
          "decisions", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}],
           "=", "Defect"}]}], "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"noise", "\[NotEqual]", "0"}], ",", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"RandomReal", "[", "]"}], "\[LessEqual]", "noise"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
              "decisions", "\[LeftDoubleBracket]", "1", 
               "\[RightDoubleBracket]"}], "\[Equal]", "Cooperate"}], ",", 
             RowBox[{
              RowBox[{
              "decisions", "\[LeftDoubleBracket]", "1", 
               "\[RightDoubleBracket]"}], "=", "Defect"}], ",", 
             RowBox[{
              RowBox[{
              "decisions", "\[LeftDoubleBracket]", "1", 
               "\[RightDoubleBracket]"}], "=", "Cooperate"}]}], "]"}]}], 
          "]"}]}], "]"}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"RandomReal", "[", "]"}], "\[LessEqual]", "prob2"}], ",", 
         RowBox[{
          RowBox[{
          "decisions", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}],
           "=", "Cooperate"}], ",", 
         RowBox[{
          RowBox[{
          "decisions", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}],
           "=", "Defect"}]}], "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"noise", "\[NotEqual]", "0"}], ",", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"RandomReal", "[", "]"}], "\[LessEqual]", "noise"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
              "decisions", "\[LeftDoubleBracket]", "2", 
               "\[RightDoubleBracket]"}], "\[Equal]", "Cooperate"}], ",", 
             RowBox[{
              RowBox[{
              "decisions", "\[LeftDoubleBracket]", "2", 
               "\[RightDoubleBracket]"}], "=", "Defect"}], ",", 
             RowBox[{
              RowBox[{
              "decisions", "\[LeftDoubleBracket]", "2", 
               "\[RightDoubleBracket]"}], "=", "Cooperate"}]}], "]"}]}], 
          "]"}]}], "]"}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"outcome", "=", 
        RowBox[{"Switch", "[", 
         RowBox[{"decisions", ",", "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{"Cooperate", ",", "Cooperate"}], "}"}], ",", "CC", ",", 
          "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{"Cooperate", ",", "Defect"}], "}"}], ",", "CD", ",", 
          "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{"Defect", ",", "Cooperate"}], "}"}], ",", "DC", ",", 
          "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{"Defect", ",", "Defect"}], "}"}], ",", "DD"}], "]"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"prob1", "=", 
        RowBox[{"prob1", "+", 
         RowBox[{"changeAfterOn", "[", 
          RowBox[{"outcome", ",", "prob1"}], "]"}]}]}], ";", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"outcome", "=", 
        RowBox[{"Switch", "[", 
         RowBox[{"decisions", ",", "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{"Cooperate", ",", "Cooperate"}], "}"}], ",", "CC", ",", 
          "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{"Cooperate", ",", "Defect"}], "}"}], ",", "DC", ",", 
          "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{"Defect", ",", "Cooperate"}], "}"}], ",", "CD", ",", 
          "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{"Defect", ",", "Defect"}], "}"}], ",", "DD"}], "]"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"prob2", "=", 
        RowBox[{"prob2", "+", 
         RowBox[{"changeAfterOn", "[", 
          RowBox[{"outcome", ",", "prob2"}], "]"}]}]}], ";", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"AppendTo", "[", 
        RowBox[{"listOfProb", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"GrayLevel", "[", 
            FractionBox[
             RowBox[{" ", "i"}], "nOfIterations"], "]"}], ",", 
           RowBox[{"EdgeForm", "[", "Thick", "]"}], ",", 
           RowBox[{"Disk", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"prob1", ",", "prob2"}], "}"}], ",", "0.03`"}], "]"}]}],
           "}"}]}], "]"}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
       
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"i", "<", 
          FractionBox["nOfIterations", "2"]}], ",", "\[IndentingNewLine]", 
         RowBox[{"AppendTo", "[", 
          RowBox[{"listOfProb", ",", 
           RowBox[{"Text", "[", 
            RowBox[{
             RowBox[{"Style", "[", 
              RowBox[{"i", ",", 
               RowBox[{"FontSize", "\[Rule]", 
                RowBox[{"16", "*", "textScaleFactor"}]}], ",", "Bold", ",", 
               RowBox[{"GrayLevel", "[", "1", "]"}], ",", 
               RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}]}], "]"}], 
             ",", 
             RowBox[{"{", 
              RowBox[{"prob1", ",", "prob2"}], "}"}]}], "]"}]}], "]"}], ",", 
         RowBox[{"AppendTo", "[", 
          RowBox[{"listOfProb", ",", 
           RowBox[{"Text", "[", 
            RowBox[{
             RowBox[{"Style", "[", 
              RowBox[{"i", ",", 
               RowBox[{"FontSize", "\[Rule]", 
                RowBox[{"16", "*", "textScaleFactor"}]}], ",", "Bold", ",", 
               RowBox[{"GrayLevel", "[", "0", "]"}], ",", 
               RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}]}], "]"}], 
             ",", 
             RowBox[{"{", 
              RowBox[{"prob1", ",", "prob2"}], "}"}]}], "]"}]}], "]"}]}], 
        "\[IndentingNewLine]", "]"}], ";"}]}], "\[IndentingNewLine]", "]"}], 
    ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", " ", 
   RowBox[{"Show", "[", 
    RowBox[{
     RowBox[{"Graphics", "[", "listOfProb", "]"}], ",", 
     RowBox[{"AxesOrigin", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "0.025`"}], ",", 
        RowBox[{"-", "0.025`"}]}], "}"}]}], ",", 
     RowBox[{"Axes", "\[Rule]", "True"}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "Automatic"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<Prob C Player1\>\"", ",", "\"\<Prob C Player2\>\""}], 
       "}"}]}], ",", 
     RowBox[{"PlotLabel", "\[Rule]", "\"\<Simulation\>\""}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.14`"}], ",", "1.03`"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.14`"}], ",", "1.03`"}], "}"}]}], "}"}]}]}], 
    "]"}]}]}]], "Input",
 CellChangeTimes->{{3.392695450328125*^9, 3.39269549834375*^9}, {
   3.392699619484375*^9, 3.3926996861875*^9}, {3.392699869109375*^9, 
   3.39269990209375*^9}, {3.39270000284375*^9, 3.392700071828125*^9}, {
   3.3927007693125*^9, 3.39270080375*^9}, {3.392760662953125*^9, 
   3.39276066584375*^9}, {3.392761387453125*^9, 3.39276138765625*^9}, {
   3.39276356509375*^9, 3.39276357759375*^9}, {3.392763923390625*^9, 
   3.392763938046875*^9}, {3.3927640758125*^9, 3.392764079265625*^9}, {
   3.392854925171875*^9, 3.39285493121875*^9}, {3.392855176609375*^9, 
   3.392855266078125*^9}, {3.392855380140625*^9, 3.392855400234375*^9}, {
   3.392855432609375*^9, 3.392855435015625*^9}, 3.39285548728125*^9, 
   3.39285938725*^9, 3.392859434765625*^9, {3.39285948865625*^9, 
   3.392859511078125*^9}, {3.392859544734375*^9, 3.392859545640625*^9}, {
   3.3928597296875*^9, 3.392859736765625*^9}, {3.392859832265625*^9, 
   3.39285983296875*^9}, {3.392863590875*^9, 3.392863611140625*^9}, {
   3.392863707546875*^9, 3.39286371375*^9}, {3.392863900625*^9, 
   3.39286390715625*^9}, 3.392870105046875*^9, {3.393436940640625*^9, 
   3.3934369425*^9}, {3.393437212140625*^9, 3.393437217015625*^9}, {
   3.39343726375*^9, 3.39343726534375*^9}, {3.393437328109375*^9, 
   3.393437332*^9}, {3.393437372234375*^9, 3.393437372390625*^9}, {
   3.3934374629375*^9, 3.3934374719375*^9}, {3.393437762296875*^9, 
   3.39343776259375*^9}, 3.393437828171875*^9, {3.393437873078125*^9, 
   3.393437879875*^9}}],

Cell[BoxData[
 GraphicsBox[{
   {EdgeForm[Thickness[Large]], 
    DiskBox[NCache[{Rational[1, 2], Rational[1, 2]}, {0.5, 0.5}], 0.03]}, 
   InsetBox[
    StyleBox["\<\"0\"\>",
     StripOnInput->False,
     FrontFaceColor->GrayLevel[1],
     BackFaceColor->GrayLevel[1],
     GraphicsColor->GrayLevel[1],
     FontFamily->"Times",
     FontSize->16,
     FontWeight->Bold,
     FontColor->GrayLevel[1]], 
    NCache[{Rational[1, 2], Rational[1, 2]}, {0.5, 0.5}]], 
   {GrayLevel[
     NCache[
      Rational[1, 40], 0.025]], EdgeForm[Thickness[Large]], 
    DiskBox[NCache[{Rational[9, 28], Rational[13, 28]}, {0.32142857142857145`,
       0.4642857142857143}], 0.03]}, InsetBox[
    StyleBox["1",
     StripOnInput->False,
     FrontFaceColor->GrayLevel[1],
     BackFaceColor->GrayLevel[1],
     GraphicsColor->GrayLevel[1],
     FontFamily->"Times",
     FontSize->16,
     FontWeight->Bold,
     FontColor->GrayLevel[1]], 
    NCache[{Rational[9, 28], Rational[13, 28]}, {0.32142857142857145`, 
     0.4642857142857143}]], 
   {GrayLevel[
     NCache[
      Rational[1, 20], 0.05]], EdgeForm[Thickness[Large]], 
    DiskBox[NCache[{Rational[81, 392], Rational[169, 392]}, {
      0.2066326530612245, 0.43112244897959184`}], 0.03]}, InsetBox[
    StyleBox["2",
     StripOnInput->False,
     FrontFaceColor->GrayLevel[1],
     BackFaceColor->GrayLevel[1],
     GraphicsColor->GrayLevel[1],
     FontFamily->"Times",
     FontSize->16,
     FontWeight->Bold,
     FontColor->GrayLevel[1]], 
    NCache[{Rational[81, 392], Rational[169, 392]}, {0.2066326530612245, 
     0.43112244897959184`}]], 
   {GrayLevel[
     NCache[
      Rational[3, 40], 0.075]], EdgeForm[Thickness[Large]], 
    DiskBox[NCache[{Rational[729, 5488], Rational[2197, 5488]}, {
      0.13283527696793002`, 0.40032798833819244`}], 0.03]}, InsetBox[
    StyleBox["3",
     StripOnInput->False,
     FrontFaceColor->GrayLevel[1],
     BackFaceColor->GrayLevel[1],
     GraphicsColor->GrayLevel[1],
     FontFamily->"Times",
     FontSize->16,
     FontWeight->Bold,
     FontColor->GrayLevel[1]], 
    NCache[{Rational[729, 5488], Rational[2197, 5488]}, {0.13283527696793002`,
      0.40032798833819244`}]], 
   {GrayLevel[
     NCache[
      Rational[1, 10], 0.1]], EdgeForm[Thickness[Large]], 
    DiskBox[NCache[{Rational[6561, 76832], Rational[28561, 76832]}, {
      0.08539410662224073, 0.37173313202832153`}], 0.03]}, InsetBox[
    StyleBox["4",
     StripOnInput->False,
     FrontFaceColor->GrayLevel[1],
     BackFaceColor->GrayLevel[1],
     GraphicsColor->GrayLevel[1],
     FontFamily->"Times",
     FontSize->16,
     FontWeight->Bold,
     FontColor->GrayLevel[1]], 
    NCache[{Rational[6561, 76832], Rational[28561, 76832]}, {
     0.08539410662224073, 0.37173313202832153`}]], 
   {GrayLevel[
     NCache[
      Rational[1, 8], 0.125]], EdgeForm[Thickness[Large]], 
    DiskBox[NCache[{Rational[85293, 1075648], Rational[371293, 1075648]}, {
      0.07929452757779497, 0.34518076545487}], 0.03]}, InsetBox[
    StyleBox["5",
     StripOnInput->False,
     FrontFaceColor->GrayLevel[1],
     BackFaceColor->GrayLevel[1],
     GraphicsColor->GrayLevel[1],
     FontFamily->"Times",
     FontSize->16,
     FontWeight->Bold,
     FontColor->GrayLevel[1]], 
    NCache[{Rational[85293, 1075648], Rational[371293, 1075648]}, {
     0.07929452757779497, 0.34518076545487}]], 
   {GrayLevel[
     NCache[
      Rational[3, 20], 0.15]], EdgeForm[Thickness[Large]], 
    DiskBox[NCache[{
      Rational[1108809, 15059072], Rational[4826809, 15059072]}, {
      0.07363063275080961, 0.32052499649380783`}], 0.03]}, InsetBox[
    StyleBox["6",
     StripOnInput->False,
     FrontFaceColor->GrayLevel[1],
     BackFaceColor->GrayLevel[1],
     GraphicsColor->GrayLevel[1],
     FontFamily->"Times",
     FontSize->16,
     FontWeight->Bold,
     FontColor->GrayLevel[1]], 
    NCache[{Rational[1108809, 15059072], Rational[4826809, 15059072]}, {
     0.07363063275080961, 0.32052499649380783`}]], 
   {GrayLevel[
     NCache[
      Rational[7, 40], 0.175]], EdgeForm[Thickness[Large]], 
    DiskBox[NCache[{
      Rational[9979281, 210827008], Rational[62748517, 210827008]}, {
      0.04733397819694904, 0.2976303538871073}], 0.03]}, InsetBox[
    StyleBox["7",
     StripOnInput->False,
     FrontFaceColor->GrayLevel[1],
     BackFaceColor->GrayLevel[1],
     GraphicsColor->GrayLevel[1],
     FontFamily->"Times",
     FontSize->16,
     FontWeight->Bold,
     FontColor->GrayLevel[1]], 
    NCache[{Rational[9979281, 210827008], Rational[62748517, 210827008]}, {
     0.04733397819694904, 0.2976303538871073}]], 
   {GrayLevel[
     NCache[
      Rational[1, 5], 0.2]], EdgeForm[Thickness[Large]], 
    DiskBox[NCache[{
      Rational[129730653, 2951578112], Rational[815730721, 2951578112]}, {
      0.04395297975430982, 0.27637104289517106`}], 0.03]}, InsetBox[
    StyleBox["8",
     StripOnInput->False,
     FrontFaceColor->GrayLevel[1],
     BackFaceColor->GrayLevel[1],
     GraphicsColor->GrayLevel[1],
     FontFamily->"Times",
     FontSize->16,
     FontWeight->Bold,
     FontColor->GrayLevel[1]], 
    NCache[{Rational[129730653, 2951578112], Rational[
      815730721, 2951578112]}, {0.04395297975430982, 
     0.27637104289517106`}]], 
   {GrayLevel[
     NCache[
      Rational[9, 40], 0.225]], EdgeForm[Thickness[Large]], 
    DiskBox[NCache[{
      Rational[1686498489, 41322093568], Rational[
       10604499373, 41322093568]}, {0.040813481200430546`, 
      0.25663025411694457`}], 0.03]}, InsetBox[
    StyleBox["9",
     StripOnInput->False,
     FrontFaceColor->GrayLevel[1],
     BackFaceColor->GrayLevel[1],
     GraphicsColor->GrayLevel[1],
     FontFamily->"Times",
     FontSize->16,
     FontWeight->Bold,
     FontColor->GrayLevel[1]], 
    NCache[{Rational[1686498489, 41322093568], Rational[
      10604499373, 41322093568]}, {0.040813481200430546`, 
     0.25663025411694457`}]], 
   {GrayLevel[
     NCache[
      Rational[1, 4], 0.25]], EdgeForm[Thickness[Large]], 
    DiskBox[NCache[{
      Rational[15178486401, 578509309952], Rational[
       137858491849, 578509309952]}, {0.026237237914562495`, 
      0.23829952168001994`}], 0.03]}, InsetBox[
    StyleBox["10",
     StripOnInput->False,
     FrontFaceColor->GrayLevel[1],
     BackFaceColor->GrayLevel[1],
     GraphicsColor->GrayLevel[1],
     FontFamily->"Times",
     FontSize->16,
     FontWeight->Bold,
     FontColor->GrayLevel[1]], 
    NCache[{Rational[15178486401, 578509309952], Rational[
      137858491849, 578509309952]}, {0.026237237914562495`, 
     0.23829952168001994`}]], 
   {GrayLevel[
     NCache[
      Rational[11, 40], 0.275]], EdgeForm[Thickness[Large]], 
    DiskBox[NCache[{
      Rational[136606377609, 8099130339328], Rational[
       1792160394037, 8099130339328]}, {0.016866795802218747`, 
      0.22127812727430424`}], 0.03]}, InsetBox[
    StyleBox["11",
     StripOnInput->False,
     FrontFaceColor->GrayLevel[1],
     BackFaceColor->GrayLevel[1],
     GraphicsColor->GrayLevel[1],
     FontFamily->"Times",
     FontSize->16,
     FontWeight->Bold,
     FontColor->GrayLevel[1]], 
    NCache[{Rational[136606377609, 8099130339328], Rational[
      1792160394037, 8099130339328]}, {0.016866795802218747`, 
     0.22127812727430424`}]], 
   {GrayLevel[
     NCache[
      Rational[3, 10], 0.3]], EdgeForm[Thickness[Large]], 
    DiskBox[NCache[{
      Rational[1775882908917, 113387824750592], Rational[
       23298085122481, 113387824750592]}, {0.015662024673488834`, 
      0.20547254675471108`}], 0.03]}, InsetBox[
    StyleBox["12",
     StripOnInput->False,
     FrontFaceColor->GrayLevel[1],
     BackFaceColor->GrayLevel[1],
     GraphicsColor->GrayLevel[1],
     FontFamily->"Times",
     FontSize->16,
     FontWeight->Bold,
     FontColor->GrayLevel[1]], 
    NCache[{Rational[1775882908917, 113387824750592], Rational[
      23298085122481, 113387824750592]}, {0.015662024673488834`, 
     0.20547254675471108`}]], 
   {GrayLevel[
     NCache[
      Rational[13, 40], 0.325]], EdgeForm[Thickness[Large]], 
    DiskBox[NCache[{
      Rational[23086477815921, 1587429546508288], Rational[
       302875106592253, 1587429546508288]}, {0.01454330862538249, 
      0.1907959362722317}], 0.03]}, InsetBox[
    StyleBox["13",
     StripOnInput->False,
     FrontFaceColor->GrayLevel[1],
     BackFaceColor->GrayLevel[1],
     GraphicsColor->GrayLevel[1],
     FontFamily->"Times",
     FontSize->16,
     FontWeight->Bold,
     FontColor->GrayLevel[1]], 
    NCache[{Rational[23086477815921, 1587429546508288], Rational[
      302875106592253, 1587429546508288]}, {0.01454330862538249, 
     0.1907959362722317}]], 
   {GrayLevel[
     NCache[
      Rational[7, 20], 0.35]], EdgeForm[Thickness[Large]], 
    DiskBox[NCache[{
      Rational[300124211606973, 22224013651116032], Rational[
       3937376385699289, 22224013651116032]}, {0.013504500866426598`, 
      0.17716765510992943`}], 0.03]}, InsetBox[
    StyleBox["14",
     StripOnInput->False,
     FrontFaceColor->GrayLevel[1],
     BackFaceColor->GrayLevel[1],
     GraphicsColor->GrayLevel[1],
     FontFamily->"Times",
     FontSize->16,
     FontWeight->Bold,
     FontColor->GrayLevel[1]], 
    NCache[{Rational[300124211606973, 22224013651116032], Rational[
      3937376385699289, 22224013651116032]}, {0.013504500866426598`, 
     0.17716765510992943`}]], 
   {GrayLevel[
     NCache[
      Rational[3, 8], 0.375]], EdgeForm[Thickness[Large]], 
    DiskBox[NCache[{
      Rational[2701117904462757, 311136191115624448], Rational[
       51185893014090757, 311136191115624448]}, {0.008681464842702814, 
      0.16451282260207736`}], 0.03]}, InsetBox[
    StyleBox["15",
     StripOnInput->False,
     FrontFaceColor->GrayLevel[1],
     BackFaceColor->GrayLevel[1],
     GraphicsColor->GrayLevel[1],
     FontFamily->"Times",
     FontSize->16,
     FontWeight->Bold,
     FontColor->GrayLevel[1]], 
    NCache[{Rational[2701117904462757, 311136191115624448], Rational[
      51185893014090757, 311136191115624448]}, {0.008681464842702814, 
     0.16451282260207736`}]], 
   {GrayLevel[
     NCache[
      Rational[2, 5], 0.4]], EdgeForm[Thickness[Large]], 
    DiskBox[NCache[{
      Rational[35114532758015841, 4355906675618742272], Rational[
       665416609183179841, 4355906675618742272]}, {0.008061360211081184, 
      0.15276190670192896`}], 0.03]}, InsetBox[
    StyleBox["16",
     StripOnInput->False,
     FrontFaceColor->GrayLevel[1],
     BackFaceColor->GrayLevel[1],
     GraphicsColor->GrayLevel[1],
     FontFamily->"Times",
     FontSize->16,
     FontWeight->Bold,
     FontColor->GrayLevel[1]], 
    NCache[{Rational[35114532758015841, 4355906675618742272], Rational[
      665416609183179841, 4355906675618742272]}, {0.008061360211081184, 
     0.15276190670192896`}]], 
   {GrayLevel[
     NCache[
      Rational[17, 40], 0.425]], EdgeForm[Thickness[Large]], 
    DiskBox[NCache[{
      Rational[456488925854205933, 60982693458662391808], Rational[
       8650415919381337933, 60982693458662391808]}, {0.007485548767432528, 
      0.14185034193750545`}], 0.03]}, InsetBox[
    StyleBox["17",
     StripOnInput->False,
     FrontFaceColor->GrayLevel[1],
     BackFaceColor->GrayLevel[1],
     GraphicsColor->GrayLevel[1],
     FontFamily->"Times",
     FontSize->16,
     FontWeight->Bold,
     FontColor->GrayLevel[1]], 
    NCache[{Rational[456488925854205933, 60982693458662391808], Rational[
      8650415919381337933, 60982693458662391808]}, {0.007485548767432528, 
     0.14185034193750545`}]], 
   {GrayLevel[
     NCache[
      Rational[9, 20], 0.45]], EdgeForm[Thickness[Large]], 
    DiskBox[
     NCache[{Rational[4108400332687853397, 853757708421273485312], Rational[
       112455406951957393129, 853757708421273485312]}, {
      0.0048121384933494825`, 0.13171817465625507`}], 0.03]}, InsetBox[
    StyleBox["18",
     StripOnInput->False,
     FrontFaceColor->GrayLevel[1],
     BackFaceColor->GrayLevel[1],
     GraphicsColor->GrayLevel[1],
     FontFamily->"Times",
     FontSize->16,
     FontWeight->Bold,
     FontColor->GrayLevel[1]], 
    NCache[{Rational[4108400332687853397, 853757708421273485312], Rational[
      112455406951957393129, 853757708421273485312]}, {0.0048121384933494825`,
      0.13171817465625507`}]], 
   {GrayLevel[
     NCache[
      Rational[19, 40], 0.475]], EdgeForm[Thickness[Large]], 
    DiskBox[NCache[{
      Rational[53409204324942094161, 11952607917897828794368], Rational[
       1461920290375446110677, 11952607917897828794368]}, {
      0.00446841431525309, 0.12230973360937969`}], 0.03]}, InsetBox[
    StyleBox["19",
     StripOnInput->False,
     FrontFaceColor->GrayLevel[1],
     BackFaceColor->GrayLevel[1],
     GraphicsColor->GrayLevel[1],
     FontFamily->"Times",
     FontSize->16,
     FontWeight->Bold,
     FontColor->GrayLevel[1]], 
    NCache[{Rational[53409204324942094161, 11952607917897828794368], Rational[
      1461920290375446110677, 11952607917897828794368]}, {0.00446841431525309,
      0.12230973360937969`}]], 
   {GrayLevel[
     NCache[
      Rational[1, 2], 0.5]], EdgeForm[Thickness[Large]], 
    DiskBox[NCache[{
      Rational[694319656224247224093, 167336510850569603121152], Rational[
       19004963774880799438801, 167336510850569603121152]}, {
      0.004149241864163584, 0.11357332406585259`}], 0.03]}, InsetBox[
    StyleBox["20",
     StripOnInput->False,
     FrontFaceColor->GrayLevel[0],
     BackFaceColor->GrayLevel[0],
     GraphicsColor->GrayLevel[0],
     FontFamily->"Times",
     FontSize->16,
     FontWeight->Bold,
     FontColor->GrayLevel[0]], 
    NCache[{Rational[694319656224247224093, 167336510850569603121152], 
      Rational[19004963774880799438801, 167336510850569603121152]}, {
     0.004149241864163584, 0.11357332406585259`}]], 
   {GrayLevel[
     NCache[
      Rational[21, 40], 0.525]], EdgeForm[Thickness[Large]], 
    DiskBox[NCache[{
      Rational[9026155530915213913209, 2342711151907974443696128], Rational[
       247064529073450392704413, 2342711151907974443696128]}, {
      0.003852867445294756, 0.10546094377543454`}], 0.03]}, InsetBox[
    StyleBox["21",
     StripOnInput->False,
     FrontFaceColor->GrayLevel[0],
     BackFaceColor->GrayLevel[0],
     GraphicsColor->GrayLevel[0],
     FontFamily->"Times",
     FontSize->16,
     FontWeight->Bold,
     FontColor->GrayLevel[0]], 
    NCache[{Rational[9026155530915213913209, 2342711151907974443696128], 
      Rational[247064529073450392704413, 2342711151907974443696128]}, {
     0.003852867445294756, 0.10546094377543454`}]], 
   {GrayLevel[
     NCache[
      Rational[11, 20], 0.55]], EdgeForm[Thickness[Large]], 
    DiskBox[NCache[{
      Rational[117340021901897780871717, 32797956126711642211745792], 
       Rational[3211838877954855105157369, 32797956126711642211745792]}, {
      0.0035776626277737025`, 0.09792801922004636}], 0.03]}, InsetBox[
    StyleBox["22",
     StripOnInput->False,
     FrontFaceColor->GrayLevel[0],
     BackFaceColor->GrayLevel[0],
     GraphicsColor->GrayLevel[0],
     FontFamily->"Times",
     FontSize->16,
     FontWeight->Bold,
     FontColor->GrayLevel[0]], 
    NCache[{Rational[117340021901897780871717, 32797956126711642211745792], 
      Rational[3211838877954855105157369, 32797956126711642211745792]}, {
     0.0035776626277737025`, 0.09792801922004636}]], 
   {GrayLevel[
     NCache[
      Rational[23, 40], 0.575]], EdgeForm[Thickness[Large]], 
    DiskBox[NCache[{
      Rational[1525420284724671151332321, 459171385773962990964441088], 
       Rational[41753905413413116367045797, 459171385773962990964441088]}, {
      0.0033221152972184383`, 0.09093316070432877}], 0.03]}, InsetBox[
    StyleBox["23",
     StripOnInput->False,
     FrontFaceColor->GrayLevel[0],
     BackFaceColor->GrayLevel[0],
     GraphicsColor->GrayLevel[0],
     FontFamily->"Times",
     FontSize->16,
     FontWeight->Bold,
     FontColor->GrayLevel[0]], 
    NCache[{Rational[1525420284724671151332321, 459171385773962990964441088], 
      Rational[41753905413413116367045797, 459171385773962990964441088]}, {
     0.0033221152972184383`, 0.09093316070432877}]], 
   {GrayLevel[
     NCache[
      Rational[3, 5], 0.6]], EdgeForm[Thickness[Large]], 
    DiskBox[NCache[{
      Rational[19830463701420724967320173, 6428399400835481873502175232], 
       Rational[542800770374370512771595361, 6428399400835481873502175232]}, {
      0.003084821347417121, 0.08443793493973385}], 0.03]}, InsetBox[
    StyleBox["24",
     StripOnInput->False,
     FrontFaceColor->GrayLevel[0],
     BackFaceColor->GrayLevel[0],
     GraphicsColor->GrayLevel[0],
     FontFamily->"Times",
     FontSize->16,
     FontWeight->Bold,
     FontColor->GrayLevel[0]], 
    NCache[{Rational[
      19830463701420724967320173, 6428399400835481873502175232], Rational[
      542800770374370512771595361, 6428399400835481873502175232]}, {
     0.003084821347417121, 0.08443793493973385}]], 
   {GrayLevel[
     NCache[
      Rational[5, 8], 0.625]], EdgeForm[Thickness[Large]], 
    DiskBox[NCache[{
      Rational[257796028118469424575162249, 89997591611696746229030453248], 
       Rational[
       7056410014866816666030739693, 89997591611696746229030453248]}, {
      0.0028644769654587554`, 0.07840665387261002}], 0.03]}, InsetBox[
    StyleBox["25",
     StripOnInput->False,
     FrontFaceColor->GrayLevel[0],
     BackFaceColor->GrayLevel[0],
     GraphicsColor->GrayLevel[0],
     FontFamily->"Times",
     FontSize->16,
     FontWeight->Bold,
     FontColor->GrayLevel[0]], 
    NCache[{Rational[
      257796028118469424575162249, 89997591611696746229030453248], Rational[
      7056410014866816666030739693, 89997591611696746229030453248]}, {
     0.0028644769654587554`, 0.07840665387261002}]], 
   {GrayLevel[
     NCache[
      Rational[13, 20], 0.65]], EdgeForm[Thickness[Large]], 
    DiskBox[NCache[{
      Rational[3351348365540102519477109237, 1259966282563754447206426345472],
        Rational[
       91733330193268616658399616009, 1259966282563754447206426345472]}, {
      0.002659871467925987, 0.07280617859599502}], 0.03]}, InsetBox[
    StyleBox["26",
     StripOnInput->False,
     FrontFaceColor->GrayLevel[0],
     BackFaceColor->GrayLevel[0],
     GraphicsColor->GrayLevel[0],
     FontFamily->"Times",
     FontSize->16,
     FontWeight->Bold,
     FontColor->GrayLevel[0]], 
    NCache[{Rational[
      3351348365540102519477109237, 1259966282563754447206426345472], 
      Rational[91733330193268616658399616009, 
       1259966282563754447206426345472]}, {0.002659871467925987, 
     0.07280617859599502}]], 
   {GrayLevel[
     NCache[
      Rational[27, 40], 0.675]], EdgeForm[Thickness[Large]], 
    DiskBox[NCache[{
      Rational[43567528752021332753202420081, 
        17639527955892562260889968836608], Rational[
       1192533292512492016559195008117, 17639527955892562260889968836608]}, {
      0.0024698806487884165`, 0.06760573726770966}], 0.03]}, InsetBox[
    StyleBox["27",
     StripOnInput->False,
     FrontFaceColor->GrayLevel[0],
     BackFaceColor->GrayLevel[0],
     GraphicsColor->GrayLevel[0],
     FontFamily->"Times",
     FontSize->16,
     FontWeight->Bold,
     FontColor->GrayLevel[0]], 
    NCache[{Rational[
      43567528752021332753202420081, 17639527955892562260889968836608], 
      Rational[1192533292512492016559195008117, 
       17639527955892562260889968836608]}, {0.0024698806487884165`, 
     0.06760573726770966}]], 
   {GrayLevel[
     NCache[
      Rational[7, 10], 0.7]], EdgeForm[Thickness[Large]], 
    DiskBox[NCache[{
      Rational[566377873776277325791631461053, 
        246953391382495871652459563712512], Rational[
       15502932802662396215269535105521, 
        246953391382495871652459563712512]}, {0.002293460602446387, 
      0.06277675603430181}], 0.03]}, InsetBox[
    StyleBox["28",
     StripOnInput->False,
     FrontFaceColor->GrayLevel[0],
     BackFaceColor->GrayLevel[0],
     GraphicsColor->GrayLevel[0],
     FontFamily->"Times",
     FontSize->16,
     FontWeight->Bold,
     FontColor->GrayLevel[0]], 
    NCache[{Rational[
      566377873776277325791631461053, 246953391382495871652459563712512], 
      Rational[15502932802662396215269535105521, 
       246953391382495871652459563712512]}, {0.002293460602446387, 
     0.06277675603430181}]], 
   {GrayLevel[
     NCache[
      Rational[29, 40], 0.725]], EdgeForm[Thickness[Large]], 
    DiskBox[NCache[{
      Rational[7362912359091605235291208993689, 
        3457347479354942203134433891975168], Rational[
       201538126434611150798503956371773, 
        3457347479354942203134433891975168]}, {0.0021296419879859303`, 
      0.05829270203185168}], 0.03]}, InsetBox[
    StyleBox["29",
     StripOnInput->False,
     FrontFaceColor->GrayLevel[0],
     BackFaceColor->GrayLevel[0],
     GraphicsColor->GrayLevel[0],
     FontFamily->"Times",
     FontSize->16,
     FontWeight->Bold,
     FontColor->GrayLevel[0]], 
    NCache[{Rational[
      7362912359091605235291208993689, 3457347479354942203134433891975168], 
      Rational[201538126434611150798503956371773, 
       3457347479354942203134433891975168]}, {0.0021296419879859303`, 
     0.05829270203185168}]], 
   {GrayLevel[
     NCache[
      Rational[3, 4], 0.75]], EdgeForm[Thickness[Large]], 
    DiskBox[NCache[{
      Rational[95717860668190868058785716917957, 
        48402864710969190843882074487652352], Rational[
       2619995643649944960380551432833049, 
        48402864710969190843882074487652352]}, {0.001977524703129793, 
      0.05412893760100515}], 0.03]}, InsetBox[
    StyleBox["30",
     StripOnInput->False,
     FrontFaceColor->GrayLevel[0],
     BackFaceColor->GrayLevel[0],
     GraphicsColor->GrayLevel[0],
     FontFamily->"Times",
     FontSize->16,
     FontWeight->Bold,
     FontColor->GrayLevel[0]], 
    NCache[{Rational[
      95717860668190868058785716917957, 48402864710969190843882074487652352], 
      Rational[2619995643649944960380551432833049, 
       48402864710969190843882074487652352]}, {0.001977524703129793, 
     0.05412893760100515}]], 
   {GrayLevel[
     NCache[
      Rational[31, 40], 0.775]], EdgeForm[Thickness[Large]], 
    DiskBox[NCache[{
      Rational[1244332188686481284764214319933441, 
        677640105953568671814349042827132928], Rational[
       34059943367449284484947168626829637, 
        677640105953568671814349042827132928]}, {0.0018362729386205217`, 
      0.05026258491521905}], 0.03]}, InsetBox[
    StyleBox["31",
     StripOnInput->False,
     FrontFaceColor->GrayLevel[0],
     BackFaceColor->GrayLevel[0],
     GraphicsColor->GrayLevel[0],
     FontFamily->"Times",
     FontSize->16,
     FontWeight->Bold,
     FontColor->GrayLevel[0]], 
    NCache[{Rational[
      1244332188686481284764214319933441, 
       677640105953568671814349042827132928], Rational[
      34059943367449284484947168626829637, 
       677640105953568671814349042827132928]}, {0.0018362729386205217`, 
     0.05026258491521905}]], 
   {GrayLevel[
     NCache[
      Rational[4, 5], 0.8]], EdgeForm[Thickness[Large]], 
    DiskBox[NCache[{
      Rational[16176318452924256701934786159134733, 
        9486961483349961405400886599579860992], Rational[
       442779263776840698304313192148785281, 
        9486961483349961405400886599579860992]}, {0.001705110585861913, 
      0.046672400278417694`}], 0.03]}, InsetBox[
    StyleBox["32",
     StripOnInput->False,
     FrontFaceColor->GrayLevel[0],
     BackFaceColor->GrayLevel[0],
     GraphicsColor->GrayLevel[0],
     FontFamily->"Times",
     FontSize->16,
     FontWeight->Bold,
     FontColor->GrayLevel[0]], 
    NCache[{Rational[
      16176318452924256701934786159134733, 
       9486961483349961405400886599579860992], Rational[
      442779263776840698304313192148785281, 
       9486961483349961405400886599579860992]}, {0.001705110585861913, 
     0.046672400278417694`}]], 
   {GrayLevel[
     NCache[
      Rational[33, 40], 0.825]], EdgeForm[Thickness[Large]], 
    DiskBox[NCache[{
      Rational[210292139888015337125152220068751529, 
        132817460766899459675612412394118053888], Rational[
       5756130429098929077956071497934208653, 
        132817460766899459675612412394118053888]}, {0.0015833169725860622`, 
      0.04333865740138786}], 0.03]}, InsetBox[
    StyleBox["33",
     StripOnInput->False,
     FrontFaceColor->GrayLevel[0],
     BackFaceColor->GrayLevel[0],
     GraphicsColor->GrayLevel[0],
     FontFamily->"Times",
     FontSize->16,
     FontWeight->Bold,
     FontColor->GrayLevel[0]], 
    NCache[{Rational[
      210292139888015337125152220068751529, 
       132817460766899459675612412394118053888], Rational[
      5756130429098929077956071497934208653, 
       132817460766899459675612412394118053888]}, {0.0015833169725860622`, 
     0.04333865740138786}]], 
   {GrayLevel[
     NCache[
      Rational[17, 20], 0.85]], EdgeForm[Thickness[Large]], 
    DiskBox[NCache[{
      Rational[2733797818544199382626978860893769877, 
        1859444450736592435458573773517652754432], Rational[
       74829695578286078013428929473144712489, 
        1859444450736592435458573773517652754432]}, {0.0014702229031156291`, 
      0.040243039015574446`}], 0.03]}, InsetBox[
    StyleBox["34",
     StripOnInput->False,
     FrontFaceColor->GrayLevel[0],
     BackFaceColor->GrayLevel[0],
     GraphicsColor->GrayLevel[0],
     FontFamily->"Times",
     FontSize->16,
     FontWeight->Bold,
     FontColor->GrayLevel[0]], 
    NCache[{Rational[
      2733797818544199382626978860893769877, 
       1859444450736592435458573773517652754432], Rational[
      74829695578286078013428929473144712489, 
       1859444450736592435458573773517652754432]}, {0.0014702229031156291`, 
     0.040243039015574446`}]], 
   {GrayLevel[
     NCache[
      Rational[7, 8], 0.875]], EdgeForm[Thickness[Large]], 
    DiskBox[NCache[{
      Rational[35539371641074591974150725191619008401, 
        26032222310312294096420032829247138562048], Rational[
       972786042517719014174576083150881262357, 
        26032222310312294096420032829247138562048]}, {0.0013652069814645128`, 
      0.0373685362287477}], 0.03]}, InsetBox[
    StyleBox["35",
     StripOnInput->False,
     FrontFaceColor->GrayLevel[0],
     BackFaceColor->GrayLevel[0],
     GraphicsColor->GrayLevel[0],
     FontFamily->"Times",
     FontSize->16,
     FontWeight->Bold,
     FontColor->GrayLevel[0]], 
    NCache[{Rational[
      35539371641074591974150725191619008401, 
       26032222310312294096420032829247138562048], Rational[
      972786042517719014174576083150881262357, 
       26032222310312294096420032829247138562048]}, {0.0013652069814645128`, 
     0.0373685362287477}]], 
   {GrayLevel[
     NCache[
      Rational[9, 10], 0.9]], EdgeForm[Thickness[Large]], 
    DiskBox[NCache[{
      Rational[462011831333969695663959427491047109213, 
        364451112344372117349880459609459939868672], Rational[
       12646218552730347184269489080961456410641, 
        364451112344372117349880459609459939868672]}, {0.0012676921970741905`,
       0.03469935506955143}], 0.03]}, InsetBox[
    StyleBox["36",
     StripOnInput->False,
     FrontFaceColor->GrayLevel[0],
     BackFaceColor->GrayLevel[0],
     GraphicsColor->GrayLevel[0],
     FontFamily->"Times",
     FontSize->16,
     FontWeight->Bold,
     FontColor->GrayLevel[0]], 
    NCache[{Rational[
      462011831333969695663959427491047109213, 
       364451112344372117349880459609459939868672], Rational[
      12646218552730347184269489080961456410641, 
       364451112344372117349880459609459939868672]}, {0.0012676921970741905`, 
     0.03469935506955143}]], 
   {GrayLevel[
     NCache[
      Rational[37, 40], 0.925]], EdgeForm[Thickness[Large]], 
    DiskBox[NCache[{
      Rational[6006153807341606043631472557383612419769, 
        5102315572821209642898326434532439158161408], Rational[
       164400841185494513395503358052498933338333, 
        5102315572821209642898326434532439158161408]}, {0.001177142754426034, 
      0.03222082970744061}], 0.03]}, InsetBox[
    StyleBox["37",
     StripOnInput->False,
     FrontFaceColor->GrayLevel[0],
     BackFaceColor->GrayLevel[0],
     GraphicsColor->GrayLevel[0],
     FontFamily->"Times",
     FontSize->16,
     FontWeight->Bold,
     FontColor->GrayLevel[0]], 
    NCache[{Rational[
      6006153807341606043631472557383612419769, 
       5102315572821209642898326434532439158161408], Rational[
      164400841185494513395503358052498933338333, 
       5102315572821209642898326434532439158161408]}, {0.001177142754426034, 
     0.03222082970744061}]], 
   {GrayLevel[
     NCache[
      Rational[19, 20], 0.95]], EdgeForm[Thickness[Large]], 
    DiskBox[NCache[{
      Rational[78079999495440878567209143245986961456997, 
        71432418019496935000576570083454148214259712], Rational[
       2137210935411428674141543654682486133398329, 
        71432418019496935000576570083454148214259712]}, {
      0.0010930611291098886`, 0.029919341871194854`}], 0.03]}, InsetBox[
    StyleBox["38",
     StripOnInput->False,
     FrontFaceColor->GrayLevel[0],
     BackFaceColor->GrayLevel[0],
     GraphicsColor->GrayLevel[0],
     FontFamily->"Times",
     FontSize->16,
     FontWeight->Bold,
     FontColor->GrayLevel[0]], 
    NCache[{Rational[
      78079999495440878567209143245986961456997, 
       71432418019496935000576570083454148214259712], Rational[
      2137210935411428674141543654682486133398329, 
       71432418019496935000576570083454148214259712]}, {
     0.0010930611291098886`, 0.029919341871194854`}]], 
   {GrayLevel[
     NCache[
      Rational[39, 40], 0.975]], EdgeForm[Thickness[Large]], 
    DiskBox[
     NCache[{Rational[
       1015039993440731421373718862197830498940961, 
        1000053852272957090008071981168358074999635968], Rational[
       27783742160348572763840067510872319734178277, 
        1000053852272957090008071981168358074999635968]}, {
      0.0010149853341734681`, 0.027782246023252365`}], 0.03]}, InsetBox[
    StyleBox["39",
     StripOnInput->False,
     FrontFaceColor->GrayLevel[0],
     BackFaceColor->GrayLevel[0],
     GraphicsColor->GrayLevel[0],
     FontFamily->"Times",
     FontSize->16,
     FontWeight->Bold,
     FontColor->GrayLevel[0]], 
    NCache[{Rational[
      1015039993440731421373718862197830498940961, 
       1000053852272957090008071981168358074999635968], Rational[
      27783742160348572763840067510872319734178277, 
       1000053852272957090008071981168358074999635968]}, {
     0.0010149853341734681`, 0.027782246023252365`}]], 
   {GrayLevel[1], EdgeForm[Thickness[Large]], 
    DiskBox[NCache[{
      Rational[13195519914729508477858345208571796486232493, 
        14000753931821399260113007736357013049994903552], Rational[
       361188648084531445929920877641340156544317601, 
        14000753931821399260113007736357013049994903552]}, {
      0.0009424863817325059, 0.02579779987873434}], 0.03]}, InsetBox[
    StyleBox["40",
     StripOnInput->False,
     FrontFaceColor->GrayLevel[0],
     BackFaceColor->GrayLevel[0],
     GraphicsColor->GrayLevel[0],
     FontFamily->"Times",
     FontSize->16,
     FontWeight->Bold,
     FontColor->GrayLevel[0]], 
    NCache[{Rational[
      13195519914729508477858345208571796486232493, 
       14000753931821399260113007736357013049994903552], Rational[
      361188648084531445929920877641340156544317601, 
       14000753931821399260113007736357013049994903552]}, {
     0.0009424863817325059, 0.02579779987873434}]]},
  AspectRatio->Automatic,
  Axes->True,
  AxesLabel->{
    FormBox["\"Prob C Player1\"", TraditionalForm], 
    FormBox["\"Prob C Player2\"", TraditionalForm]},
  AxesOrigin->{-0.025, -0.025},
  ImageSize->{559., Automatic},
  PlotLabel->FormBox["\"Simulation\"", TraditionalForm],
  PlotRange->{{-0.14, 1.03}, {-0.14, 1.03}}]], "Output",
 CellChangeTimes->{
  3.39268777084375*^9, 3.392688027265625*^9, 3.392689641390625*^9, 
   3.39269969359375*^9, 3.392700077578125*^9, {3.3927014299375*^9, 
   3.392701446328125*^9}, 3.3927055258125*^9, 3.392705666125*^9, 
   3.392706634609375*^9, 3.392707142203125*^9, 3.392707211546875*^9, 
   3.392707260859375*^9, 3.392752806390625*^9, 3.39275907046875*^9, 
   3.392759141671875*^9, 3.392759186890625*^9, 3.392759242734375*^9, 
   3.39275985421875*^9, 3.3927606705625*^9, 3.39276094128125*^9, {
   3.392761374578125*^9, 3.3927613910625*^9}, 3.392763113890625*^9, 
   3.39276361009375*^9, 3.392763753875*^9, 3.392763953015625*^9, 
   3.39276420715625*^9, 3.392764341140625*^9, 3.392764902265625*^9, 
   3.39277691815625*^9, 3.392777824125*^9, 3.39285504190625*^9, {
   3.3928552391875*^9, 3.39285528028125*^9}, {3.392855386578125*^9, 
   3.392855403296875*^9}, {3.392855437125*^9, 3.39285544125*^9}, 
   3.39285549821875*^9, 3.392856977609375*^9, {3.392857068375*^9, 
   3.392857092125*^9}, 3.39285951640625*^9, 3.392859737953125*^9, 
   3.3928597765625*^9, 3.392860167*^9, 3.392860290609375*^9, 
   3.3928606321875*^9, 3.39286362896875*^9, 3.39286371959375*^9, 
   3.392863766578125*^9, 3.39286960365625*^9, 3.393406906359375*^9, 
   3.393407033984375*^9, 3.39340733725*^9, 3.393407613046875*^9, 
   3.393436890234375*^9, 3.3934369596875*^9, {3.39343727009375*^9, 
   3.393437282734375*^9}, {3.393437333484375*^9, 3.39343733715625*^9}, 
   3.39343737471875*^9, 3.39343751671875*^9, 3.39343764178125*^9, {
   3.39343776615625*^9, 3.393437794625*^9}, 3.3934378305625*^9, 
   3.3934378828125*^9, 3.3934380165625*^9, {3.3934380966875*^9, 
   3.393438118140625*^9}, 3.393438165765625*^9, {3.39343856584375*^9, 
   3.393438592546875*^9}, 3.393438790546875*^9, {3.393438902421875*^9, 
   3.393438931125*^9}, 3.3934397256875*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Figure - Creation", "Section"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"maxNorm", "=", 
    RowBox[{
     RowBox[{"NMaximize", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"expChangeNorm", "[", 
          RowBox[{"x", ",", "y"}], "]"}], ",", 
         RowBox[{
          RowBox[{"0", "\[LessEqual]", "x", "\[LessEqual]", "1"}], "&&", 
          RowBox[{"0", "\[LessEqual]", "y", "\[LessEqual]", "1"}]}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "y"}], "}"}]}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"gFigure", "=", 
   RowBox[{"Show", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"DensityPlot", "[", 
      RowBox[{
       RowBox[{"Rescale", "[", 
        RowBox[{
         RowBox[{"expChangeNorm", "[", 
          RowBox[{"x", ",", "y"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "maxNorm"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"380", ",", "680"}], "}"}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "0", ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"y", ",", "0", ",", "1"}], "}"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.04"}], ",", "1.04"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.04"}], ",", "1.04"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"BaseStyle", "\[Rule]", 
        RowBox[{"Directive", "[", 
         RowBox[{
          RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
          RowBox[{"FontSize", "\[Rule]", 
           RowBox[{"20", "*", "textScaleFactor"}]}]}], "]"}]}], ",", 
       RowBox[{"ColorFunction", "\[Rule]", 
        RowBox[{"ColorData", "[", "\"\<VisibleSpectrum\>\"", "]"}]}], ",", 
       RowBox[{"ColorFunctionScaling", "\[Rule]", "False"}], ",", 
       RowBox[{"FrameStyle", "\[Rule]", "Thick"}], ",", 
       RowBox[{"FrameTicksStyle", "\[Rule]", "Thick"}], ",", 
       RowBox[{"FrameTicks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"0", ",", "\"\< 0 \>\"", ",", ".02"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"0.2", ",", "\"\< 0.2 \>\"", ",", ".02"}], "}"}], ",", 
              
              RowBox[{"{", 
               RowBox[{"0.4", ",", "\"\< 0.4 \>\"", ",", ".02"}], "}"}], ",", 
              
              RowBox[{"{", 
               RowBox[{"0.6", ",", "\"\< 0.6 \>\"", ",", ".02"}], "}"}], ",", 
              
              RowBox[{"{", 
               RowBox[{"0.8", ",", "\"\< 0.8 \>\"", ",", ".02"}], "}"}], ",", 
              
              RowBox[{"{", 
               RowBox[{"1", ",", "\"\< 1 \>\"", ",", ".02"}], "}"}]}], "}"}], 
            ",", "None"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"0", ",", "0", ",", ".02"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"0.2", ",", "0.2", ",", ".02"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"0.4", ",", "0.4", ",", ".02"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"0.6", ",", "0.6", ",", ".02"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"0.8", ",", "0.8", ",", ".02"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"1", ",", "1", ",", ".02"}], "}"}]}], "}"}], ",", 
            "None"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"FrameLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Text", "[", 
             RowBox[{"Style", "[", 
              RowBox[{"\"\<Probability of Cooperating, Player1\>\"", ",", 
               RowBox[{"FontSize", "\[Rule]", 
                RowBox[{"26", "*", "textScaleFactor"}]}], ",", 
               RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}]}], "]"}], 
             "]"}], ",", "None"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Text", "[", 
             RowBox[{"Style", "[", 
              RowBox[{"\"\<Probability of Cooperating, Player2\>\"", ",", 
               RowBox[{"FontSize", "\[Rule]", 
                RowBox[{"26", "*", "textScaleFactor"}]}], ",", 
               RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}]}], "]"}], 
             "]"}], ",", "None"}], "}"}]}], "}"}]}]}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"expectedMovementArrowsAndPoints", ",", "listOfProb"}], "}"}], 
      "]"}]}], "\[IndentingNewLine]", "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"myLegend", "=", 
   RowBox[{"DensityPlot", "[", 
    RowBox[{
     RowBox[{"Rescale", "[", 
      RowBox[{"y", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"380", ",", "680"}], "}"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0", ",", ".07"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", "0", ",", "1"}], "}"}], ",", 
     RowBox[{"ColorFunction", "\[Rule]", 
      RowBox[{"ColorData", "[", "\"\<VisibleSpectrum\>\"", "]"}]}], ",", 
     RowBox[{"ColorFunctionScaling", "\[Rule]", "False"}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "Automatic"}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"FrameStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"White", ",", "White"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"White", ",", "White"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Axes", "\[Rule]", "False"}], ",", 
     RowBox[{"FrameTicksStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Directive", "[", 
         RowBox[{"Black", ",", 
          RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
          RowBox[{"FontSize", "\[Rule]", 
           RowBox[{"15", "*", "textScaleFactor"}]}]}], "]"}], ",", "Thick"}], 
       "}"}]}], ",", 
     RowBox[{"FrameTicks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"None", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0", ",", "\"\< 0 \>\"", ",", 
              RowBox[{"textScaleFactor", "/", "10"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"1", "/", "7"}], ",", 
              RowBox[{"Round", "[", 
               RowBox[{
                RowBox[{"Rescale", "[", 
                 RowBox[{
                  RowBox[{"1", "/", "7"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"0", ",", "1"}], "}"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"0", ",", "maxNorm"}], "}"}]}], "]"}], ",", 
                "0.01"}], "]"}], ",", 
              RowBox[{"textScaleFactor", "/", "10"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"2", "/", "7"}], ",", 
              RowBox[{"Round", "[", 
               RowBox[{
                RowBox[{"Rescale", "[", 
                 RowBox[{
                  RowBox[{"2", "/", "7"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"0", ",", "1"}], "}"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"0", ",", "maxNorm"}], "}"}]}], "]"}], ",", 
                "0.01"}], "]"}], ",", 
              RowBox[{"textScaleFactor", "/", "10"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"3", "/", "7"}], ",", 
              RowBox[{"Round", "[", 
               RowBox[{
                RowBox[{"Rescale", "[", 
                 RowBox[{
                  RowBox[{"3", "/", "7"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"0", ",", "1"}], "}"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"0", ",", "maxNorm"}], "}"}]}], "]"}], ",", 
                "0.01"}], "]"}], ",", 
              RowBox[{"textScaleFactor", "/", "10"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"4", "/", "7"}], ",", 
              RowBox[{"Round", "[", 
               RowBox[{
                RowBox[{"Rescale", "[", 
                 RowBox[{
                  RowBox[{"4", "/", "7"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"0", ",", "1"}], "}"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"0", ",", "maxNorm"}], "}"}]}], "]"}], ",", 
                "0.01"}], "]"}], ",", 
              RowBox[{"textScaleFactor", "/", "10"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"5", "/", "7"}], ",", 
              RowBox[{"Round", "[", 
               RowBox[{
                RowBox[{"Rescale", "[", 
                 RowBox[{
                  RowBox[{"5", "/", "7"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"0", ",", "1"}], "}"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"0", ",", "maxNorm"}], "}"}]}], "]"}], ",", 
                "0.01"}], "]"}], ",", 
              RowBox[{"textScaleFactor", "/", "10"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"6", "/", "7"}], ",", 
              RowBox[{"Round", "[", 
               RowBox[{
                RowBox[{"Rescale", "[", 
                 RowBox[{
                  RowBox[{"6", "/", "7"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"0", ",", "1"}], "}"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"0", ",", "maxNorm"}], "}"}]}], "]"}], ",", 
                "0.01"}], "]"}], ",", 
              RowBox[{"textScaleFactor", "/", "10"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"1", ",", 
              RowBox[{"Round", "[", 
               RowBox[{
                RowBox[{"Rescale", "[", 
                 RowBox[{"1", ",", 
                  RowBox[{"{", 
                   RowBox[{"0", ",", "1"}], "}"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"0", ",", "maxNorm"}], "}"}]}], "]"}], ",", 
                "0.01"}], "]"}], ",", 
              RowBox[{"textScaleFactor", "/", "10"}]}], "}"}]}], "}"}]}], 
         "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"None", ",", "None"}], "}"}]}], "}"}]}]}], "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.392701523421875*^9, 3.392701523703125*^9}, {
   3.392702573453125*^9, 3.39270257371875*^9}, {3.3927030148125*^9, 
   3.392703118265625*^9}, {3.392703163375*^9, 3.392703171984375*^9}, {
   3.3927032033125*^9, 3.39270320359375*^9}, {3.39270337990625*^9, 
   3.392703390703125*^9}, {3.39270342128125*^9, 3.392703426265625*^9}, {
   3.392703581421875*^9, 3.392703612015625*^9}, {3.39270364884375*^9, 
   3.392703842625*^9}, {3.392703921125*^9, 3.39270393590625*^9}, {
   3.392703998203125*^9, 3.3927040098125*^9}, {3.392704154296875*^9, 
   3.392704155015625*^9}, {3.392704189078125*^9, 3.39270424009375*^9}, {
   3.392704672640625*^9, 3.39270468134375*^9}, {3.392704722421875*^9, 
   3.392704743671875*^9}, {3.3927048086875*^9, 3.392704811703125*^9}, {
   3.39270485*^9, 3.392704850375*^9}, {3.392705252828125*^9, 
   3.39270528603125*^9}, {3.392705434328125*^9, 3.39270544184375*^9}, {
   3.39270547371875*^9, 3.392705512703125*^9}, {3.3927055619375*^9, 
   3.392705562265625*^9}, {3.39270562296875*^9, 3.3927057254375*^9}, {
   3.392705793875*^9, 3.392705796828125*^9}, {3.39270583353125*^9, 
   3.392705872515625*^9}, {3.392705925296875*^9, 3.392705972953125*^9}, {
   3.392706138984375*^9, 3.39270614090625*^9}, {3.392706187625*^9, 
   3.39270621371875*^9}, {3.392706303515625*^9, 3.392706628703125*^9}, {
   3.39270673159375*^9, 3.392706762296875*^9}, {3.392706805046875*^9, 
   3.392706809484375*^9}, {3.392707116796875*^9, 3.39270711703125*^9}, {
   3.3927074890625*^9, 3.392707496875*^9}, {3.3927076333125*^9, 
   3.392707637546875*^9}, {3.3927490305625*^9, 3.392749062703125*^9}, {
   3.392749311171875*^9, 3.39274933003125*^9}, {3.39274979828125*^9, 
   3.39274979975*^9}, {3.392750383375*^9, 3.392750409296875*^9}, {
   3.392750580109375*^9, 3.39275066596875*^9}, {3.392751254125*^9, 
   3.3927512629375*^9}, {3.392751294421875*^9, 3.392751303609375*^9}, {
   3.392752301328125*^9, 3.392752399*^9}, {3.39275245875*^9, 
   3.392752481859375*^9}, {3.392752579265625*^9, 3.392752639171875*^9}, {
   3.392752674203125*^9, 3.3927526744375*^9}, {3.392752888109375*^9, 
   3.39275291875*^9}, {3.392753007390625*^9, 3.392753055640625*^9}, 
   3.392753250359375*^9, {3.39275336478125*^9, 3.392753395546875*^9}, {
   3.392753434796875*^9, 3.39275345896875*^9}, {3.392753564015625*^9, 
   3.392753572390625*^9}, {3.392753606140625*^9, 3.3927536084375*^9}, {
   3.392753727328125*^9, 3.3927537615*^9}, {3.39275379271875*^9, 
   3.39275381609375*^9}, {3.392753915703125*^9, 3.392753933640625*^9}, {
   3.392753997796875*^9, 3.392754041734375*^9}, {3.39275416215625*^9, 
   3.392754254765625*^9}, {3.392754319125*^9, 3.39275437690625*^9}, {
   3.39275445153125*^9, 3.392754529921875*^9}, {3.392754564328125*^9, 
   3.39275457628125*^9}, {3.392754616125*^9, 3.392754645359375*^9}, {
   3.392754714921875*^9, 3.392754808703125*^9}, {3.39275492684375*^9, 
   3.3927550234375*^9}, 3.3927550745625*^9, {3.39275514353125*^9, 
   3.392755143875*^9}, {3.39275522740625*^9, 3.3927552941875*^9}, {
   3.392756114828125*^9, 3.39275614515625*^9}, 3.39275618190625*^9, {
   3.392756250875*^9, 3.392756251109375*^9}, {3.39275630290625*^9, 
   3.392756318046875*^9}, {3.392756389140625*^9, 3.392756396640625*^9}, {
   3.392756518984375*^9, 3.392756522703125*^9}, {3.3927566238125*^9, 
   3.39275662565625*^9}, {3.39275667115625*^9, 3.392756720953125*^9}, {
   3.3927568156875*^9, 3.3927569268125*^9}, {3.39275702784375*^9, 
   3.39275707378125*^9}, {3.39275710403125*^9, 3.392757112953125*^9}, {
   3.3927575485*^9, 3.392757579546875*^9}, {3.392757874140625*^9, 
   3.3927578796875*^9}, {3.392757925765625*^9, 3.392757934265625*^9}, {
   3.392757972296875*^9, 3.392757997625*^9}, {3.392758062015625*^9, 
   3.392758139*^9}, {3.39275832*^9, 3.3927583916875*^9}, {
   3.392758432015625*^9, 3.392758459*^9}, {3.392758529109375*^9, 
   3.392758544890625*^9}, {3.392758613625*^9, 3.392758647984375*^9}, {
   3.39275870496875*^9, 3.392758795671875*^9}, {3.392758840625*^9, 
   3.392758857484375*^9}, {3.39275894103125*^9, 3.392758941765625*^9}, {
   3.3927589883125*^9, 3.392759066234375*^9}, {3.39275912846875*^9, 
   3.392759132140625*^9}, {3.392759179*^9, 3.392759218890625*^9}, {
   3.392759458390625*^9, 3.3927595086875*^9}, {3.392760544828125*^9, 
   3.392760552703125*^9}, {3.392760591078125*^9, 3.392760620359375*^9}, {
   3.392760835984375*^9, 3.392760883125*^9}, {3.39276110240625*^9, 
   3.3927611365625*^9}, {3.392761298328125*^9, 3.39276135640625*^9}, {
   3.392762935796875*^9, 3.3927631011875*^9}, {3.39276329821875*^9, 
   3.392763300484375*^9}, 3.3927633378125*^9, {3.392763417*^9, 
   3.392763420609375*^9}, {3.39276347178125*^9, 3.39276348590625*^9}, {
   3.39276353584375*^9, 3.3927635545*^9}, {3.392763801171875*^9, 
   3.392763815453125*^9}, {3.392763857515625*^9, 3.392763897453125*^9}, {
   3.392763977015625*^9, 3.392763980671875*^9}, {3.39276406509375*^9, 
   3.392764069828125*^9}, {3.392764160640625*^9, 3.3927641978125*^9}, {
   3.3927643105*^9, 3.392764332796875*^9}, {3.392764396796875*^9, 
   3.392764397390625*^9}, {3.39276467409375*^9, 3.3927646895625*^9}, {
   3.3927647829375*^9, 3.39276479253125*^9}, {3.392764825546875*^9, 
   3.392764830078125*^9}, {3.392764898234375*^9, 3.39276489846875*^9}, {
   3.39277689565625*^9, 3.392776907734375*^9}, {3.392777192015625*^9, 
   3.392777200328125*^9}, {3.39277743171875*^9, 3.392777636625*^9}, {
   3.39277768496875*^9, 3.39277772025*^9}, {3.392777769078125*^9, 
   3.392777814171875*^9}, {3.39285500003125*^9, 3.392855035234375*^9}, 
   3.3928601516875*^9, {3.392860185109375*^9, 3.392860229109375*^9}, {
   3.3928602665625*^9, 3.39286027878125*^9}, {3.393406873578125*^9, 
   3.393406885515625*^9}, {3.393407000140625*^9, 3.393407019828125*^9}, {
   3.39340720175*^9, 3.39340720521875*^9}, {3.393407252515625*^9, 
   3.393407300671875*^9}, {3.3934075883125*^9, 3.393407603015625*^9}, {
   3.393436904921875*^9, 3.39343693559375*^9}, {3.393437490390625*^9, 
   3.39343750459375*^9}, 3.393437976875*^9, {3.393438011078125*^9, 
   3.393438013921875*^9}, {3.393438556*^9, 3.393438589796875*^9}, {
   3.393438777109375*^9, 3.393438787484375*^9}, {3.39343888046875*^9, 
   3.3934388965*^9}, {3.393438927578125*^9, 3.39343892796875*^9}}],

Cell[BoxData[
 GraphicsBox[{GraphicsComplexBox[CompressedData["
1:eJyFmc1uHEUUhS32PASQ95gdP1seAYkVBF4F5hFmy24Es8kmakWWIgtp0gSj
sUmIbZLBdhL6CQh2l7/bul91KZaVo1Nd3V3n/rfz0Vfff/n1BwcHBx/e/HOL
/lne++Lmd73IvAt+url/83uk633w8fLpcfCTshD8v3e3P38F/3G8/zz4J7d0
+XfwX8bbXwX/bHzhZfDd+Pzr4N+MB3wTvPwM4pPOeeyCozdf74OjF45eOHrh
6IWjF45eOHrh6IWjN/ttEJ/8OK9zwqy3k95Oejvp7aS3k95Oejvp7aS3k95O
ejvpreN03o+TTiN64eiFoxeOXjh64eiFoxeOXjh64ejNeTeIT3k4H6ddpStf
nzD7t5d/e/m3l397+beXf3v5t5d/e/m3l3/rOjOfh13lN+uCG9ELRy8cvXD0
wtELRy8cvXD05ro5iE91dL7OdFVc2m/WBTeiF45eOHrh6IWjF45eOHpzXxgW
rT4xX0e7Ku8cl/abdcGN6IWjF45eOHrh6IWjN/e9YdHqg+h13XRdcd45Lu03
64Ib0QtHLxy9cPTC0Zv7+rBo9Xn0ui+4brquOO8cl/abdcGN6IWjF45eOHrz
3DIsWnMMet333BdcN11XnHeOS/vNuuBG9MLRC0dvnsuGRWtOQ6/7uvue+4Lr
puuK885xab9ZF9yIXjh689w5LFpzKHo9t7ivu++5L7huuq447xyX9pt1wY3o
zXP1sGjN2ej1XOa5xX3dfc99wXXTdcV557i036wLbkRv6zsCvfNzp+cyzy3u
6+577guum64rzjvHpf1mXUOF5byrwKLnQXPdWOQcNteN5b3bwPHxy6fNdePn
44F2zXXjt+OBngWW9bPA4o+LwLLvZWDxzz7wh/GFV4Efj+9/HVh0vg3Efgf6
YX1+3+QX7Ebcgbbn++xMnOZ43coutd2w0/vs6LmKdetEf+ZDZTevcx/nt17W
yS/r8RxoPXmenPxQ7n8cWPLzJLDk4/PAco5/A8vzloEFHgXy3Nb6d+ODfg0s
118E5nhaxj6fm3V0cT6u256s89xs/0kXujkPdoTjv1ae8BzbLefBuqpHrOd6
tW6sd1V9yvnUV/nCOvUF7nXqu+sR68Qf3OvUZ9sn99MHyptNwy/U3U0g8VR2
PQxkfYR7T6o4Y70897fA0b3v/ggkf/xdyTp+dt9lnXPkvrqtzpP7wotm3OX4
4bvjz8hXzg3P8/PzBfvh2c7um8s4Nzpa7/E58hxfv5dzfTq+4E2Fpf+4LpI/
PwXm/rFS3K8iHtg/33dW8s8UR8QJSFznvnQcvITl77Gf9dZ97AeJK/IMO8Kx
L/tZb91H32/NBcxjvs46c0JrjsjfqdP1/L26b84dzHu+zjpzSGtOyd9N03XW
qTetuYZ50tdZJx7zvL9UHTqMukye5Dq2Vv/ZqA/uou6SV9Qj1tnnOkVegfZr
/rvJxd37zwPtR5D18t4J7bf8nb6/e8+E9hPIennPZaD9ArJe3nMdSJ0AqZfl
eWf6e9FJ5B35YjuSn7mfHgVnbsh1Yhv1I88xj9QvD8Of8FxXHquvHMe5OGfO
053y+TT0Ox54bs7rZ2En6jKc5xD/2Bvd5AF11XXW/dd10f2DuGaf6xx6OJ+R
eC7nvKi4kXgucfOq4kbiucThPxU3Es8/j+e4qrjR8YzdibtWXBJHrTjL80sd
B7nvbcNvec7ehf1bcQdnH/GT5+9N+J/34D/u29zNTdQHeK7Tb8Ne6GVO4LnE
J3bBXtgh/z39XN8bD6s893cHOpw3xKvtxzlzHT+KPGA//sEfcPyJnciXXKfP
gue+/lL5sJcd9urje+XDVTwXnvv2pfLhdTwXnvv0ddyHHfAT9kVf/n+Oi7A3
erAn+7An++C2a7HnSnwdfsh9+mnkHZy84ZzEXZ63dpqLTuPcnpc5L/fB/wcR
KxP+
    "], {{
      {GrayLevel[0.8], EdgeForm[None], 
       GraphicsGroupBox[PolygonBox[CompressedData["
1:eJxNmgn4l8MWx9/3lxZaKFyXUMnNviRlSSGJZClRiVyVRGhBFKIS11K4LVS0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         "]]]}, {}, {}, {}}, {}},
    VertexColors->CompressedData["
1:eJytmnk01lvUx9GAUBmipEE0mSpxI3WP1EOkaFBKmUUyhjJEKUrdMpQ0U5HS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     "]], {{
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{0, Rational[1, 20]}, {0, Rational[13, 280]}}, {{
         0, 0.05}, {0, 0.04642857142857143}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{0, Rational[1, 10]}, {0, Rational[13, 140]}}, {{
         0, 0.1}, {0, 0.09285714285714286}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{0, Rational[3, 20]}, {0, Rational[39, 280]}}, {{
         0, 0.15}, {0, 0.1392857142857143}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{0, Rational[1, 5]}, {0, Rational[13, 70]}}, {{
         0, 0.2}, {0, 0.18571428571428572`}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{0, Rational[1, 4]}, {0, Rational[13, 56]}}, {{
         0, 0.25}, {0, 0.23214285714285715`}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{0, Rational[3, 10]}, {0, Rational[39, 140]}}, {{
         0, 0.3}, {0, 0.2785714285714286}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{0, Rational[7, 20]}, {0, Rational[13, 40]}}, {{
         0, 0.35}, {0, 0.325}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{0, Rational[2, 5]}, {0, Rational[13, 35]}}, {{
         0, 0.4}, {0, 0.37142857142857144`}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{0, Rational[9, 20]}, {0, Rational[117, 280]}}, {{
         0, 0.45}, {0, 0.41785714285714287`}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{0, Rational[1, 2]}, {0, Rational[13, 28]}}, {{
         0, 0.5}, {0, 0.4642857142857143}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{0, Rational[11, 20]}, {0, Rational[143, 280]}}, {{
         0, 0.55}, {0, 0.5107142857142857}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{0, Rational[3, 5]}, {0, Rational[39, 70]}}, {{
         0, 0.6}, {0, 0.5571428571428572}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{0, Rational[13, 20]}, {0, Rational[169, 280]}}, {{
         0, 0.65}, {0, 0.6035714285714285}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{0, Rational[7, 10]}, {0, Rational[13, 20]}}, {{
         0, 0.7}, {0, 0.65}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{0, Rational[3, 4]}, {0, Rational[39, 56]}}, {{
         0, 0.75}, {0, 0.6964285714285714}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{0, Rational[4, 5]}, {0, Rational[26, 35]}}, {{
         0, 0.8}, {0, 0.7428571428571429}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{0, Rational[17, 20]}, {0, Rational[221, 280]}}, {{
         0, 0.85}, {0, 0.7892857142857143}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{0, Rational[9, 10]}, {0, Rational[117, 140]}}, {{
         0, 0.9}, {0, 0.8357142857142857}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{0, Rational[19, 20]}, {0, Rational[247, 280]}}, {{
         0, 0.95}, {0, 0.8821428571428571}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{0, 1}, {0, Rational[13, 14]}}, {{0, 1}, {
         0, 0.9285714285714286}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 20], 0}, {Rational[13, 280], 0}}, {{
         0.05, 0}, {0.04642857142857143, 0}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 20], Rational[1, 20]}, {
         Rational[2629, 56000], Rational[2629, 56000]}}, {{0.05, 0.05}, {
        0.04694642857142857, 0.04694642857142857}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 20], Rational[1, 10]}, {
         Rational[1329, 28000], Rational[657, 7000]}}, {{0.05, 0.1}, {
        0.047464285714285716`, 0.09385714285714286}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 20], Rational[3, 20]}, {
         Rational[2687, 56000], Rational[7881, 56000]}}, {{0.05, 0.15}, {
        0.047982142857142855`, 0.14073214285714286`}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 20], Rational[1, 5]}, {
         Rational[97, 2000], Rational[1313, 7000]}}, {{0.05, 0.2}, {0.0485, 
        0.18757142857142858`}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 20], Rational[1, 4]}, {
         Rational[549, 11200], Rational[15, 64]}}, {{0.05, 0.25}, {
        0.04901785714285714, 0.234375}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 20], Rational[3, 10]}, {
         Rational[1387, 28000], Rational[246, 875]}}, {{0.05, 0.3}, {
        0.04953571428571429, 0.28114285714285714`}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 20], Rational[7, 20]}, {
         Rational[2803, 56000], Rational[2623, 8000]}}, {{0.05, 0.35}, {
        0.050053571428571426`, 0.327875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 20], Rational[2, 5]}, {
         Rational[177, 3500], Rational[1311, 3500]}}, {{0.05, 0.4}, {
        0.05057142857142857, 0.37457142857142856`}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 20], Rational[9, 20]}, {
         Rational[2861, 56000], Rational[23589, 56000]}}, {{0.05, 0.45}, {
        0.05108928571428571, 0.42123214285714283`}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 20], Rational[1, 2]}, {
         Rational[289, 5600], Rational[131, 280]}}, {{0.05, 0.5}, {
        0.05160714285714286, 0.46785714285714286`}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 20], Rational[11, 20]}, {
         Rational[417, 8000], Rational[28809, 56000]}}, {{0.05, 0.55}, {
        0.052125, 0.5144464285714285}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 20], Rational[3, 5]}, {
         Rational[737, 14000], Rational[561, 1000]}}, {{0.05, 0.6}, {
        0.052642857142857144`, 0.561}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 20], Rational[13, 20]}, {
         Rational[2977, 56000], Rational[34021, 56000]}}, {{0.05, 0.65}, {
        0.05316071428571428, 0.6075178571428571}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 20], Rational[7, 10]}, {
         Rational[1503, 28000], Rational[327, 500]}}, {{0.05, 0.7}, {
        0.05367857142857143, 0.654}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 20], Rational[3, 4]}, {
         Rational[607, 11200], Rational[1569, 2240]}}, {{0.05, 0.75}, {
        0.05419642857142857, 0.7004464285714286}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 20], Rational[4, 5]}, {
         Rational[383, 7000], Rational[1307, 1750]}}, {{0.05, 0.8}, {
        0.054714285714285715`, 0.7468571428571429}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 20], Rational[17, 20]}, {
         Rational[3093, 56000], Rational[44421, 56000]}}, {{0.05, 0.85}, {
        0.055232142857142855`, 0.7932321428571428}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 20], Rational[9, 10]}, {
         Rational[223, 4000], Rational[5877, 7000]}}, {{0.05, 0.9}, {0.05575, 
        0.8395714285714285}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 20], Rational[19, 20]}, {
         Rational[3151, 56000], Rational[7087, 8000]}}, {{0.05, 0.95}, {
        0.05626785714285714, 0.885875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 20], 1}, {
         Rational[159, 2800], Rational[261, 280]}}, {{0.05, 1}, {
         0.05678571428571429, 0.9321428571428572}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 10], 0}, {Rational[13, 140], 0}}, {{
         0.1, 0}, {0.09285714285714286, 0}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 10], Rational[1, 20]}, {
         Rational[657, 7000], Rational[1329, 28000]}}, {{0.1, 0.05}, {
        0.09385714285714286, 0.047464285714285716`}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 10], Rational[1, 10]}, {
         Rational[83, 875], Rational[83, 875]}}, {{0.1, 0.1}, {
        0.09485714285714286, 0.09485714285714286}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 10], Rational[3, 20]}, {
         Rational[671, 7000], Rational[3981, 28000]}}, {{0.1, 0.15}, {
        0.09585714285714286, 0.14217857142857143`}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 10], Rational[1, 5]}, {
         Rational[339, 3500], Rational[663, 3500]}}, {{0.1, 0.2}, {
        0.09685714285714286, 0.18942857142857142`}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 10], Rational[1, 4]}, {
         Rational[137, 1400], Rational[53, 224]}}, {{0.1, 0.25}, {
        0.09785714285714285, 0.23660714285714285`}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 10], Rational[3, 10]}, {
         Rational[173, 1750], Rational[993, 3500]}}, {{0.1, 0.3}, {
        0.09885714285714285, 0.2837142857142857}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 10], Rational[7, 20]}, {
         Rational[699, 7000], Rational[1323, 4000]}}, {{0.1, 0.35}, {
        0.09985714285714285, 0.33075}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 10], Rational[2, 5]}, {
         Rational[353, 3500], Rational[661, 1750]}}, {{0.1, 0.4}, {
        0.10085714285714285`, 0.3777142857142857}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 10], Rational[9, 20]}, {
         Rational[713, 7000], Rational[11889, 28000]}}, {{0.1, 0.45}, {
        0.10185714285714285`, 0.42460714285714285`}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 10], Rational[1, 2]}, {
         Rational[18, 175], Rational[33, 70]}}, {{0.1, 0.5}, {
        0.10285714285714286`, 0.4714285714285714}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 10], Rational[11, 20]}, {
         Rational[727, 7000], Rational[14509, 28000]}}, {{0.1, 0.55}, {
        0.10385714285714286`, 0.5181785714285714}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 10], Rational[3, 5]}, {
         Rational[367, 3500], Rational[1977, 3500]}}, {{0.1, 0.6}, {
        0.10485714285714286`, 0.5648571428571428}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 10], Rational[13, 20]}, {
         Rational[741, 7000], Rational[17121, 28000]}}, {{0.1, 0.65}, {
        0.10585714285714286`, 0.6114642857142857}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 10], Rational[7, 10]}, {
         Rational[187, 1750], Rational[329, 500]}}, {{0.1, 0.7}, {
        0.10685714285714286`, 0.658}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 10], Rational[3, 4]}, {
         Rational[151, 1400], Rational[789, 1120]}}, {{0.1, 0.75}, {
        0.10785714285714286`, 0.7044642857142858}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 10], Rational[4, 5]}, {
         Rational[381, 3500], Rational[657, 875]}}, {{0.1, 0.8}, {
        0.10885714285714286`, 0.7508571428571429}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 10], Rational[17, 20]}, {
         Rational[769, 7000], Rational[22321, 28000]}}, {{0.1, 0.85}, {
        0.10985714285714286`, 0.7971785714285714}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 10], Rational[9, 10]}, {
         Rational[97, 875], Rational[738, 875]}}, {{0.1, 0.9}, {
        0.11085714285714286`, 0.8434285714285714}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 10], Rational[19, 20]}, {
         Rational[783, 7000], Rational[24909, 28000]}}, {{0.1, 0.95}, {
        0.11185714285714286`, 0.8896071428571428}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 10], 1}, {
         Rational[79, 700], Rational[131, 140]}}, {{0.1, 1}, {
         0.11285714285714285`, 0.9357142857142857}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 20], 0}, {Rational[39, 280], 0}}, {{
         0.15, 0}, {0.1392857142857143, 0}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 20], Rational[1, 20]}, {
         Rational[7881, 56000], Rational[2687, 56000]}}, {{0.15, 0.05}, {
        0.14073214285714286`, 0.047982142857142855`}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 20], Rational[1, 10]}, {
         Rational[3981, 28000], Rational[671, 7000]}}, {{0.15, 0.1}, {
        0.14217857142857143`, 0.09585714285714286}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 20], Rational[3, 20]}, {
         Rational[1149, 8000], Rational[1149, 8000]}}, {{0.15, 0.15}, {
        0.143625, 0.143625}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 20], Rational[1, 5]}, {
         Rational[2031, 14000], Rational[1339, 7000]}}, {{0.15, 0.2}, {
        0.14507142857142857`, 0.19128571428571428`}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 20], Rational[1, 4]}, {
         Rational[1641, 11200], Rational[107, 448]}}, {{0.15, 0.25}, {
        0.14651785714285714`, 0.23883928571428573`}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 20], Rational[3, 10]}, {
         Rational[4143, 28000], Rational[501, 1750]}}, {{0.15, 0.3}, {
        0.14796428571428571`, 0.2862857142857143}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 20], Rational[7, 20]}, {
         Rational[8367, 56000], Rational[2669, 8000]}}, {{0.15, 0.35}, {
        0.14941071428571429`, 0.333625}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 20], Rational[2, 5]}, {
         Rational[132, 875], Rational[1333, 3500]}}, {{0.15, 0.4}, {
        0.15085714285714286`, 0.38085714285714284`}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 20], Rational[9, 20]}, {
         Rational[8529, 56000], Rational[23967, 56000]}}, {{0.15, 0.45}, {
        0.15230357142857143`, 0.42798214285714287`}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 20], Rational[1, 2]}, {
         Rational[123, 800], Rational[19, 40]}}, {{0.15, 0.5}, {0.15375, 
        0.475}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 20], Rational[11, 20]}, {
         Rational[8691, 56000], Rational[29227, 56000]}}, {{0.15, 0.55}, {
        0.15519642857142857`, 0.5219107142857143}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 20], Rational[3, 5]}, {
         Rational[2193, 14000], Rational[3981, 7000]}}, {{0.15, 0.6}, {
        0.15664285714285714`, 0.5687142857142857}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 20], Rational[13, 20]}, {
         Rational[8853, 56000], Rational[34463, 56000]}}, {{0.15, 0.65}, {
        0.1580892857142857, 0.6154107142857143}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 20], Rational[7, 10]}, {
         Rational[4467, 28000], Rational[331, 500]}}, {{0.15, 0.7}, {
        0.15953571428571428`, 0.662}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 20], Rational[3, 4]}, {
         Rational[1803, 11200], Rational[1587, 2240]}}, {{0.15, 0.75}, {
        0.16098214285714285`, 0.7084821428571428}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 20], Rational[4, 5]}, {
         Rational[1137, 7000], Rational[1321, 1750]}}, {{0.15, 0.8}, {
        0.16242857142857142`, 0.7548571428571429}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 20], Rational[17, 20]}, {
         Rational[1311, 8000], Rational[6409, 8000]}}, {{0.15, 0.85}, {
        0.163875, 0.801125}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 20], Rational[9, 10]}, {
         Rational[4629, 28000], Rational[5931, 7000]}}, {{0.15, 0.9}, {
        0.16532142857142856`, 0.8472857142857143}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 20], Rational[19, 20]}, {
         Rational[9339, 56000], Rational[50027, 56000]}}, {{0.15, 0.95}, {
        0.16676785714285713`, 0.8933392857142857}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 20], 1}, {
         Rational[471, 2800], Rational[263, 280]}}, {{0.15, 1}, {
         0.1682142857142857, 0.9392857142857143}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 5], 0}, {Rational[13, 70], 0}}, {{
         0.2, 0}, {0.18571428571428572`, 0}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 5], Rational[1, 20]}, {
         Rational[1313, 7000], Rational[97, 2000]}}, {{0.2, 0.05}, {
        0.18757142857142858`, 0.0485}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 5], Rational[1, 10]}, {
         Rational[663, 3500], Rational[339, 3500]}}, {{0.2, 0.1}, {
        0.18942857142857142`, 0.09685714285714286}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 5], Rational[3, 20]}, {
         Rational[1339, 7000], Rational[2031, 14000]}}, {{0.2, 0.15}, {
        0.19128571428571428`, 0.14507142857142857`}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 5], Rational[1, 5]}, {
         Rational[169, 875], Rational[169, 875]}}, {{0.2, 0.2}, {
        0.19314285714285714`, 0.19314285714285714`}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 5], Rational[1, 4]}, {
         Rational[39, 200], Rational[27, 112]}}, {{0.2, 0.25}, {0.195, 
        0.24107142857142858`}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 5], Rational[3, 10]}, {
         Rational[689, 3500], Rational[1011, 3500]}}, {{0.2, 0.3}, {
        0.19685714285714287`, 0.28885714285714287`}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 5], Rational[7, 20]}, {
         Rational[1391, 7000], Rational[673, 2000]}}, {{0.2, 0.35}, {
        0.1987142857142857, 0.3365}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 5], Rational[2, 5]}, {
         Rational[351, 1750], Rational[48, 125]}}, {{0.2, 0.4}, {
        0.20057142857142857`, 0.384}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 5], Rational[9, 20]}, {
         Rational[1417, 7000], Rational[6039, 14000]}}, {{0.2, 0.45}, {
        0.20242857142857143`, 0.4313571428571429}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 5], Rational[1, 2]}, {
         Rational[143, 700], Rational[67, 140]}}, {{0.2, 0.5}, {
        0.2042857142857143, 0.4785714285714286}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 5], Rational[11, 20]}, {
         Rational[1443, 7000], Rational[7359, 14000]}}, {{0.2, 0.55}, {
        0.20614285714285716`, 0.5256428571428572}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 5], Rational[3, 5]}, {
         Rational[26, 125], Rational[501, 875]}}, {{0.2, 0.6}, {0.208, 
        0.5725714285714286}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 5], Rational[13, 20]}, {
         Rational[1469, 7000], Rational[8671, 14000]}}, {{0.2, 0.65}, {
        0.20985714285714285`, 0.6193571428571428}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 5], Rational[7, 10]}, {
         Rational[741, 3500], Rational[333, 500]}}, {{0.2, 0.7}, {
        0.21171428571428572`, 0.666}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 5], Rational[3, 4]}, {
         Rational[299, 1400], Rational[57, 80]}}, {{0.2, 0.75}, {
        0.21357142857142858`, 0.7125}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 5], Rational[4, 5]}, {
         Rational[377, 1750], Rational[664, 875]}}, {{0.2, 0.8}, {
        0.21542857142857144`, 0.7588571428571429}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 5], Rational[17, 20]}, {
         Rational[1521, 7000], Rational[11271, 14000]}}, {{0.2, 0.85}, {
        0.21728571428571428`, 0.8050714285714285}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 5], Rational[9, 10]}, {
         Rational[767, 3500], Rational[2979, 3500]}}, {{0.2, 0.9}, {
        0.21914285714285714`, 0.8511428571428571}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 5], Rational[19, 20]}, {
         Rational[221, 1000], Rational[12559, 14000]}}, {{0.2, 0.95}, {0.221, 
        0.8970714285714285}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 5], 1}, {
         Rational[39, 175], Rational[33, 35]}}, {{0.2, 1}, {
         0.22285714285714286`, 0.9428571428571428}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 4], 0}, {Rational[13, 56], 0}}, {{
         0.25, 0}, {0.23214285714285715`, 0}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 4], Rational[1, 20]}, {
         Rational[15, 64], Rational[549, 11200]}}, {{0.25, 0.05}, {0.234375, 
        0.04901785714285714}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 4], Rational[1, 10]}, {
         Rational[53, 224], Rational[137, 1400]}}, {{0.25, 0.1}, {
        0.23660714285714285`, 0.09785714285714285}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 4], Rational[3, 20]}, {
         Rational[107, 448], Rational[1641, 11200]}}, {{0.25, 0.15}, {
        0.23883928571428573`, 0.14651785714285714`}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 4], Rational[1, 5]}, {
         Rational[27, 112], Rational[39, 200]}}, {{0.25, 0.2}, {
        0.24107142857142858`, 0.195}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 4], Rational[1, 4]}, {
         Rational[109, 448], Rational[109, 448]}}, {{0.25, 0.25}, {
        0.24330357142857142`, 0.24330357142857142`}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 4], Rational[3, 10]}, {
         Rational[55, 224], Rational[51, 175]}}, {{0.25, 0.3}, {
        0.24553571428571427`, 0.2914285714285714}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 4], Rational[7, 20]}, {
         Rational[111, 448], Rational[543, 1600]}}, {{0.25, 0.35}, {
        0.24776785714285715`, 0.339375}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 4], Rational[2, 5]}, {
         Rational[1, 4], Rational[271, 700]}}, {{0.25, 0.4}, {0.25, 
        0.3871428571428571}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 4], Rational[9, 20]}, {
         Rational[113, 448], Rational[4869, 11200]}}, {{0.25, 0.45}, {
        0.25223214285714285`, 0.43473214285714284`}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 4], Rational[1, 2]}, {
         Rational[57, 224], Rational[27, 56]}}, {{0.25, 0.5}, {
        0.2544642857142857, 0.48214285714285715`}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 4], Rational[11, 20]}, {
         Rational[115, 448], Rational[847, 1600]}}, {{0.25, 0.55}, {
        0.25669642857142855`, 0.529375}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 4], Rational[3, 5]}, {
         Rational[29, 112], Rational[807, 1400]}}, {{0.25, 0.6}, {
        0.25892857142857145`, 0.5764285714285714}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 4], Rational[13, 20]}, {
         Rational[117, 448], Rational[6981, 11200]}}, {{0.25, 0.65}, {
        0.2611607142857143, 0.6233035714285714}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 4], Rational[7, 10]}, {
         Rational[59, 224], Rational[67, 100]}}, {{0.25, 0.7}, {
        0.26339285714285715`, 0.67}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 4], Rational[3, 4]}, {
         Rational[17, 64], Rational[321, 448]}}, {{0.25, 0.75}, {0.265625, 
        0.7165178571428571}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 4], Rational[4, 5]}, {
         Rational[15, 56], Rational[267, 350]}}, {{0.25, 0.8}, {
        0.26785714285714285`, 0.7628571428571429}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 4], Rational[17, 20]}, {
         Rational[121, 448], Rational[9061, 11200]}}, {{0.25, 0.85}, {
        0.2700892857142857, 0.8090178571428571}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 4], Rational[9, 10]}, {
         Rational[61, 224], Rational[171, 200]}}, {{0.25, 0.9}, {
        0.27232142857142855`, 0.855}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 4], Rational[19, 20]}, {
         Rational[123, 448], Rational[10089, 11200]}}, {{0.25, 0.95}, {
        0.27455357142857145`, 0.9008035714285715}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 4], 1}, {
         Rational[31, 112], Rational[53, 56]}}, {{0.25, 1}, {
         0.2767857142857143, 0.9464285714285714}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 10], 0}, {Rational[39, 140], 0}}, {{
         0.3, 0}, {0.2785714285714286, 0}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 10], Rational[1, 20]}, {
         Rational[246, 875], Rational[1387, 28000]}}, {{0.3, 0.05}, {
        0.28114285714285714`, 0.04953571428571429}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 10], Rational[1, 10]}, {
         Rational[993, 3500], Rational[173, 1750]}}, {{0.3, 0.1}, {
        0.2837142857142857, 0.09885714285714285}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 10], Rational[3, 20]}, {
         Rational[501, 1750], Rational[4143, 28000]}}, {{0.3, 0.15}, {
        0.2862857142857143, 0.14796428571428571`}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 10], Rational[1, 5]}, {
         Rational[1011, 3500], Rational[689, 3500]}}, {{0.3, 0.2}, {
        0.28885714285714287`, 0.19685714285714287`}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 10], Rational[1, 4]}, {
         Rational[51, 175], Rational[55, 224]}}, {{0.3, 0.25}, {
        0.2914285714285714, 0.24553571428571427`}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 10], Rational[3, 10]}, {
         Rational[147, 500], Rational[147, 500]}}, {{0.3, 0.3}, {0.294, 
        0.294}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 10], Rational[7, 20]}, {
         Rational[519, 1750], Rational[1369, 4000]}}, {{0.3, 0.35}, {
        0.2965714285714286, 0.34225}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 10], Rational[2, 5]}, {
         Rational[1047, 3500], Rational[683, 1750]}}, {{0.3, 0.4}, {
        0.29914285714285715`, 0.3902857142857143}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 10], Rational[9, 20]}, {
         Rational[264, 875], Rational[12267, 28000]}}, {{0.3, 0.45}, {
        0.3017142857142857, 0.43810714285714286`}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 10], Rational[1, 2]}, {
         Rational[213, 700], Rational[17, 35]}}, {{0.3, 0.5}, {
        0.30428571428571427`, 0.4857142857142857}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 10], Rational[11, 20]}, {
         Rational[537, 1750], Rational[14927, 28000]}}, {{0.3, 0.55}, {
        0.3068571428571429, 0.5331071428571429}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 10], Rational[3, 5]}, {
         Rational[1083, 3500], Rational[2031, 3500]}}, {{0.3, 0.6}, {
        0.30942857142857144`, 0.5802857142857143}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 10], Rational[13, 20]}, {
         Rational[39, 125], Rational[2509, 4000]}}, {{0.3, 0.65}, {0.312, 
        0.62725}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 10], Rational[7, 10]}, {
         Rational[1101, 3500], Rational[337, 500]}}, {{0.3, 0.7}, {
        0.31457142857142856`, 0.674}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 10], Rational[3, 4]}, {
         Rational[111, 350], Rational[807, 1120]}}, {{0.3, 0.75}, {
        0.3171428571428571, 0.7205357142857143}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 10], Rational[4, 5]}, {
         Rational[1119, 3500], Rational[671, 875]}}, {{0.3, 0.8}, {
        0.31971428571428573`, 0.7668571428571429}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 10], Rational[17, 20]}, {
         Rational[282, 875], Rational[22763, 28000]}}, {{0.3, 0.85}, {
        0.3222857142857143, 0.8129642857142857}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 10], Rational[9, 10]}, {
         Rational[1137, 3500], Rational[1503, 1750]}}, {{0.3, 0.9}, {
        0.32485714285714284`, 0.8588571428571429}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 10], Rational[19, 20]}, {
         Rational[573, 1750], Rational[25327, 28000]}}, {{0.3, 0.95}, {
        0.3274285714285714, 0.9045357142857143}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 10], 1}, {
         Rational[33, 100], Rational[19, 20]}}, {{0.3, 1}, {0.33, 0.95}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[7, 20], 0}, {Rational[13, 40], 0}}, {{
         0.35, 0}, {0.325, 0}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[7, 20], Rational[1, 20]}, {
         Rational[2623, 8000], Rational[2803, 56000]}}, {{0.35, 0.05}, {
        0.327875, 0.050053571428571426`}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[7, 20], Rational[1, 10]}, {
         Rational[1323, 4000], Rational[699, 7000]}}, {{0.35, 0.1}, {0.33075, 
        0.09985714285714285}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[7, 20], Rational[3, 20]}, {
         Rational[2669, 8000], Rational[8367, 56000]}}, {{0.35, 0.15}, {
        0.333625, 0.14941071428571429`}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[7, 20], Rational[1, 5]}, {
         Rational[673, 2000], Rational[1391, 7000]}}, {{0.35, 0.2}, {0.3365, 
        0.1987142857142857}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[7, 20], Rational[1, 4]}, {
         Rational[543, 1600], Rational[111, 448]}}, {{0.35, 0.25}, {0.339375, 
        0.24776785714285715`}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[7, 20], Rational[3, 10]}, {
         Rational[1369, 4000], Rational[519, 1750]}}, {{0.35, 0.3}, {0.34225, 
        0.2965714285714286}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[7, 20], Rational[7, 20]}, {
         Rational[2761, 8000], Rational[2761, 8000]}}, {{0.35, 0.35}, {
        0.345125, 0.345125}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[7, 20], Rational[2, 5]}, {
         Rational[87, 250], Rational[1377, 3500]}}, {{0.35, 0.4}, {0.348, 
        0.3934285714285714}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[7, 20], Rational[9, 20]}, {
         Rational[2807, 8000], Rational[24723, 56000]}}, {{0.35, 0.45}, {
        0.350875, 0.4414821428571429}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[7, 20], Rational[1, 2]}, {
         Rational[283, 800], Rational[137, 280]}}, {{0.35, 0.5}, {0.35375, 
        0.48928571428571427`}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[7, 20], Rational[11, 20]}, {
         Rational[2853, 8000], Rational[30063, 56000]}}, {{0.35, 0.55}, {
        0.356625, 0.5368392857142857}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[7, 20], Rational[3, 5]}, {
         Rational[719, 2000], Rational[4089, 7000]}}, {{0.35, 0.6}, {0.3595, 
        0.5841428571428572}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[7, 20], Rational[13, 20]}, {
         Rational[2899, 8000], Rational[35347, 56000]}}, {{0.35, 0.65}, {
        0.362375, 0.6311964285714285}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[7, 20], Rational[7, 10]}, {
         Rational[1461, 4000], Rational[339, 500]}}, {{0.35, 0.7}, {0.36525, 
        0.678}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[7, 20], Rational[3, 4]}, {
         Rational[589, 1600], Rational[1623, 2240]}}, {{0.35, 0.75}, {
        0.368125, 0.7245535714285715}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[7, 20], Rational[4, 5]}, {
         Rational[371, 1000], Rational[1349, 1750]}}, {{0.35, 0.8}, {0.371, 
        0.7708571428571429}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[7, 20], Rational[17, 20]}, {
         Rational[2991, 8000], Rational[45747, 56000]}}, {{0.35, 0.85}, {
        0.373875, 0.8169107142857143}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[7, 20], Rational[9, 10]}, {
         Rational[1507, 4000], Rational[6039, 7000]}}, {{0.35, 0.9}, {0.37675,
         0.8627142857142858}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[7, 20], Rational[19, 20]}, {
         Rational[3037, 8000], Rational[50863, 56000]}}, {{0.35, 0.95}, {
        0.379625, 0.9082678571428572}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[7, 20], 1}, {
         Rational[153, 400], Rational[267, 280]}}, {{0.35, 1}, {0.3825, 
         0.9535714285714286}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[2, 5], 0}, {Rational[13, 35], 0}}, {{
         0.4, 0}, {0.37142857142857144`, 0}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[2, 5], Rational[1, 20]}, {
         Rational[1311, 3500], Rational[177, 3500]}}, {{0.4, 0.05}, {
        0.37457142857142856`, 0.05057142857142857}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[2, 5], Rational[1, 10]}, {
         Rational[661, 1750], Rational[353, 3500]}}, {{0.4, 0.1}, {
        0.3777142857142857, 0.10085714285714285`}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[2, 5], Rational[3, 20]}, {
         Rational[1333, 3500], Rational[132, 875]}}, {{0.4, 0.15}, {
        0.38085714285714284`, 0.15085714285714286`}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[2, 5], Rational[1, 5]}, {
         Rational[48, 125], Rational[351, 1750]}}, {{0.4, 0.2}, {0.384, 
        0.20057142857142857`}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[2, 5], Rational[1, 4]}, {
         Rational[271, 700], Rational[1, 4]}}, {{0.4, 0.25}, {
        0.3871428571428571, 0.25}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[2, 5], Rational[3, 10]}, {
         Rational[683, 1750], Rational[1047, 3500]}}, {{0.4, 0.3}, {
        0.3902857142857143, 0.29914285714285715`}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[2, 5], Rational[7, 20]}, {
         Rational[1377, 3500], Rational[87, 250]}}, {{0.4, 0.35}, {
        0.3934285714285714, 0.348}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[2, 5], Rational[2, 5]}, {
         Rational[347, 875], Rational[347, 875]}}, {{0.4, 0.4}, {
        0.3965714285714286, 0.3965714285714286}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[2, 5], Rational[9, 20]}, {
         Rational[1399, 3500], Rational[1557, 3500]}}, {{0.4, 0.45}, {
        0.3997142857142857, 0.44485714285714284`}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[2, 5], Rational[1, 2]}, {
         Rational[141, 350], Rational[69, 140]}}, {{0.4, 0.5}, {
        0.40285714285714286`, 0.4928571428571429}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[2, 5], Rational[11, 20]}, {
         Rational[203, 500], Rational[473, 875]}}, {{0.4, 0.55}, {0.406, 
        0.5405714285714286}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[2, 5], Rational[3, 5]}, {
         Rational[358, 875], Rational[147, 250]}}, {{0.4, 0.6}, {
        0.40914285714285714`, 0.588}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[2, 5], Rational[13, 20]}, {
         Rational[1443, 3500], Rational[2223, 3500]}}, {{0.4, 0.65}, {
        0.4122857142857143, 0.6351428571428571}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[2, 5], Rational[7, 10]}, {
         Rational[727, 1750], Rational[341, 500]}}, {{0.4, 0.7}, {
        0.4154285714285714, 0.682}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[2, 5], Rational[3, 4]}, {
         Rational[293, 700], Rational[51, 70]}}, {{0.4, 0.75}, {
        0.4185714285714286, 0.7285714285714285}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[2, 5], Rational[4, 5]}, {
         Rational[369, 875], Rational[678, 875]}}, {{0.4, 0.8}, {
        0.4217142857142857, 0.7748571428571429}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[2, 5], Rational[17, 20]}, {
         Rational[1487, 3500], Rational[2873, 3500]}}, {{0.4, 0.85}, {
        0.4248571428571429, 0.8208571428571428}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[2, 5], Rational[9, 10]}, {
         Rational[107, 250], Rational[3033, 3500]}}, {{0.4, 0.9}, {0.428, 
        0.8665714285714285}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[2, 5], Rational[19, 20]}, {
         Rational[1509, 3500], Rational[114, 125]}}, {{0.4, 0.95}, {
        0.43114285714285716`, 0.912}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[2, 5], 1}, {
         Rational[76, 175], Rational[67, 70]}}, {{0.4, 1}, {
         0.4342857142857143, 0.9571428571428572}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[9, 20], 0}, {Rational[117, 280], 0}}, {{
         0.45, 0}, {0.41785714285714287`, 0}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[9, 20], Rational[1, 20]}, {
         Rational[23589, 56000], Rational[2861, 56000]}}, {{0.45, 0.05}, {
        0.42123214285714283`, 0.05108928571428571}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[9, 20], Rational[1, 10]}, {
         Rational[11889, 28000], Rational[713, 7000]}}, {{0.45, 0.1}, {
        0.42460714285714285`, 0.10185714285714285`}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[9, 20], Rational[3, 20]}, {
         Rational[23967, 56000], Rational[8529, 56000]}}, {{0.45, 0.15}, {
        0.42798214285714287`, 0.15230357142857143`}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[9, 20], Rational[1, 5]}, {
         Rational[6039, 14000], Rational[1417, 7000]}}, {{0.45, 0.2}, {
        0.4313571428571429, 0.20242857142857143`}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[9, 20], Rational[1, 4]}, {
         Rational[4869, 11200], Rational[113, 448]}}, {{0.45, 0.25}, {
        0.43473214285714284`, 0.25223214285714285`}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[9, 20], Rational[3, 10]}, {
         Rational[12267, 28000], Rational[264, 875]}}, {{0.45, 0.3}, {
        0.43810714285714286`, 0.3017142857142857}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[9, 20], Rational[7, 20]}, {
         Rational[24723, 56000], Rational[2807, 8000]}}, {{0.45, 0.35}, {
        0.4414821428571429, 0.350875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[9, 20], Rational[2, 5]}, {
         Rational[1557, 3500], Rational[1399, 3500]}}, {{0.45, 0.4}, {
        0.44485714285714284`, 0.3997142857142857}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[9, 20], Rational[9, 20]}, {
         Rational[25101, 56000], Rational[25101, 56000]}}, {{0.45, 0.45}, {
        0.44823214285714286`, 0.44823214285714286`}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[9, 20], Rational[1, 2]}, {
         Rational[2529, 5600], Rational[139, 280]}}, {{0.45, 0.5}, {
        0.4516071428571429, 0.49642857142857144`}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[9, 20], Rational[11, 20]}, {
         Rational[25479, 56000], Rational[30481, 56000]}}, {{0.45, 0.55}, {
        0.45498214285714284`, 0.5443035714285714}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[9, 20], Rational[3, 5]}, {
         Rational[6417, 14000], Rational[4143, 7000]}}, {{0.45, 0.6}, {
        0.45835714285714285`, 0.5918571428571429}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[9, 20], Rational[13, 20]}, {
         Rational[25857, 56000], Rational[35789, 56000]}}, {{0.45, 0.65}, {
        0.46173214285714287`, 0.6390892857142857}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[9, 20], Rational[7, 10]}, {
         Rational[13023, 28000], Rational[343, 500]}}, {{0.45, 0.7}, {
        0.46510714285714283`, 0.686}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[9, 20], Rational[3, 4]}, {
         Rational[5247, 11200], Rational[1641, 2240]}}, {{0.45, 0.75}, {
        0.46848214285714285`, 0.7325892857142857}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[9, 20], Rational[4, 5]}, {
         Rational[3303, 7000], Rational[1363, 1750]}}, {{0.45, 0.8}, {
        0.47185714285714286`, 0.7788571428571428}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[9, 20], Rational[17, 20]}, {
         Rational[26613, 56000], Rational[46189, 56000]}}, {{0.45, 0.85}, {
        0.4752321428571429, 0.8248035714285714}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[9, 20], Rational[9, 10]}, {
         Rational[13401, 28000], Rational[6093, 7000]}}, {{0.45, 0.9}, {
        0.47860714285714284`, 0.8704285714285714}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[9, 20], Rational[19, 20]}, {
         Rational[26991, 56000], Rational[51281, 56000]}}, {{0.45, 0.95}, {
        0.48198214285714286`, 0.9157321428571429}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[9, 20], 1}, {
         Rational[1359, 2800], Rational[269, 280]}}, {{0.45, 1}, {
         0.4853571428571429, 0.9607142857142857}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 2], 0}, {Rational[13, 28], 0}}, {{
         0.5, 0}, {0.4642857142857143, 0}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 2], Rational[1, 20]}, {
         Rational[131, 280], Rational[289, 5600]}}, {{0.5, 0.05}, {
        0.46785714285714286`, 0.05160714285714286}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 2], Rational[1, 10]}, {
         Rational[33, 70], Rational[18, 175]}}, {{0.5, 0.1}, {
        0.4714285714285714, 0.10285714285714286`}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 2], Rational[3, 20]}, {
         Rational[19, 40], Rational[123, 800]}}, {{0.5, 0.15}, {0.475, 
        0.15375}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 2], Rational[1, 5]}, {
         Rational[67, 140], Rational[143, 700]}}, {{0.5, 0.2}, {
        0.4785714285714286, 0.2042857142857143}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 2], Rational[1, 4]}, {
         Rational[27, 56], Rational[57, 224]}}, {{0.5, 0.25}, {
        0.48214285714285715`, 0.2544642857142857}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 2], Rational[3, 10]}, {
         Rational[17, 35], Rational[213, 700]}}, {{0.5, 0.3}, {
        0.4857142857142857, 0.30428571428571427`}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 2], Rational[7, 20]}, {
         Rational[137, 280], Rational[283, 800]}}, {{0.5, 0.35}, {
        0.48928571428571427`, 0.35375}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 2], Rational[2, 5]}, {
         Rational[69, 140], Rational[141, 350]}}, {{0.5, 0.4}, {
        0.4928571428571429, 0.40285714285714286`}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 2], Rational[9, 20]}, {
         Rational[139, 280], Rational[2529, 5600]}}, {{0.5, 0.45}, {
        0.49642857142857144`, 0.4516071428571429}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 2], Rational[11, 20]}, {
         Rational[141, 280], Rational[3069, 5600]}}, {{0.5, 0.55}, {
        0.5035714285714286, 0.5480357142857143}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 2], Rational[3, 5]}, {
         Rational[71, 140], Rational[417, 700]}}, {{0.5, 0.6}, {
        0.5071428571428571, 0.5957142857142858}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 2], Rational[13, 20]}, {
         Rational[143, 280], Rational[3601, 5600]}}, {{0.5, 0.65}, {
        0.5107142857142857, 0.6430357142857143}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 2], Rational[7, 10]}, {
         Rational[18, 35], Rational[69, 100]}}, {{0.5, 0.7}, {
        0.5142857142857142, 0.69}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 2], Rational[3, 4]}, {
         Rational[29, 56], Rational[165, 224]}}, {{0.5, 0.75}, {
        0.5178571428571429, 0.7366071428571429}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 2], Rational[4, 5]}, {
         Rational[73, 140], Rational[137, 175]}}, {{0.5, 0.8}, {
        0.5214285714285715, 0.7828571428571428}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 2], Rational[17, 20]}, {
         Rational[21, 40], Rational[663, 800]}}, {{0.5, 0.85}, {0.525, 
        0.82875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 2], Rational[9, 10]}, {
         Rational[37, 70], Rational[153, 175]}}, {{0.5, 0.9}, {
        0.5285714285714286, 0.8742857142857143}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 2], Rational[19, 20]}, {
         Rational[149, 280], Rational[5149, 5600]}}, {{0.5, 0.95}, {
        0.5321428571428571, 0.9194642857142857}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 2], 1}, {
         Rational[15, 28], Rational[27, 28]}}, {{0.5, 1}, {0.5357142857142857,
          0.9642857142857143}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[11, 20], 0}, {Rational[143, 280], 0}}, {{
         0.55, 0}, {0.5107142857142857, 0}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[11, 20], Rational[1, 20]}, {
         Rational[28809, 56000], Rational[417, 8000]}}, {{0.55, 0.05}, {
        0.5144464285714285, 0.052125}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[11, 20], Rational[1, 10]}, {
         Rational[14509, 28000], Rational[727, 7000]}}, {{0.55, 0.1}, {
        0.5181785714285714, 0.10385714285714286`}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[11, 20], Rational[3, 20]}, {
         Rational[29227, 56000], Rational[8691, 56000]}}, {{0.55, 0.15}, {
        0.5219107142857143, 0.15519642857142857`}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[11, 20], Rational[1, 5]}, {
         Rational[7359, 14000], Rational[1443, 7000]}}, {{0.55, 0.2}, {
        0.5256428571428572, 0.20614285714285716`}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[11, 20], Rational[1, 4]}, {
         Rational[847, 1600], Rational[115, 448]}}, {{0.55, 0.25}, {0.529375, 
        0.25669642857142855`}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[11, 20], Rational[3, 10]}, {
         Rational[14927, 28000], Rational[537, 1750]}}, {{0.55, 0.3}, {
        0.5331071428571429, 0.3068571428571429}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[11, 20], Rational[7, 20]}, {
         Rational[30063, 56000], Rational[2853, 8000]}}, {{0.55, 0.35}, {
        0.5368392857142857, 0.356625}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[11, 20], Rational[2, 5]}, {
         Rational[473, 875], Rational[203, 500]}}, {{0.55, 0.4}, {
        0.5405714285714286, 0.406}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[11, 20], Rational[9, 20]}, {
         Rational[30481, 56000], Rational[25479, 56000]}}, {{0.55, 0.45}, {
        0.5443035714285714, 0.45498214285714284`}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[11, 20], Rational[1, 2]}, {
         Rational[3069, 5600], Rational[141, 280]}}, {{0.55, 0.5}, {
        0.5480357142857143, 0.5035714285714286}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[11, 20], Rational[11, 20]}, {
         Rational[30899, 56000], Rational[30899, 56000]}}, {{0.55, 0.55}, {
        0.5517678571428571, 0.5517678571428571}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[11, 20], Rational[3, 5]}, {
         Rational[1111, 2000], Rational[4197, 7000]}}, {{0.55, 0.6}, {0.5555, 
        0.5995714285714285}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[11, 20], Rational[13, 20]}, {
         Rational[31317, 56000], Rational[36231, 56000]}}, {{0.55, 0.65}, {
        0.5592321428571428, 0.6469821428571428}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[11, 20], Rational[7, 10]}, {
         Rational[15763, 28000], Rational[347, 500]}}, {{0.55, 0.7}, {
        0.5629642857142857, 0.694}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[11, 20], Rational[3, 4]}, {
         Rational[6347, 11200], Rational[237, 320]}}, {{0.55, 0.75}, {
        0.5666964285714285, 0.740625}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[11, 20], Rational[4, 5]}, {
         Rational[3993, 7000], Rational[1377, 1750]}}, {{0.55, 0.8}, {
        0.5704285714285714, 0.7868571428571428}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[11, 20], Rational[17, 20]}, {
         Rational[32153, 56000], Rational[46631, 56000]}}, {{0.55, 0.85}, {
        0.5741607142857142, 0.8326964285714286}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[11, 20], Rational[9, 10]}, {
         Rational[16181, 28000], Rational[6147, 7000]}}, {{0.55, 0.9}, {
        0.5778928571428571, 0.8781428571428571}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[11, 20], Rational[19, 20]}, {
         Rational[4653, 8000], Rational[51699, 56000]}}, {{0.55, 0.95}, {
        0.581625, 0.9231964285714286}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[11, 20], 1}, {
         Rational[1639, 2800], Rational[271, 280]}}, {{0.55, 1}, {
         0.5853571428571429, 0.9678571428571429}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 5], 0}, {Rational[39, 70], 0}}, {{
         0.6, 0}, {0.5571428571428572, 0}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 5], Rational[1, 20]}, {
         Rational[561, 1000], Rational[737, 14000]}}, {{0.6, 0.05}, {0.561, 
        0.052642857142857144`}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 5], Rational[1, 10]}, {
         Rational[1977, 3500], Rational[367, 3500]}}, {{0.6, 0.1}, {
        0.5648571428571428, 0.10485714285714286`}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 5], Rational[3, 20]}, {
         Rational[3981, 7000], Rational[2193, 14000]}}, {{0.6, 0.15}, {
        0.5687142857142857, 0.15664285714285714`}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 5], Rational[1, 5]}, {
         Rational[501, 875], Rational[26, 125]}}, {{0.6, 0.2}, {
        0.5725714285714286, 0.208}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 5], Rational[1, 4]}, {
         Rational[807, 1400], Rational[29, 112]}}, {{0.6, 0.25}, {
        0.5764285714285714, 0.25892857142857145`}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 5], Rational[3, 10]}, {
         Rational[2031, 3500], Rational[1083, 3500]}}, {{0.6, 0.3}, {
        0.5802857142857143, 0.30942857142857144`}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 5], Rational[7, 20]}, {
         Rational[4089, 7000], Rational[719, 2000]}}, {{0.6, 0.35}, {
        0.5841428571428572, 0.3595}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 5], Rational[2, 5]}, {
         Rational[147, 250], Rational[358, 875]}}, {{0.6, 0.4}, {0.588, 
        0.40914285714285714`}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 5], Rational[9, 20]}, {
         Rational[4143, 7000], Rational[6417, 14000]}}, {{0.6, 0.45}, {
        0.5918571428571429, 0.45835714285714285`}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 5], Rational[1, 2]}, {
         Rational[417, 700], Rational[71, 140]}}, {{0.6, 0.5}, {
        0.5957142857142858, 0.5071428571428571}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 5], Rational[11, 20]}, {
         Rational[4197, 7000], Rational[1111, 2000]}}, {{0.6, 0.55}, {
        0.5995714285714285, 0.5555}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 5], Rational[3, 5]}, {
         Rational[528, 875], Rational[528, 875]}}, {{0.6, 0.6}, {
        0.6034285714285714, 0.6034285714285714}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 5], Rational[13, 20]}, {
         Rational[4251, 7000], Rational[9113, 14000]}}, {{0.6, 0.65}, {
        0.6072857142857143, 0.6509285714285714}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 5], Rational[7, 10]}, {
         Rational[2139, 3500], Rational[349, 500]}}, {{0.6, 0.7}, {
        0.6111428571428571, 0.698}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 5], Rational[3, 4]}, {
         Rational[123, 200], Rational[417, 560]}}, {{0.6, 0.75}, {0.615, 
        0.7446428571428572}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 5], Rational[4, 5]}, {
         Rational[1083, 1750], Rational[692, 875]}}, {{0.6, 0.8}, {
        0.6188571428571429, 0.7908571428571428}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 5], Rational[17, 20]}, {
         Rational[4359, 7000], Rational[11713, 14000]}}, {{0.6, 0.85}, {
        0.6227142857142857, 0.8366428571428571}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 5], Rational[9, 10]}, {
         Rational[2193, 3500], Rational[441, 500]}}, {{0.6, 0.9}, {
        0.6265714285714286, 0.882}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 5], Rational[19, 20]}, {
         Rational[4413, 7000], Rational[12977, 14000]}}, {{0.6, 0.95}, {
        0.6304285714285714, 0.9269285714285714}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 5], 1}, {
         Rational[111, 175], Rational[34, 35]}}, {{0.6, 1}, {
         0.6342857142857142, 0.9714285714285714}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[13, 20], 0}, {Rational[169, 280], 0}}, {{
         0.65, 0}, {0.6035714285714285, 0}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[13, 20], Rational[1, 20]}, {
         Rational[34021, 56000], Rational[2977, 56000]}}, {{0.65, 0.05}, {
        0.6075178571428571, 0.05316071428571428}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[13, 20], Rational[1, 10]}, {
         Rational[17121, 28000], Rational[741, 7000]}}, {{0.65, 0.1}, {
        0.6114642857142857, 0.10585714285714286`}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[13, 20], Rational[3, 20]}, {
         Rational[34463, 56000], Rational[8853, 56000]}}, {{0.65, 0.15}, {
        0.6154107142857143, 0.1580892857142857}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[13, 20], Rational[1, 5]}, {
         Rational[8671, 14000], Rational[1469, 7000]}}, {{0.65, 0.2}, {
        0.6193571428571428, 0.20985714285714285`}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[13, 20], Rational[1, 4]}, {
         Rational[6981, 11200], Rational[117, 448]}}, {{0.65, 0.25}, {
        0.6233035714285714, 0.2611607142857143}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[13, 20], Rational[3, 10]}, {
         Rational[2509, 4000], Rational[39, 125]}}, {{0.65, 0.3}, {0.62725, 
        0.312}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[13, 20], Rational[7, 20]}, {
         Rational[35347, 56000], Rational[2899, 8000]}}, {{0.65, 0.35}, {
        0.6311964285714285, 0.362375}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[13, 20], Rational[2, 5]}, {
         Rational[2223, 3500], Rational[1443, 3500]}}, {{0.65, 0.4}, {
        0.6351428571428571, 0.4122857142857143}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[13, 20], Rational[9, 20]}, {
         Rational[35789, 56000], Rational[25857, 56000]}}, {{0.65, 0.45}, {
        0.6390892857142857, 0.46173214285714287`}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[13, 20], Rational[1, 2]}, {
         Rational[3601, 5600], Rational[143, 280]}}, {{0.65, 0.5}, {
        0.6430357142857143, 0.5107142857142857}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[13, 20], Rational[11, 20]}, {
         Rational[36231, 56000], Rational[31317, 56000]}}, {{0.65, 0.55}, {
        0.6469821428571428, 0.5592321428571428}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[13, 20], Rational[3, 5]}, {
         Rational[9113, 14000], Rational[4251, 7000]}}, {{0.65, 0.6}, {
        0.6509285714285714, 0.6072857142857143}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[13, 20], Rational[13, 20]}, {
         Rational[5239, 8000], Rational[5239, 8000]}}, {{0.65, 0.65}, {
        0.654875, 0.654875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[13, 20], Rational[7, 10]}, {
         Rational[18447, 28000], Rational[351, 500]}}, {{0.65, 0.7}, {
        0.6588214285714286, 0.702}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[13, 20], Rational[3, 4]}, {
         Rational[7423, 11200], Rational[1677, 2240]}}, {{0.65, 0.75}, {
        0.6627678571428571, 0.7486607142857142}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[13, 20], Rational[4, 5]}, {
         Rational[4667, 7000], Rational[1391, 1750]}}, {{0.65, 0.8}, {
        0.6667142857142857, 0.7948571428571428}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[13, 20], Rational[17, 20]}, {
         Rational[37557, 56000], Rational[47073, 56000]}}, {{0.65, 0.85}, {
        0.6706607142857143, 0.8405892857142857}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[13, 20], Rational[9, 10]}, {
         Rational[18889, 28000], Rational[6201, 7000]}}, {{0.65, 0.9}, {
        0.6746071428571428, 0.8858571428571429}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[13, 20], Rational[19, 20]}, {
         Rational[37999, 56000], Rational[52117, 56000]}}, {{0.65, 0.95}, {
        0.6785535714285714, 0.9306607142857143}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[13, 20], 1}, {
         Rational[273, 400], Rational[39, 40]}}, {{0.65, 1}, {0.6825, 
         0.975}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[7, 10], 0}, {Rational[13, 20], 0}}, {{
         0.7, 0}, {0.65, 0}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[7, 10], Rational[1, 20]}, {
         Rational[327, 500], Rational[1503, 28000]}}, {{0.7, 0.05}, {0.654, 
        0.05367857142857143}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[7, 10], Rational[1, 10]}, {
         Rational[329, 500], Rational[187, 1750]}}, {{0.7, 0.1}, {0.658, 
        0.10685714285714286`}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[7, 10], Rational[3, 20]}, {
         Rational[331, 500], Rational[4467, 28000]}}, {{0.7, 0.15}, {0.662, 
        0.15953571428571428`}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[7, 10], Rational[1, 5]}, {
         Rational[333, 500], Rational[741, 3500]}}, {{0.7, 0.2}, {0.666, 
        0.21171428571428572`}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[7, 10], Rational[1, 4]}, {
         Rational[67, 100], Rational[59, 224]}}, {{0.7, 0.25}, {0.67, 
        0.26339285714285715`}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[7, 10], Rational[3, 10]}, {
         Rational[337, 500], Rational[1101, 3500]}}, {{0.7, 0.3}, {0.674, 
        0.31457142857142856`}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[7, 10], Rational[7, 20]}, {
         Rational[339, 500], Rational[1461, 4000]}}, {{0.7, 0.35}, {0.678, 
        0.36525}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[7, 10], Rational[2, 5]}, {
         Rational[341, 500], Rational[727, 1750]}}, {{0.7, 0.4}, {0.682, 
        0.4154285714285714}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[7, 10], Rational[9, 20]}, {
         Rational[343, 500], Rational[13023, 28000]}}, {{0.7, 0.45}, {0.686, 
        0.46510714285714283`}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[7, 10], Rational[1, 2]}, {
         Rational[69, 100], Rational[18, 35]}}, {{0.7, 0.5}, {0.69, 
        0.5142857142857142}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[7, 10], Rational[11, 20]}, {
         Rational[347, 500], Rational[15763, 28000]}}, {{0.7, 0.55}, {0.694, 
        0.5629642857142857}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[7, 10], Rational[3, 5]}, {
         Rational[349, 500], Rational[2139, 3500]}}, {{0.7, 0.6}, {0.698, 
        0.6111428571428571}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[7, 10], Rational[13, 20]}, {
         Rational[351, 500], Rational[18447, 28000]}}, {{0.7, 0.65}, {0.702, 
        0.6588214285714286}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[7, 10], Rational[7, 10]}, {
         Rational[353, 500], Rational[353, 500]}}, {{0.7, 0.7}, {0.706, 
        0.706}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[7, 10], Rational[3, 4]}, {
         Rational[71, 100], Rational[843, 1120]}}, {{0.7, 0.75}, {0.71, 
        0.7526785714285714}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[7, 10], Rational[4, 5]}, {
         Rational[357, 500], Rational[699, 875]}}, {{0.7, 0.8}, {0.714, 
        0.7988571428571428}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[7, 10], Rational[17, 20]}, {
         Rational[359, 500], Rational[23647, 28000]}}, {{0.7, 0.85}, {0.718, 
        0.8445357142857143}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[7, 10], Rational[9, 10]}, {
         Rational[361, 500], Rational[1557, 1750]}}, {{0.7, 0.9}, {0.722, 
        0.8897142857142857}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[7, 10], Rational[19, 20]}, {
         Rational[363, 500], Rational[26163, 28000]}}, {{0.7, 0.95}, {0.726, 
        0.9343928571428571}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[7, 10], 1}, {
         Rational[73, 100], Rational[137, 140]}}, {{0.7, 1}, {0.73, 
         0.9785714285714285}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 4], 0}, {Rational[39, 56], 0}}, {{
         0.75, 0}, {0.6964285714285714, 0}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 4], Rational[1, 20]}, {
         Rational[1569, 2240], Rational[607, 11200]}}, {{0.75, 0.05}, {
        0.7004464285714286, 0.05419642857142857}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 4], Rational[1, 10]}, {
         Rational[789, 1120], Rational[151, 1400]}}, {{0.75, 0.1}, {
        0.7044642857142858, 0.10785714285714286`}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 4], Rational[3, 20]}, {
         Rational[1587, 2240], Rational[1803, 11200]}}, {{0.75, 0.15}, {
        0.7084821428571428, 0.16098214285714285`}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 4], Rational[1, 5]}, {
         Rational[57, 80], Rational[299, 1400]}}, {{0.75, 0.2}, {0.7125, 
        0.21357142857142858`}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 4], Rational[1, 4]}, {
         Rational[321, 448], Rational[17, 64]}}, {{0.75, 0.25}, {
        0.7165178571428571, 0.265625}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 4], Rational[3, 10]}, {
         Rational[807, 1120], Rational[111, 350]}}, {{0.75, 0.3}, {
        0.7205357142857143, 0.3171428571428571}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 4], Rational[7, 20]}, {
         Rational[1623, 2240], Rational[589, 1600]}}, {{0.75, 0.35}, {
        0.7245535714285715, 0.368125}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 4], Rational[2, 5]}, {
         Rational[51, 70], Rational[293, 700]}}, {{0.75, 0.4}, {
        0.7285714285714285, 0.4185714285714286}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 4], Rational[9, 20]}, {
         Rational[1641, 2240], Rational[5247, 11200]}}, {{0.75, 0.45}, {
        0.7325892857142857, 0.46848214285714285`}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 4], Rational[1, 2]}, {
         Rational[165, 224], Rational[29, 56]}}, {{0.75, 0.5}, {
        0.7366071428571429, 0.5178571428571429}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 4], Rational[11, 20]}, {
         Rational[237, 320], Rational[6347, 11200]}}, {{0.75, 0.55}, {
        0.740625, 0.5666964285714285}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 4], Rational[3, 5]}, {
         Rational[417, 560], Rational[123, 200]}}, {{0.75, 0.6}, {
        0.7446428571428572, 0.615}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 4], Rational[13, 20]}, {
         Rational[1677, 2240], Rational[7423, 11200]}}, {{0.75, 0.65}, {
        0.7486607142857142, 0.6627678571428571}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 4], Rational[7, 10]}, {
         Rational[843, 1120], Rational[71, 100]}}, {{0.75, 0.7}, {
        0.7526785714285714, 0.71}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 4], Rational[3, 4]}, {
         Rational[339, 448], Rational[339, 448]}}, {{0.75, 0.75}, {
        0.7566964285714286, 0.7566964285714286}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 4], Rational[4, 5]}, {
         Rational[213, 280], Rational[281, 350]}}, {{0.75, 0.8}, {
        0.7607142857142857, 0.8028571428571428}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 4], Rational[17, 20]}, {
         Rational[1713, 2240], Rational[9503, 11200]}}, {{0.75, 0.85}, {
        0.7647321428571429, 0.8484821428571429}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 4], Rational[9, 10]}, {
         Rational[123, 160], Rational[1251, 1400]}}, {{0.75, 0.9}, {0.76875, 
        0.8935714285714286}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 4], Rational[19, 20]}, {
         Rational[1731, 2240], Rational[1501, 1600]}}, {{0.75, 0.95}, {
        0.7727678571428571, 0.938125}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 4], 1}, {
         Rational[87, 112], Rational[55, 56]}}, {{0.75, 1}, {
         0.7767857142857143, 0.9821428571428571}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[4, 5], 0}, {Rational[26, 35], 0}}, {{
         0.8, 0}, {0.7428571428571429, 0}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[4, 5], Rational[1, 20]}, {
         Rational[1307, 1750], Rational[383, 7000]}}, {{0.8, 0.05}, {
        0.7468571428571429, 0.054714285714285715`}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[4, 5], Rational[1, 10]}, {
         Rational[657, 875], Rational[381, 3500]}}, {{0.8, 0.1}, {
        0.7508571428571429, 0.10885714285714286`}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[4, 5], Rational[3, 20]}, {
         Rational[1321, 1750], Rational[1137, 7000]}}, {{0.8, 0.15}, {
        0.7548571428571429, 0.16242857142857142`}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[4, 5], Rational[1, 5]}, {
         Rational[664, 875], Rational[377, 1750]}}, {{0.8, 0.2}, {
        0.7588571428571429, 0.21542857142857144`}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[4, 5], Rational[1, 4]}, {
         Rational[267, 350], Rational[15, 56]}}, {{0.8, 0.25}, {
        0.7628571428571429, 0.26785714285714285`}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[4, 5], Rational[3, 10]}, {
         Rational[671, 875], Rational[1119, 3500]}}, {{0.8, 0.3}, {
        0.7668571428571429, 0.31971428571428573`}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[4, 5], Rational[7, 20]}, {
         Rational[1349, 1750], Rational[371, 1000]}}, {{0.8, 0.35}, {
        0.7708571428571429, 0.371}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[4, 5], Rational[2, 5]}, {
         Rational[678, 875], Rational[369, 875]}}, {{0.8, 0.4}, {
        0.7748571428571429, 0.4217142857142857}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[4, 5], Rational[9, 20]}, {
         Rational[1363, 1750], Rational[3303, 7000]}}, {{0.8, 0.45}, {
        0.7788571428571428, 0.47185714285714286`}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[4, 5], Rational[1, 2]}, {
         Rational[137, 175], Rational[73, 140]}}, {{0.8, 0.5}, {
        0.7828571428571428, 0.5214285714285715}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[4, 5], Rational[11, 20]}, {
         Rational[1377, 1750], Rational[3993, 7000]}}, {{0.8, 0.55}, {
        0.7868571428571428, 0.5704285714285714}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[4, 5], Rational[3, 5]}, {
         Rational[692, 875], Rational[1083, 1750]}}, {{0.8, 0.6}, {
        0.7908571428571428, 0.6188571428571429}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[4, 5], Rational[13, 20]}, {
         Rational[1391, 1750], Rational[4667, 7000]}}, {{0.8, 0.65}, {
        0.7948571428571428, 0.6667142857142857}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[4, 5], Rational[7, 10]}, {
         Rational[699, 875], Rational[357, 500]}}, {{0.8, 0.7}, {
        0.7988571428571428, 0.714}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[4, 5], Rational[3, 4]}, {
         Rational[281, 350], Rational[213, 280]}}, {{0.8, 0.75}, {
        0.8028571428571428, 0.7607142857142857}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[4, 5], Rational[4, 5]}, {
         Rational[706, 875], Rational[706, 875]}}, {{0.8, 0.8}, {
        0.8068571428571428, 0.8068571428571428}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[4, 5], Rational[17, 20]}, {
         Rational[1419, 1750], Rational[5967, 7000]}}, {{0.8, 0.85}, {
        0.8108571428571428, 0.8524285714285714}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[4, 5], Rational[9, 10]}, {
         Rational[713, 875], Rational[3141, 3500]}}, {{0.8, 0.9}, {
        0.8148571428571428, 0.8974285714285715}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[4, 5], Rational[19, 20]}, {
         Rational[1433, 1750], Rational[6593, 7000]}}, {{0.8, 0.95}, {
        0.8188571428571428, 0.9418571428571428}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[4, 5], 1}, {
         Rational[144, 175], Rational[69, 70]}}, {{0.8, 1}, {
         0.8228571428571428, 0.9857142857142858}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[17, 20], 0}, {Rational[221, 280], 0}}, {{
         0.85, 0}, {0.7892857142857143, 0}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[17, 20], Rational[1, 20]}, {
         Rational[44421, 56000], Rational[3093, 56000]}}, {{0.85, 0.05}, {
        0.7932321428571428, 0.055232142857142855`}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[17, 20], Rational[1, 10]}, {
         Rational[22321, 28000], Rational[769, 7000]}}, {{0.85, 0.1}, {
        0.7971785714285714, 0.10985714285714286`}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[17, 20], Rational[3, 20]}, {
         Rational[6409, 8000], Rational[1311, 8000]}}, {{0.85, 0.15}, {
        0.801125, 0.163875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[17, 20], Rational[1, 5]}, {
         Rational[11271, 14000], Rational[1521, 7000]}}, {{0.85, 0.2}, {
        0.8050714285714285, 0.21728571428571428`}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[17, 20], Rational[1, 4]}, {
         Rational[9061, 11200], Rational[121, 448]}}, {{0.85, 0.25}, {
        0.8090178571428571, 0.2700892857142857}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[17, 20], Rational[3, 10]}, {
         Rational[22763, 28000], Rational[282, 875]}}, {{0.85, 0.3}, {
        0.8129642857142857, 0.3222857142857143}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[17, 20], Rational[7, 20]}, {
         Rational[45747, 56000], Rational[2991, 8000]}}, {{0.85, 0.35}, {
        0.8169107142857143, 0.373875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[17, 20], Rational[2, 5]}, {
         Rational[2873, 3500], Rational[1487, 3500]}}, {{0.85, 0.4}, {
        0.8208571428571428, 0.4248571428571429}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[17, 20], Rational[9, 20]}, {
         Rational[46189, 56000], Rational[26613, 56000]}}, {{0.85, 0.45}, {
        0.8248035714285714, 0.4752321428571429}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[17, 20], Rational[1, 2]}, {
         Rational[663, 800], Rational[21, 40]}}, {{0.85, 0.5}, {0.82875, 
        0.525}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[17, 20], Rational[11, 20]}, {
         Rational[46631, 56000], Rational[32153, 56000]}}, {{0.85, 0.55}, {
        0.8326964285714286, 0.5741607142857142}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[17, 20], Rational[3, 5]}, {
         Rational[11713, 14000], Rational[4359, 7000]}}, {{0.85, 0.6}, {
        0.8366428571428571, 0.6227142857142857}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[17, 20], Rational[13, 20]}, {
         Rational[47073, 56000], Rational[37557, 56000]}}, {{0.85, 0.65}, {
        0.8405892857142857, 0.6706607142857143}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[17, 20], Rational[7, 10]}, {
         Rational[23647, 28000], Rational[359, 500]}}, {{0.85, 0.7}, {
        0.8445357142857143, 0.718}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[17, 20], Rational[3, 4]}, {
         Rational[9503, 11200], Rational[1713, 2240]}}, {{0.85, 0.75}, {
        0.8484821428571429, 0.7647321428571429}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[17, 20], Rational[4, 5]}, {
         Rational[5967, 7000], Rational[1419, 1750]}}, {{0.85, 0.8}, {
        0.8524285714285714, 0.8108571428571428}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[17, 20], Rational[17, 20]}, {
         Rational[6851, 8000], Rational[6851, 8000]}}, {{0.85, 0.85}, {
        0.856375, 0.856375}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[17, 20], Rational[9, 10]}, {
         Rational[24089, 28000], Rational[6309, 7000]}}, {{0.85, 0.9}, {
        0.8603214285714286, 0.9012857142857142}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[17, 20], Rational[19, 20]}, {
         Rational[48399, 56000], Rational[52953, 56000]}}, {{0.85, 0.95}, {
        0.8642678571428571, 0.9455892857142857}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[17, 20], 1}, {
         Rational[2431, 2800], Rational[277, 280]}}, {{0.85, 1}, {
         0.8682142857142857, 0.9892857142857143}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[9, 10], 0}, {Rational[117, 140], 0}}, {{
         0.9, 0}, {0.8357142857142857, 0}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[9, 10], Rational[1, 20]}, {
         Rational[5877, 7000], Rational[223, 4000]}}, {{0.9, 0.05}, {
        0.8395714285714285, 0.05575}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[9, 10], Rational[1, 10]}, {
         Rational[738, 875], Rational[97, 875]}}, {{0.9, 0.1}, {
        0.8434285714285714, 0.11085714285714286`}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[9, 10], Rational[3, 20]}, {
         Rational[5931, 7000], Rational[4629, 28000]}}, {{0.9, 0.15}, {
        0.8472857142857143, 0.16532142857142856`}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[9, 10], Rational[1, 5]}, {
         Rational[2979, 3500], Rational[767, 3500]}}, {{0.9, 0.2}, {
        0.8511428571428571, 0.21914285714285714`}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[9, 10], Rational[1, 4]}, {
         Rational[171, 200], Rational[61, 224]}}, {{0.9, 0.25}, {0.855, 
        0.27232142857142855`}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[9, 10], Rational[3, 10]}, {
         Rational[1503, 1750], Rational[1137, 3500]}}, {{0.9, 0.3}, {
        0.8588571428571429, 0.32485714285714284`}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[9, 10], Rational[7, 20]}, {
         Rational[6039, 7000], Rational[1507, 4000]}}, {{0.9, 0.35}, {
        0.8627142857142858, 0.37675}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[9, 10], Rational[2, 5]}, {
         Rational[3033, 3500], Rational[107, 250]}}, {{0.9, 0.4}, {
        0.8665714285714285, 0.428}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[9, 10], Rational[9, 20]}, {
         Rational[6093, 7000], Rational[13401, 28000]}}, {{0.9, 0.45}, {
        0.8704285714285714, 0.47860714285714284`}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[9, 10], Rational[1, 2]}, {
         Rational[153, 175], Rational[37, 70]}}, {{0.9, 0.5}, {
        0.8742857142857143, 0.5285714285714286}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[9, 10], Rational[11, 20]}, {
         Rational[6147, 7000], Rational[16181, 28000]}}, {{0.9, 0.55}, {
        0.8781428571428571, 0.5778928571428571}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[9, 10], Rational[3, 5]}, {
         Rational[441, 500], Rational[2193, 3500]}}, {{0.9, 0.6}, {0.882, 
        0.6265714285714286}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[9, 10], Rational[13, 20]}, {
         Rational[6201, 7000], Rational[18889, 28000]}}, {{0.9, 0.65}, {
        0.8858571428571429, 0.6746071428571428}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[9, 10], Rational[7, 10]}, {
         Rational[1557, 1750], Rational[361, 500]}}, {{0.9, 0.7}, {
        0.8897142857142857, 0.722}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[9, 10], Rational[3, 4]}, {
         Rational[1251, 1400], Rational[123, 160]}}, {{0.9, 0.75}, {
        0.8935714285714286, 0.76875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[9, 10], Rational[4, 5]}, {
         Rational[3141, 3500], Rational[713, 875]}}, {{0.9, 0.8}, {
        0.8974285714285715, 0.8148571428571428}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[9, 10], Rational[17, 20]}, {
         Rational[6309, 7000], Rational[24089, 28000]}}, {{0.9, 0.85}, {
        0.9012857142857142, 0.8603214285714286}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[9, 10], Rational[9, 10]}, {
         Rational[792, 875], Rational[792, 875]}}, {{0.9, 0.9}, {
        0.9051428571428571, 0.9051428571428571}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[9, 10], Rational[19, 20]}, {
         Rational[909, 1000], Rational[26581, 28000]}}, {{0.9, 0.95}, {0.909, 
        0.9493214285714285}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[9, 10], 1}, {
         Rational[639, 700], Rational[139, 140]}}, {{0.9, 1}, {
         0.9128571428571428, 0.9928571428571429}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[19, 20], 0}, {Rational[247, 280], 0}}, {{
         0.95, 0}, {0.8821428571428571, 0}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[19, 20], Rational[1, 20]}, {
         Rational[7087, 8000], Rational[3151, 56000]}}, {{0.95, 0.05}, {
        0.885875, 0.05626785714285714}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[19, 20], Rational[1, 10]}, {
         Rational[24909, 28000], Rational[783, 7000]}}, {{0.95, 0.1}, {
        0.8896071428571428, 0.11185714285714286`}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[19, 20], Rational[3, 20]}, {
         Rational[50027, 56000], Rational[9339, 56000]}}, {{0.95, 0.15}, {
        0.8933392857142857, 0.16676785714285713`}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[19, 20], Rational[1, 5]}, {
         Rational[12559, 14000], Rational[221, 1000]}}, {{0.95, 0.2}, {
        0.8970714285714285, 0.221}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[19, 20], Rational[1, 4]}, {
         Rational[10089, 11200], Rational[123, 448]}}, {{0.95, 0.25}, {
        0.9008035714285715, 0.27455357142857145`}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[19, 20], Rational[3, 10]}, {
         Rational[25327, 28000], Rational[573, 1750]}}, {{0.95, 0.3}, {
        0.9045357142857143, 0.3274285714285714}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[19, 20], Rational[7, 20]}, {
         Rational[50863, 56000], Rational[3037, 8000]}}, {{0.95, 0.35}, {
        0.9082678571428572, 0.379625}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[19, 20], Rational[2, 5]}, {
         Rational[114, 125], Rational[1509, 3500]}}, {{0.95, 0.4}, {0.912, 
        0.43114285714285716`}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[19, 20], Rational[9, 20]}, {
         Rational[51281, 56000], Rational[26991, 56000]}}, {{0.95, 0.45}, {
        0.9157321428571429, 0.48198214285714286`}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[19, 20], Rational[1, 2]}, {
         Rational[5149, 5600], Rational[149, 280]}}, {{0.95, 0.5}, {
        0.9194642857142857, 0.5321428571428571}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[19, 20], Rational[11, 20]}, {
         Rational[51699, 56000], Rational[4653, 8000]}}, {{0.95, 0.55}, {
        0.9231964285714286, 0.581625}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[19, 20], Rational[3, 5]}, {
         Rational[12977, 14000], Rational[4413, 7000]}}, {{0.95, 0.6}, {
        0.9269285714285714, 0.6304285714285714}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[19, 20], Rational[13, 20]}, {
         Rational[52117, 56000], Rational[37999, 56000]}}, {{0.95, 0.65}, {
        0.9306607142857143, 0.6785535714285714}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[19, 20], Rational[7, 10]}, {
         Rational[26163, 28000], Rational[363, 500]}}, {{0.95, 0.7}, {
        0.9343928571428571, 0.726}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[19, 20], Rational[3, 4]}, {
         Rational[1501, 1600], Rational[1731, 2240]}}, {{0.95, 0.75}, {
        0.938125, 0.7727678571428571}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[19, 20], Rational[4, 5]}, {
         Rational[6593, 7000], Rational[1433, 1750]}}, {{0.95, 0.8}, {
        0.9418571428571428, 0.8188571428571428}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[19, 20], Rational[17, 20]}, {
         Rational[52953, 56000], Rational[48399, 56000]}}, {{0.95, 0.85}, {
        0.9455892857142857, 0.8642678571428571}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[19, 20], Rational[9, 10]}, {
         Rational[26581, 28000], Rational[909, 1000]}}, {{0.95, 0.9}, {
        0.9493214285714285, 0.909}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[19, 20], Rational[19, 20]}, {
         Rational[53371, 56000], Rational[53371, 56000]}}, {{0.95, 0.95}, {
        0.9530535714285714, 0.9530535714285714}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[19, 20], 1}, {
         Rational[2679, 2800], Rational[279, 280]}}, {{0.95, 1}, {
         0.9567857142857142, 0.9964285714285714}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{1, 0}, {Rational[13, 14], 0}}, {{1, 0}, {
         0.9285714285714286, 0}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{1, Rational[1, 20]}, {
         Rational[261, 280], Rational[159, 2800]}}, {{1, 0.05}, {
         0.9321428571428572, 0.05678571428571429}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{1, Rational[1, 10]}, {
         Rational[131, 140], Rational[79, 700]}}, {{1, 0.1}, {
         0.9357142857142857, 0.11285714285714285`}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{1, Rational[3, 20]}, {
         Rational[263, 280], Rational[471, 2800]}}, {{1, 0.15}, {
         0.9392857142857143, 0.1682142857142857}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{1, Rational[1, 5]}, {
         Rational[33, 35], Rational[39, 175]}}, {{1, 0.2}, {
         0.9428571428571428, 0.22285714285714286`}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{1, Rational[1, 4]}, {
         Rational[53, 56], Rational[31, 112]}}, {{1, 0.25}, {
         0.9464285714285714, 0.2767857142857143}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{1, Rational[3, 10]}, {
         Rational[19, 20], Rational[33, 100]}}, {{1, 0.3}, {0.95, 0.33}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{1, Rational[7, 20]}, {
         Rational[267, 280], Rational[153, 400]}}, {{1, 0.35}, {
         0.9535714285714286, 0.3825}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{1, Rational[2, 5]}, {
         Rational[67, 70], Rational[76, 175]}}, {{1, 0.4}, {
         0.9571428571428572, 0.4342857142857143}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{1, Rational[9, 20]}, {
         Rational[269, 280], Rational[1359, 2800]}}, {{1, 0.45}, {
         0.9607142857142857, 0.4853571428571429}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{1, Rational[1, 2]}, {
         Rational[27, 28], Rational[15, 28]}}, {{1, 0.5}, {0.9642857142857143,
          0.5357142857142857}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{1, Rational[11, 20]}, {
         Rational[271, 280], Rational[1639, 2800]}}, {{1, 0.55}, {
         0.9678571428571429, 0.5853571428571429}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{1, Rational[3, 5]}, {
         Rational[34, 35], Rational[111, 175]}}, {{1, 0.6}, {
         0.9714285714285714, 0.6342857142857142}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{1, Rational[13, 20]}, {
         Rational[39, 40], Rational[273, 400]}}, {{1, 0.65}, {0.975, 
         0.6825}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{1, Rational[7, 10]}, {
         Rational[137, 140], Rational[73, 100]}}, {{1, 0.7}, {
         0.9785714285714285, 0.73}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{1, Rational[3, 4]}, {
         Rational[55, 56], Rational[87, 112]}}, {{1, 0.75}, {
         0.9821428571428571, 0.7767857142857143}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{1, Rational[4, 5]}, {
         Rational[69, 70], Rational[144, 175]}}, {{1, 0.8}, {
         0.9857142857142858, 0.8228571428571428}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{1, Rational[17, 20]}, {
         Rational[277, 280], Rational[2431, 2800]}}, {{1, 0.85}, {
         0.9892857142857143, 0.8682142857142857}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{1, Rational[9, 10]}, {
         Rational[139, 140], Rational[639, 700]}}, {{1, 0.9}, {
         0.9928571428571429, 0.9128571428571428}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{1, Rational[19, 20]}, {
         Rational[279, 280], Rational[2679, 2800]}}, {{1, 0.95}, {
         0.9964285714285714, 0.9567857142857142}}]]}, 
     {PointSize[0.008], PointBox[{0, 0}], 
      PointBox[NCache[{Rational[1, 2], Rational[1, 2]}, {0.5, 0.5}]], 
      PointBox[{1, 1}]}}, {
     {EdgeForm[Thickness[Large]], 
      DiskBox[NCache[{Rational[1, 2], Rational[1, 2]}, {0.5, 0.5}], 0.03]}, 
     InsetBox[
      StyleBox["\<\"0\"\>",
       StripOnInput->False,
       FrontFaceColor->GrayLevel[1],
       BackFaceColor->GrayLevel[1],
       GraphicsColor->GrayLevel[1],
       FontFamily->"Times",
       FontSize->16,
       FontWeight->Bold,
       FontColor->GrayLevel[1]], 
      NCache[{Rational[1, 2], Rational[1, 2]}, {0.5, 0.5}]], 
     {GrayLevel[
       NCache[
        Rational[1, 40], 0.025]], EdgeForm[Thickness[Large]], 
      DiskBox[NCache[{Rational[9, 28], Rational[13, 28]}, {
        0.32142857142857145`, 0.4642857142857143}], 0.03]}, InsetBox[
      StyleBox["1",
       StripOnInput->False,
       FrontFaceColor->GrayLevel[1],
       BackFaceColor->GrayLevel[1],
       GraphicsColor->GrayLevel[1],
       FontFamily->"Times",
       FontSize->16,
       FontWeight->Bold,
       FontColor->GrayLevel[1]], 
      NCache[{Rational[9, 28], Rational[13, 28]}, {0.32142857142857145`, 
       0.4642857142857143}]], 
     {GrayLevel[
       NCache[
        Rational[1, 20], 0.05]], EdgeForm[Thickness[Large]], 
      DiskBox[NCache[{Rational[81, 392], Rational[169, 392]}, {
        0.2066326530612245, 0.43112244897959184`}], 0.03]}, InsetBox[
      StyleBox["2",
       StripOnInput->False,
       FrontFaceColor->GrayLevel[1],
       BackFaceColor->GrayLevel[1],
       GraphicsColor->GrayLevel[1],
       FontFamily->"Times",
       FontSize->16,
       FontWeight->Bold,
       FontColor->GrayLevel[1]], 
      NCache[{Rational[81, 392], Rational[169, 392]}, {0.2066326530612245, 
       0.43112244897959184`}]], 
     {GrayLevel[
       NCache[
        Rational[3, 40], 0.075]], EdgeForm[Thickness[Large]], 
      DiskBox[NCache[{Rational[729, 5488], Rational[2197, 5488]}, {
        0.13283527696793002`, 0.40032798833819244`}], 0.03]}, InsetBox[
      StyleBox["3",
       StripOnInput->False,
       FrontFaceColor->GrayLevel[1],
       BackFaceColor->GrayLevel[1],
       GraphicsColor->GrayLevel[1],
       FontFamily->"Times",
       FontSize->16,
       FontWeight->Bold,
       FontColor->GrayLevel[1]], 
      NCache[{Rational[729, 5488], Rational[2197, 5488]}, {
       0.13283527696793002`, 0.40032798833819244`}]], 
     {GrayLevel[
       NCache[
        Rational[1, 10], 0.1]], EdgeForm[Thickness[Large]], 
      DiskBox[NCache[{Rational[6561, 76832], Rational[28561, 76832]}, {
        0.08539410662224073, 0.37173313202832153`}], 0.03]}, InsetBox[
      StyleBox["4",
       StripOnInput->False,
       FrontFaceColor->GrayLevel[1],
       BackFaceColor->GrayLevel[1],
       GraphicsColor->GrayLevel[1],
       FontFamily->"Times",
       FontSize->16,
       FontWeight->Bold,
       FontColor->GrayLevel[1]], 
      NCache[{Rational[6561, 76832], Rational[28561, 76832]}, {
       0.08539410662224073, 0.37173313202832153`}]], 
     {GrayLevel[
       NCache[
        Rational[1, 8], 0.125]], EdgeForm[Thickness[Large]], 
      DiskBox[
       NCache[{Rational[85293, 1075648], Rational[371293, 1075648]}, {
        0.07929452757779497, 0.34518076545487}], 0.03]}, InsetBox[
      StyleBox["5",
       StripOnInput->False,
       FrontFaceColor->GrayLevel[1],
       BackFaceColor->GrayLevel[1],
       GraphicsColor->GrayLevel[1],
       FontFamily->"Times",
       FontSize->16,
       FontWeight->Bold,
       FontColor->GrayLevel[1]], 
      NCache[{Rational[85293, 1075648], Rational[371293, 1075648]}, {
       0.07929452757779497, 0.34518076545487}]], 
     {GrayLevel[
       NCache[
        Rational[3, 20], 0.15]], EdgeForm[Thickness[Large]], 
      DiskBox[NCache[{
        Rational[1108809, 15059072], Rational[4826809, 15059072]}, {
        0.07363063275080961, 0.32052499649380783`}], 0.03]}, InsetBox[
      StyleBox["6",
       StripOnInput->False,
       FrontFaceColor->GrayLevel[1],
       BackFaceColor->GrayLevel[1],
       GraphicsColor->GrayLevel[1],
       FontFamily->"Times",
       FontSize->16,
       FontWeight->Bold,
       FontColor->GrayLevel[1]], 
      NCache[{Rational[1108809, 15059072], Rational[4826809, 15059072]}, {
       0.07363063275080961, 0.32052499649380783`}]], 
     {GrayLevel[
       NCache[
        Rational[7, 40], 0.175]], EdgeForm[Thickness[Large]], 
      DiskBox[NCache[{
        Rational[9979281, 210827008], Rational[62748517, 210827008]}, {
        0.04733397819694904, 0.2976303538871073}], 0.03]}, InsetBox[
      StyleBox["7",
       StripOnInput->False,
       FrontFaceColor->GrayLevel[1],
       BackFaceColor->GrayLevel[1],
       GraphicsColor->GrayLevel[1],
       FontFamily->"Times",
       FontSize->16,
       FontWeight->Bold,
       FontColor->GrayLevel[1]], 
      NCache[{Rational[9979281, 210827008], Rational[62748517, 210827008]}, {
       0.04733397819694904, 0.2976303538871073}]], 
     {GrayLevel[
       NCache[
        Rational[1, 5], 0.2]], EdgeForm[Thickness[Large]], 
      DiskBox[
       NCache[{Rational[129730653, 2951578112], Rational[
         815730721, 2951578112]}, {0.04395297975430982, 
        0.27637104289517106`}], 0.03]}, InsetBox[
      StyleBox["8",
       StripOnInput->False,
       FrontFaceColor->GrayLevel[1],
       BackFaceColor->GrayLevel[1],
       GraphicsColor->GrayLevel[1],
       FontFamily->"Times",
       FontSize->16,
       FontWeight->Bold,
       FontColor->GrayLevel[1]], 
      NCache[{Rational[129730653, 2951578112], Rational[
        815730721, 2951578112]}, {0.04395297975430982, 
       0.27637104289517106`}]], 
     {GrayLevel[
       NCache[
        Rational[9, 40], 0.225]], EdgeForm[Thickness[Large]], 
      DiskBox[NCache[{
        Rational[1686498489, 41322093568], Rational[
         10604499373, 41322093568]}, {0.040813481200430546`, 
        0.25663025411694457`}], 0.03]}, InsetBox[
      StyleBox["9",
       StripOnInput->False,
       FrontFaceColor->GrayLevel[1],
       BackFaceColor->GrayLevel[1],
       GraphicsColor->GrayLevel[1],
       FontFamily->"Times",
       FontSize->16,
       FontWeight->Bold,
       FontColor->GrayLevel[1]], 
      NCache[{Rational[1686498489, 41322093568], Rational[
        10604499373, 41322093568]}, {0.040813481200430546`, 
       0.25663025411694457`}]], 
     {GrayLevel[
       NCache[
        Rational[1, 4], 0.25]], EdgeForm[Thickness[Large]], 
      DiskBox[NCache[{
        Rational[15178486401, 578509309952], Rational[
         137858491849, 578509309952]}, {0.026237237914562495`, 
        0.23829952168001994`}], 0.03]}, InsetBox[
      StyleBox["10",
       StripOnInput->False,
       FrontFaceColor->GrayLevel[1],
       BackFaceColor->GrayLevel[1],
       GraphicsColor->GrayLevel[1],
       FontFamily->"Times",
       FontSize->16,
       FontWeight->Bold,
       FontColor->GrayLevel[1]], 
      NCache[{Rational[15178486401, 578509309952], Rational[
        137858491849, 578509309952]}, {0.026237237914562495`, 
       0.23829952168001994`}]], 
     {GrayLevel[
       NCache[
        Rational[11, 40], 0.275]], EdgeForm[Thickness[Large]], 
      DiskBox[NCache[{
        Rational[136606377609, 8099130339328], Rational[
         1792160394037, 8099130339328]}, {0.016866795802218747`, 
        0.22127812727430424`}], 0.03]}, InsetBox[
      StyleBox["11",
       StripOnInput->False,
       FrontFaceColor->GrayLevel[1],
       BackFaceColor->GrayLevel[1],
       GraphicsColor->GrayLevel[1],
       FontFamily->"Times",
       FontSize->16,
       FontWeight->Bold,
       FontColor->GrayLevel[1]], 
      NCache[{Rational[136606377609, 8099130339328], Rational[
        1792160394037, 8099130339328]}, {0.016866795802218747`, 
       0.22127812727430424`}]], 
     {GrayLevel[
       NCache[
        Rational[3, 10], 0.3]], EdgeForm[Thickness[Large]], 
      DiskBox[NCache[{
        Rational[1775882908917, 113387824750592], Rational[
         23298085122481, 113387824750592]}, {0.015662024673488834`, 
        0.20547254675471108`}], 0.03]}, InsetBox[
      StyleBox["12",
       StripOnInput->False,
       FrontFaceColor->GrayLevel[1],
       BackFaceColor->GrayLevel[1],
       GraphicsColor->GrayLevel[1],
       FontFamily->"Times",
       FontSize->16,
       FontWeight->Bold,
       FontColor->GrayLevel[1]], 
      NCache[{Rational[1775882908917, 113387824750592], Rational[
        23298085122481, 113387824750592]}, {0.015662024673488834`, 
       0.20547254675471108`}]], 
     {GrayLevel[
       NCache[
        Rational[13, 40], 0.325]], EdgeForm[Thickness[Large]], 
      DiskBox[NCache[{
        Rational[23086477815921, 1587429546508288], Rational[
         302875106592253, 1587429546508288]}, {0.01454330862538249, 
        0.1907959362722317}], 0.03]}, InsetBox[
      StyleBox["13",
       StripOnInput->False,
       FrontFaceColor->GrayLevel[1],
       BackFaceColor->GrayLevel[1],
       GraphicsColor->GrayLevel[1],
       FontFamily->"Times",
       FontSize->16,
       FontWeight->Bold,
       FontColor->GrayLevel[1]], 
      NCache[{Rational[23086477815921, 1587429546508288], Rational[
        302875106592253, 1587429546508288]}, {0.01454330862538249, 
       0.1907959362722317}]], 
     {GrayLevel[
       NCache[
        Rational[7, 20], 0.35]], EdgeForm[Thickness[Large]], 
      DiskBox[NCache[{
        Rational[300124211606973, 22224013651116032], Rational[
         3937376385699289, 22224013651116032]}, {0.013504500866426598`, 
        0.17716765510992943`}], 0.03]}, InsetBox[
      StyleBox["14",
       StripOnInput->False,
       FrontFaceColor->GrayLevel[1],
       BackFaceColor->GrayLevel[1],
       GraphicsColor->GrayLevel[1],
       FontFamily->"Times",
       FontSize->16,
       FontWeight->Bold,
       FontColor->GrayLevel[1]], 
      NCache[{Rational[300124211606973, 22224013651116032], Rational[
        3937376385699289, 22224013651116032]}, {0.013504500866426598`, 
       0.17716765510992943`}]], 
     {GrayLevel[
       NCache[
        Rational[3, 8], 0.375]], EdgeForm[Thickness[Large]], 
      DiskBox[NCache[{
        Rational[2701117904462757, 311136191115624448], Rational[
         51185893014090757, 311136191115624448]}, {0.008681464842702814, 
        0.16451282260207736`}], 0.03]}, InsetBox[
      StyleBox["15",
       StripOnInput->False,
       FrontFaceColor->GrayLevel[1],
       BackFaceColor->GrayLevel[1],
       GraphicsColor->GrayLevel[1],
       FontFamily->"Times",
       FontSize->16,
       FontWeight->Bold,
       FontColor->GrayLevel[1]], 
      NCache[{Rational[2701117904462757, 311136191115624448], Rational[
        51185893014090757, 311136191115624448]}, {0.008681464842702814, 
       0.16451282260207736`}]], 
     {GrayLevel[
       NCache[
        Rational[2, 5], 0.4]], EdgeForm[Thickness[Large]], 
      DiskBox[NCache[{
        Rational[35114532758015841, 4355906675618742272], Rational[
         665416609183179841, 4355906675618742272]}, {0.008061360211081184, 
        0.15276190670192896`}], 0.03]}, InsetBox[
      StyleBox["16",
       StripOnInput->False,
       FrontFaceColor->GrayLevel[1],
       BackFaceColor->GrayLevel[1],
       GraphicsColor->GrayLevel[1],
       FontFamily->"Times",
       FontSize->16,
       FontWeight->Bold,
       FontColor->GrayLevel[1]], 
      NCache[{Rational[35114532758015841, 4355906675618742272], Rational[
        665416609183179841, 4355906675618742272]}, {0.008061360211081184, 
       0.15276190670192896`}]], 
     {GrayLevel[
       NCache[
        Rational[17, 40], 0.425]], EdgeForm[Thickness[Large]], 
      DiskBox[NCache[{
        Rational[456488925854205933, 60982693458662391808], Rational[
         8650415919381337933, 60982693458662391808]}, {0.007485548767432528, 
        0.14185034193750545`}], 0.03]}, InsetBox[
      StyleBox["17",
       StripOnInput->False,
       FrontFaceColor->GrayLevel[1],
       BackFaceColor->GrayLevel[1],
       GraphicsColor->GrayLevel[1],
       FontFamily->"Times",
       FontSize->16,
       FontWeight->Bold,
       FontColor->GrayLevel[1]], 
      NCache[{Rational[456488925854205933, 60982693458662391808], Rational[
        8650415919381337933, 60982693458662391808]}, {0.007485548767432528, 
       0.14185034193750545`}]], 
     {GrayLevel[
       NCache[
        Rational[9, 20], 0.45]], EdgeForm[Thickness[Large]], 
      DiskBox[NCache[{
        Rational[4108400332687853397, 853757708421273485312], Rational[
         112455406951957393129, 853757708421273485312]}, {
        0.0048121384933494825`, 0.13171817465625507`}], 0.03]}, InsetBox[
      StyleBox["18",
       StripOnInput->False,
       FrontFaceColor->GrayLevel[1],
       BackFaceColor->GrayLevel[1],
       GraphicsColor->GrayLevel[1],
       FontFamily->"Times",
       FontSize->16,
       FontWeight->Bold,
       FontColor->GrayLevel[1]], 
      NCache[{Rational[4108400332687853397, 853757708421273485312], Rational[
        112455406951957393129, 853757708421273485312]}, {
       0.0048121384933494825`, 0.13171817465625507`}]], 
     {GrayLevel[
       NCache[
        Rational[19, 40], 0.475]], EdgeForm[Thickness[Large]], 
      DiskBox[NCache[{
        Rational[53409204324942094161, 11952607917897828794368], Rational[
         1461920290375446110677, 11952607917897828794368]}, {
        0.00446841431525309, 0.12230973360937969`}], 0.03]}, InsetBox[
      StyleBox["19",
       StripOnInput->False,
       FrontFaceColor->GrayLevel[1],
       BackFaceColor->GrayLevel[1],
       GraphicsColor->GrayLevel[1],
       FontFamily->"Times",
       FontSize->16,
       FontWeight->Bold,
       FontColor->GrayLevel[1]], 
      NCache[{Rational[53409204324942094161, 11952607917897828794368], 
        Rational[1461920290375446110677, 11952607917897828794368]}, {
       0.00446841431525309, 0.12230973360937969`}]], 
     {GrayLevel[
       NCache[
        Rational[1, 2], 0.5]], EdgeForm[Thickness[Large]], 
      DiskBox[NCache[{
        Rational[694319656224247224093, 167336510850569603121152], Rational[
         19004963774880799438801, 167336510850569603121152]}, {
        0.004149241864163584, 0.11357332406585259`}], 0.03]}, InsetBox[
      StyleBox["20",
       StripOnInput->False,
       FrontFaceColor->GrayLevel[0],
       BackFaceColor->GrayLevel[0],
       GraphicsColor->GrayLevel[0],
       FontFamily->"Times",
       FontSize->16,
       FontWeight->Bold,
       FontColor->GrayLevel[0]], 
      NCache[{Rational[694319656224247224093, 167336510850569603121152], 
        Rational[19004963774880799438801, 167336510850569603121152]}, {
       0.004149241864163584, 0.11357332406585259`}]], 
     {GrayLevel[
       NCache[
        Rational[21, 40], 0.525]], EdgeForm[Thickness[Large]], 
      DiskBox[NCache[{
        Rational[9026155530915213913209, 2342711151907974443696128], Rational[
         247064529073450392704413, 2342711151907974443696128]}, {
        0.003852867445294756, 0.10546094377543454`}], 0.03]}, InsetBox[
      StyleBox["21",
       StripOnInput->False,
       FrontFaceColor->GrayLevel[0],
       BackFaceColor->GrayLevel[0],
       GraphicsColor->GrayLevel[0],
       FontFamily->"Times",
       FontSize->16,
       FontWeight->Bold,
       FontColor->GrayLevel[0]], 
      NCache[{Rational[9026155530915213913209, 2342711151907974443696128], 
        Rational[247064529073450392704413, 2342711151907974443696128]}, {
       0.003852867445294756, 0.10546094377543454`}]], 
     {GrayLevel[
       NCache[
        Rational[11, 20], 0.55]], EdgeForm[Thickness[Large]], 
      DiskBox[NCache[{
        Rational[117340021901897780871717, 32797956126711642211745792], 
         Rational[3211838877954855105157369, 32797956126711642211745792]}, {
        0.0035776626277737025`, 0.09792801922004636}], 0.03]}, InsetBox[
      StyleBox["22",
       StripOnInput->False,
       FrontFaceColor->GrayLevel[0],
       BackFaceColor->GrayLevel[0],
       GraphicsColor->GrayLevel[0],
       FontFamily->"Times",
       FontSize->16,
       FontWeight->Bold,
       FontColor->GrayLevel[0]], 
      NCache[{Rational[117340021901897780871717, 32797956126711642211745792], 
        Rational[3211838877954855105157369, 32797956126711642211745792]}, {
       0.0035776626277737025`, 0.09792801922004636}]], 
     {GrayLevel[
       NCache[
        Rational[23, 40], 0.575]], EdgeForm[Thickness[Large]], 
      DiskBox[NCache[{
        Rational[1525420284724671151332321, 459171385773962990964441088], 
         Rational[41753905413413116367045797, 459171385773962990964441088]}, {
        0.0033221152972184383`, 0.09093316070432877}], 0.03]}, InsetBox[
      StyleBox["23",
       StripOnInput->False,
       FrontFaceColor->GrayLevel[0],
       BackFaceColor->GrayLevel[0],
       GraphicsColor->GrayLevel[0],
       FontFamily->"Times",
       FontSize->16,
       FontWeight->Bold,
       FontColor->GrayLevel[0]], 
      NCache[{Rational[
        1525420284724671151332321, 459171385773962990964441088], Rational[
        41753905413413116367045797, 459171385773962990964441088]}, {
       0.0033221152972184383`, 0.09093316070432877}]], 
     {GrayLevel[
       NCache[
        Rational[3, 5], 0.6]], EdgeForm[Thickness[Large]], 
      DiskBox[NCache[{
        Rational[19830463701420724967320173, 6428399400835481873502175232], 
         Rational[
         542800770374370512771595361, 6428399400835481873502175232]}, {
        0.003084821347417121, 0.08443793493973385}], 0.03]}, InsetBox[
      StyleBox["24",
       StripOnInput->False,
       FrontFaceColor->GrayLevel[0],
       BackFaceColor->GrayLevel[0],
       GraphicsColor->GrayLevel[0],
       FontFamily->"Times",
       FontSize->16,
       FontWeight->Bold,
       FontColor->GrayLevel[0]], 
      NCache[{Rational[
        19830463701420724967320173, 6428399400835481873502175232], Rational[
        542800770374370512771595361, 6428399400835481873502175232]}, {
       0.003084821347417121, 0.08443793493973385}]], 
     {GrayLevel[
       NCache[
        Rational[5, 8], 0.625]], EdgeForm[Thickness[Large]], 
      DiskBox[NCache[{
        Rational[257796028118469424575162249, 89997591611696746229030453248], 
         Rational[
         7056410014866816666030739693, 89997591611696746229030453248]}, {
        0.0028644769654587554`, 0.07840665387261002}], 0.03]}, InsetBox[
      StyleBox["25",
       StripOnInput->False,
       FrontFaceColor->GrayLevel[0],
       BackFaceColor->GrayLevel[0],
       GraphicsColor->GrayLevel[0],
       FontFamily->"Times",
       FontSize->16,
       FontWeight->Bold,
       FontColor->GrayLevel[0]], 
      NCache[{Rational[
        257796028118469424575162249, 89997591611696746229030453248], Rational[
        7056410014866816666030739693, 89997591611696746229030453248]}, {
       0.0028644769654587554`, 0.07840665387261002}]], 
     {GrayLevel[
       NCache[
        Rational[13, 20], 0.65]], EdgeForm[Thickness[Large]], 
      DiskBox[NCache[{
        Rational[
         3351348365540102519477109237, 1259966282563754447206426345472], 
         Rational[
         91733330193268616658399616009, 1259966282563754447206426345472]}, {
        0.002659871467925987, 0.07280617859599502}], 0.03]}, InsetBox[
      StyleBox["26",
       StripOnInput->False,
       FrontFaceColor->GrayLevel[0],
       BackFaceColor->GrayLevel[0],
       GraphicsColor->GrayLevel[0],
       FontFamily->"Times",
       FontSize->16,
       FontWeight->Bold,
       FontColor->GrayLevel[0]], 
      NCache[{Rational[
        3351348365540102519477109237, 1259966282563754447206426345472], 
        Rational[
        91733330193268616658399616009, 1259966282563754447206426345472]}, {
       0.002659871467925987, 0.07280617859599502}]], 
     {GrayLevel[
       NCache[
        Rational[27, 40], 0.675]], EdgeForm[Thickness[Large]], 
      DiskBox[NCache[{
        Rational[
         43567528752021332753202420081, 17639527955892562260889968836608], 
         Rational[
         1192533292512492016559195008117, 
          17639527955892562260889968836608]}, {0.0024698806487884165`, 
        0.06760573726770966}], 0.03]}, InsetBox[
      StyleBox["27",
       StripOnInput->False,
       FrontFaceColor->GrayLevel[0],
       BackFaceColor->GrayLevel[0],
       GraphicsColor->GrayLevel[0],
       FontFamily->"Times",
       FontSize->16,
       FontWeight->Bold,
       FontColor->GrayLevel[0]], 
      NCache[{Rational[
        43567528752021332753202420081, 17639527955892562260889968836608], 
        Rational[
        1192533292512492016559195008117, 17639527955892562260889968836608]}, {
       0.0024698806487884165`, 0.06760573726770966}]], 
     {GrayLevel[
       NCache[
        Rational[7, 10], 0.7]], EdgeForm[Thickness[Large]], 
      DiskBox[NCache[{
        Rational[
         566377873776277325791631461053, 246953391382495871652459563712512], 
         Rational[
         15502932802662396215269535105521, 
          246953391382495871652459563712512]}, {0.002293460602446387, 
        0.06277675603430181}], 0.03]}, InsetBox[
      StyleBox["28",
       StripOnInput->False,
       FrontFaceColor->GrayLevel[0],
       BackFaceColor->GrayLevel[0],
       GraphicsColor->GrayLevel[0],
       FontFamily->"Times",
       FontSize->16,
       FontWeight->Bold,
       FontColor->GrayLevel[0]], 
      NCache[{Rational[
        566377873776277325791631461053, 246953391382495871652459563712512], 
        Rational[
        15502932802662396215269535105521, 
         246953391382495871652459563712512]}, {0.002293460602446387, 
       0.06277675603430181}]], 
     {GrayLevel[
       NCache[
        Rational[29, 40], 0.725]], EdgeForm[Thickness[Large]], 
      DiskBox[NCache[{
        Rational[
         7362912359091605235291208993689, 3457347479354942203134433891975168],
          Rational[
         201538126434611150798503956371773, 
          3457347479354942203134433891975168]}, {0.0021296419879859303`, 
        0.05829270203185168}], 0.03]}, InsetBox[
      StyleBox["29",
       StripOnInput->False,
       FrontFaceColor->GrayLevel[0],
       BackFaceColor->GrayLevel[0],
       GraphicsColor->GrayLevel[0],
       FontFamily->"Times",
       FontSize->16,
       FontWeight->Bold,
       FontColor->GrayLevel[0]], 
      NCache[{Rational[
        7362912359091605235291208993689, 3457347479354942203134433891975168], 
        Rational[
        201538126434611150798503956371773, 
         3457347479354942203134433891975168]}, {0.0021296419879859303`, 
       0.05829270203185168}]], 
     {GrayLevel[
       NCache[
        Rational[3, 4], 0.75]], EdgeForm[Thickness[Large]], 
      DiskBox[NCache[{
        Rational[
         95717860668190868058785716917957, 
          48402864710969190843882074487652352], Rational[
         2619995643649944960380551432833049, 
          48402864710969190843882074487652352]}, {0.001977524703129793, 
        0.05412893760100515}], 0.03]}, InsetBox[
      StyleBox["30",
       StripOnInput->False,
       FrontFaceColor->GrayLevel[0],
       BackFaceColor->GrayLevel[0],
       GraphicsColor->GrayLevel[0],
       FontFamily->"Times",
       FontSize->16,
       FontWeight->Bold,
       FontColor->GrayLevel[0]], 
      NCache[{Rational[
        95717860668190868058785716917957, 
         48402864710969190843882074487652352], Rational[
        2619995643649944960380551432833049, 
         48402864710969190843882074487652352]}, {0.001977524703129793, 
       0.05412893760100515}]], 
     {GrayLevel[
       NCache[
        Rational[31, 40], 0.775]], EdgeForm[Thickness[Large]], 
      DiskBox[NCache[{
        Rational[
         1244332188686481284764214319933441, 
          677640105953568671814349042827132928], Rational[
         34059943367449284484947168626829637, 
          677640105953568671814349042827132928]}, {0.0018362729386205217`, 
        0.05026258491521905}], 0.03]}, InsetBox[
      StyleBox["31",
       StripOnInput->False,
       FrontFaceColor->GrayLevel[0],
       BackFaceColor->GrayLevel[0],
       GraphicsColor->GrayLevel[0],
       FontFamily->"Times",
       FontSize->16,
       FontWeight->Bold,
       FontColor->GrayLevel[0]], 
      NCache[{Rational[
        1244332188686481284764214319933441, 
         677640105953568671814349042827132928], Rational[
        34059943367449284484947168626829637, 
         677640105953568671814349042827132928]}, {0.0018362729386205217`, 
       0.05026258491521905}]], 
     {GrayLevel[
       NCache[
        Rational[4, 5], 0.8]], EdgeForm[Thickness[Large]], 
      DiskBox[NCache[{
        Rational[
         16176318452924256701934786159134733, 
          9486961483349961405400886599579860992], Rational[
         442779263776840698304313192148785281, 
          9486961483349961405400886599579860992]}, {0.001705110585861913, 
        0.046672400278417694`}], 0.03]}, InsetBox[
      StyleBox["32",
       StripOnInput->False,
       FrontFaceColor->GrayLevel[0],
       BackFaceColor->GrayLevel[0],
       GraphicsColor->GrayLevel[0],
       FontFamily->"Times",
       FontSize->16,
       FontWeight->Bold,
       FontColor->GrayLevel[0]], 
      NCache[{Rational[
        16176318452924256701934786159134733, 
         9486961483349961405400886599579860992], Rational[
        442779263776840698304313192148785281, 
         9486961483349961405400886599579860992]}, {0.001705110585861913, 
       0.046672400278417694`}]], 
     {GrayLevel[
       NCache[
        Rational[33, 40], 0.825]], EdgeForm[Thickness[Large]], 
      DiskBox[NCache[{
        Rational[
         210292139888015337125152220068751529, 
          132817460766899459675612412394118053888], Rational[
         5756130429098929077956071497934208653, 
          132817460766899459675612412394118053888]}, {0.0015833169725860622`, 
        0.04333865740138786}], 0.03]}, InsetBox[
      StyleBox["33",
       StripOnInput->False,
       FrontFaceColor->GrayLevel[0],
       BackFaceColor->GrayLevel[0],
       GraphicsColor->GrayLevel[0],
       FontFamily->"Times",
       FontSize->16,
       FontWeight->Bold,
       FontColor->GrayLevel[0]], 
      NCache[{Rational[
        210292139888015337125152220068751529, 
         132817460766899459675612412394118053888], Rational[
        5756130429098929077956071497934208653, 
         132817460766899459675612412394118053888]}, {0.0015833169725860622`, 
       0.04333865740138786}]], 
     {GrayLevel[
       NCache[
        Rational[17, 20], 0.85]], EdgeForm[Thickness[Large]], 
      DiskBox[NCache[{
        Rational[
         2733797818544199382626978860893769877, 
          1859444450736592435458573773517652754432], Rational[
         74829695578286078013428929473144712489, 
          1859444450736592435458573773517652754432]}, {0.0014702229031156291`,
         0.040243039015574446`}], 0.03]}, InsetBox[
      StyleBox["34",
       StripOnInput->False,
       FrontFaceColor->GrayLevel[0],
       BackFaceColor->GrayLevel[0],
       GraphicsColor->GrayLevel[0],
       FontFamily->"Times",
       FontSize->16,
       FontWeight->Bold,
       FontColor->GrayLevel[0]], 
      NCache[{Rational[
        2733797818544199382626978860893769877, 
         1859444450736592435458573773517652754432], Rational[
        74829695578286078013428929473144712489, 
         1859444450736592435458573773517652754432]}, {0.0014702229031156291`, 
       0.040243039015574446`}]], 
     {GrayLevel[
       NCache[
        Rational[7, 8], 0.875]], EdgeForm[Thickness[Large]], 
      DiskBox[NCache[{
        Rational[
         35539371641074591974150725191619008401, 
          26032222310312294096420032829247138562048], Rational[
         972786042517719014174576083150881262357, 
          26032222310312294096420032829247138562048]}, {
        0.0013652069814645128`, 0.0373685362287477}], 0.03]}, InsetBox[
      StyleBox["35",
       StripOnInput->False,
       FrontFaceColor->GrayLevel[0],
       BackFaceColor->GrayLevel[0],
       GraphicsColor->GrayLevel[0],
       FontFamily->"Times",
       FontSize->16,
       FontWeight->Bold,
       FontColor->GrayLevel[0]], 
      NCache[{Rational[
        35539371641074591974150725191619008401, 
         26032222310312294096420032829247138562048], Rational[
        972786042517719014174576083150881262357, 
         26032222310312294096420032829247138562048]}, {0.0013652069814645128`,
        0.0373685362287477}]], 
     {GrayLevel[
       NCache[
        Rational[9, 10], 0.9]], EdgeForm[Thickness[Large]], 
      DiskBox[NCache[{
        Rational[
         462011831333969695663959427491047109213, 
          364451112344372117349880459609459939868672], Rational[
         12646218552730347184269489080961456410641, 
          364451112344372117349880459609459939868672]}, {
        0.0012676921970741905`, 0.03469935506955143}], 0.03]}, InsetBox[
      StyleBox["36",
       StripOnInput->False,
       FrontFaceColor->GrayLevel[0],
       BackFaceColor->GrayLevel[0],
       GraphicsColor->GrayLevel[0],
       FontFamily->"Times",
       FontSize->16,
       FontWeight->Bold,
       FontColor->GrayLevel[0]], 
      NCache[{Rational[
        462011831333969695663959427491047109213, 
         364451112344372117349880459609459939868672], Rational[
        12646218552730347184269489080961456410641, 
         364451112344372117349880459609459939868672]}, {
       0.0012676921970741905`, 0.03469935506955143}]], 
     {GrayLevel[
       NCache[
        Rational[37, 40], 0.925]], EdgeForm[Thickness[Large]], 
      DiskBox[NCache[{
        Rational[
         6006153807341606043631472557383612419769, 
          5102315572821209642898326434532439158161408], Rational[
         164400841185494513395503358052498933338333, 
          5102315572821209642898326434532439158161408]}, {
        0.001177142754426034, 0.03222082970744061}], 0.03]}, InsetBox[
      StyleBox["37",
       StripOnInput->False,
       FrontFaceColor->GrayLevel[0],
       BackFaceColor->GrayLevel[0],
       GraphicsColor->GrayLevel[0],
       FontFamily->"Times",
       FontSize->16,
       FontWeight->Bold,
       FontColor->GrayLevel[0]], 
      NCache[{Rational[
        6006153807341606043631472557383612419769, 
         5102315572821209642898326434532439158161408], Rational[
        164400841185494513395503358052498933338333, 
         5102315572821209642898326434532439158161408]}, {0.001177142754426034,
        0.03222082970744061}]], 
     {GrayLevel[
       NCache[
        Rational[19, 20], 0.95]], EdgeForm[Thickness[Large]], 
      DiskBox[NCache[{
        Rational[
         78079999495440878567209143245986961456997, 
          71432418019496935000576570083454148214259712], Rational[
         2137210935411428674141543654682486133398329, 
          71432418019496935000576570083454148214259712]}, {
        0.0010930611291098886`, 0.029919341871194854`}], 0.03]}, InsetBox[
      StyleBox["38",
       StripOnInput->False,
       FrontFaceColor->GrayLevel[0],
       BackFaceColor->GrayLevel[0],
       GraphicsColor->GrayLevel[0],
       FontFamily->"Times",
       FontSize->16,
       FontWeight->Bold,
       FontColor->GrayLevel[0]], 
      NCache[{Rational[
        78079999495440878567209143245986961456997, 
         71432418019496935000576570083454148214259712], Rational[
        2137210935411428674141543654682486133398329, 
         71432418019496935000576570083454148214259712]}, {
       0.0010930611291098886`, 0.029919341871194854`}]], 
     {GrayLevel[
       NCache[
        Rational[39, 40], 0.975]], EdgeForm[Thickness[Large]], 
      DiskBox[NCache[{
        Rational[
         1015039993440731421373718862197830498940961, 
          1000053852272957090008071981168358074999635968], Rational[
         27783742160348572763840067510872319734178277, 
          1000053852272957090008071981168358074999635968]}, {
        0.0010149853341734681`, 0.027782246023252365`}], 0.03]}, InsetBox[
      StyleBox["39",
       StripOnInput->False,
       FrontFaceColor->GrayLevel[0],
       BackFaceColor->GrayLevel[0],
       GraphicsColor->GrayLevel[0],
       FontFamily->"Times",
       FontSize->16,
       FontWeight->Bold,
       FontColor->GrayLevel[0]], 
      NCache[{Rational[
        1015039993440731421373718862197830498940961, 
         1000053852272957090008071981168358074999635968], Rational[
        27783742160348572763840067510872319734178277, 
         1000053852272957090008071981168358074999635968]}, {
       0.0010149853341734681`, 0.027782246023252365`}]], 
     {GrayLevel[1], EdgeForm[Thickness[Large]], 
      DiskBox[NCache[{
        Rational[
         13195519914729508477858345208571796486232493, 
          14000753931821399260113007736357013049994903552], Rational[
         361188648084531445929920877641340156544317601, 
          14000753931821399260113007736357013049994903552]}, {
        0.0009424863817325059, 0.02579779987873434}], 0.03]}, InsetBox[
      StyleBox["40",
       StripOnInput->False,
       FrontFaceColor->GrayLevel[0],
       BackFaceColor->GrayLevel[0],
       GraphicsColor->GrayLevel[0],
       FontFamily->"Times",
       FontSize->16,
       FontWeight->Bold,
       FontColor->GrayLevel[0]], 
      NCache[{Rational[
        13195519914729508477858345208571796486232493, 
         14000753931821399260113007736357013049994903552], Rational[
        361188648084531445929920877641340156544317601, 
         14000753931821399260113007736357013049994903552]}, {
       0.0009424863817325059, 0.02579779987873434}]]}}},
  AspectRatio->1,
  BaseStyle->Directive[FontFamily -> "Times", FontSize -> 20],
  Frame->True,
  FrameLabel->{{
     FormBox[
      InterpretationBox[
       Cell[
        BoxData[
         FormBox[
          StyleBox[
          "\"Probability of Cooperating, Player1\"", FontSize -> 26, 
           FontFamily -> "Times", StripOnInput -> False], TraditionalForm]], 
        "Text", "TR"], 
       Text[
        Style[
        "Probability of Cooperating, Player1", FontSize -> 26, FontFamily -> 
         "Times"]]], TraditionalForm], None}, {
     FormBox[
      InterpretationBox[
       Cell[
        BoxData[
         FormBox[
          StyleBox[
          "\"Probability of Cooperating, Player2\"", FontSize -> 26, 
           FontFamily -> "Times", StripOnInput -> False], TraditionalForm]], 
        "Text", "TR"], 
       Text[
        Style[
        "Probability of Cooperating, Player2", FontSize -> 26, FontFamily -> 
         "Times"]]], TraditionalForm], None}},
  FrameStyle->Thickness[Large],
  FrameTicks->{{{{0, 
       FormBox["\" 0 \"", TraditionalForm], 0.02}, {0.2, 
       FormBox["\" 0.2 \"", TraditionalForm], 0.02}, {0.4, 
       FormBox["\" 0.4 \"", TraditionalForm], 0.02}, {0.6, 
       FormBox["\" 0.6 \"", TraditionalForm], 0.02}, {0.8, 
       FormBox["\" 0.8 \"", TraditionalForm], 0.02}, {1, 
       FormBox["\" 1 \"", TraditionalForm], 0.02}}, None}, {{{0, 
       FormBox["0", TraditionalForm], 0.02}, {0.2, 
       FormBox["0.2`", TraditionalForm], 0.02}, {0.4, 
       FormBox["0.4`", TraditionalForm], 0.02}, {0.6, 
       FormBox["0.6`", TraditionalForm], 0.02}, {0.8, 
       FormBox["0.8`", TraditionalForm], 0.02}, {1, 
       FormBox["1", TraditionalForm], 0.02}}, None}},
  FrameTicksStyle->Thickness[Large],
  ImageSize->{666., Automatic},
  PlotRange->{{-0.04, 1.04}, {-0.04, 1.04}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.392777606640625*^9, 3.392777638609375*^9, 3.392777698265625*^9, {
   3.39277777125*^9, 3.392777825125*^9}, 3.392855044703125*^9, 
   3.3928552813125*^9, 3.392855404328125*^9, 3.39285544228125*^9, 
   3.39285549921875*^9, 3.392856978609375*^9, {3.392857069359375*^9, 
   3.392857093125*^9}, 3.392859517609375*^9, 3.392859777625*^9, 
   3.392860168046875*^9, {3.3928602115625*^9, 3.3928602308125*^9}, 
   3.392860291671875*^9, 3.392860633234375*^9, 3.3928636300625*^9, 
   3.392863720625*^9, 3.392863767703125*^9, 3.392869604796875*^9, 
   3.393406907390625*^9, 3.39340703496875*^9, 3.3934072065625*^9, 
   3.3934073020625*^9, 3.393407338234375*^9, 3.39340761403125*^9, 
   3.39343689309375*^9, 3.3934369606875*^9, 3.39343728371875*^9, 
   3.3934373381875*^9, 3.393437375734375*^9, 3.39343751775*^9, 
   3.393437642765625*^9, {3.393437767171875*^9, 3.393437795625*^9}, 
   3.39343783159375*^9, 3.393437883875*^9, 3.39343801759375*^9, {
   3.3934380976875*^9, 3.39343811915625*^9}, 3.393438166765625*^9, {
   3.393438566859375*^9, 3.393438593578125*^9}, 3.393438791578125*^9, {
   3.39343890346875*^9, 3.39343893215625*^9}, 3.3934397266875*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Figure - Saving to file", "Section"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"numberOfExtensions", "=", "  ", 
    RowBox[{"Length", "[", "extensions", "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"For", "[", 
   RowBox[{
    RowBox[{"j", "=", "1"}], ",", " ", 
    RowBox[{"j", "\[LessEqual]", "numberOfExtensions"}], ",", 
    RowBox[{"j", "++"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Export", "[", 
      RowBox[{
       RowBox[{"StringJoin", "[", 
        RowBox[{"\"\<fig1\>\"", ",", 
         RowBox[{"extensions", "[", 
          RowBox[{"[", "j", "]"}], "]"}]}], "]"}], ",", "gFigure", ",", 
       RowBox[{"ImageSize", "\[Rule]", 
        RowBox[{"{", "figureSize", "}"}]}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Export", "[", 
      RowBox[{
       RowBox[{"StringJoin", "[", 
        RowBox[{"\"\<fig1-legend\>\"", ",", 
         RowBox[{"extensions", "[", 
          RowBox[{"[", "j", "]"}], "]"}]}], "]"}], ",", "myLegend", ",", 
       RowBox[{"ImageSize", "\[Rule]", " ", 
        RowBox[{"{", 
         RowBox[{"figureSize", "/", "2"}], "}"}]}]}], "]"}], ";"}]}], 
   "\[IndentingNewLine]", "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.3927586769375*^9, 3.392758688484375*^9}, {
   3.3927592378125*^9, 3.3927592385*^9}, {3.392759381578125*^9, 
   3.39275939021875*^9}, {3.39275943190625*^9, 3.3927594331875*^9}, {
   3.3927595433125*^9, 3.3927595620625*^9}, {3.392759641953125*^9, 
   3.39275971225*^9}, {3.39275974796875*^9, 3.3927598060625*^9}, {
   3.392759892609375*^9, 3.392759892984375*^9}, {3.392759983203125*^9, 
   3.392760003234375*^9}, {3.392760053984375*^9, 3.392760073734375*^9}, {
   3.392760146625*^9, 3.392760194484375*^9}, {3.39276023546875*^9, 
   3.3927602358125*^9}, {3.392760511796875*^9, 3.392760512796875*^9}, {
   3.39276069621875*^9, 3.392760696453125*^9}, {3.39276156046875*^9, 
   3.392761561390625*^9}, {3.3927631243125*^9, 3.392763155984375*^9}, 
   3.3927631870625*^9, {3.392763245265625*^9, 3.392763267328125*^9}, {
   3.39276351321875*^9, 3.392763513734375*^9}, {3.392764418703125*^9, 
   3.392764439859375*^9}, {3.39276453215625*^9, 3.392764557671875*^9}, {
   3.392860613421875*^9, 3.392860624828125*^9}, {3.3928606578125*^9, 
   3.392860657984375*^9}}]
}, Closed]]
},
CellGrouping->Manual,
WindowSize->{1432, 790},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
FrontEndVersion->"6.0 for Microsoft Windows (32-bit) (June 19, 2007)",
StyleDefinitions->"DemoText.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 86, 2, 56, "Title"],
Cell[657, 25, 65, 0, 37, "Subtitle"],
Cell[725, 27, 783, 15, 90, "Subsubtitle"],
Cell[CellGroupData[{
Cell[1533, 46, 57, 0, 52, "Section"],
Cell[1593, 48, 779, 17, 294, "Subsubtitle"]
}, Closed]],
Cell[CellGroupData[{
Cell[2409, 70, 42, 0, 32, "Section"],
Cell[2454, 72, 156, 3, 38, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[2647, 80, 29, 0, 32, "Section"],
Cell[2679, 82, 3547, 84, 659, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[6263, 171, 53, 0, 32, "Section"],
Cell[6319, 173, 9637, 257, 839, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[15993, 435, 65, 0, 32, "Section"],
Cell[16061, 437, 201, 6, 59, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[16299, 448, 59, 0, 32, "Section"],
Cell[CellGroupData[{
Cell[16383, 452, 3634, 93, 361, "Input"],
Cell[20020, 547, 85955, 1754, 297, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[106024, 2307, 46, 0, 32, "Section"],
Cell[106073, 2309, 635, 18, 139, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[106745, 2332, 41, 0, 32, "Section"],
Cell[CellGroupData[{
Cell[106811, 2336, 10610, 248, 868, "Input"],
Cell[117424, 2586, 33558, 861, 522, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[151031, 3453, 36, 0, 32, "Section"],
Cell[CellGroupData[{
Cell[151092, 3457, 16891, 359, 439, "Input"],
Cell[167986, 3818, 137522, 2861, 685, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[305557, 6685, 42, 0, 32, "Section"],
Cell[305602, 6687, 2257, 47, 139, "Input"]
}, Closed]]
}
]
*)

(* End of internal cache information *)
